diff --git a/projects/hip/docs/RuntimeAPI/html/Synchonization.html b/projects/hip/docs/RuntimeAPI/html/Synchonization.html index d1d49391dd..198f1d8d55 100644 --- a/projects/hip/docs/RuntimeAPI/html/Synchonization.html +++ b/projects/hip/docs/RuntimeAPI/html/Synchonization.html @@ -79,7 +79,7 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
The following commands are "host-asynchronous" - meaning they do not wait for any preceding commands to complete, and may return control to the host thread before the requested operation completes:
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/annotated.html b/projects/hip/docs/RuntimeAPI/html/annotated.html
index 1d7e7e2a5b..7aad966bcb 100644
--- a/projects/hip/docs/RuntimeAPI/html/annotated.html
+++ b/projects/hip/docs/RuntimeAPI/html/annotated.html
@@ -96,20 +96,23 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/bug.html b/projects/hip/docs/RuntimeAPI/html/bug.html
index ef94caaa9f..b017f3a1b0 100644
--- a/projects/hip/docs/RuntimeAPI/html/bug.html
+++ b/projects/hip/docs/RuntimeAPI/html/bug.html
@@ -80,22 +80,20 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
HCC always returns 0 for maxThreadsPerMultiProcessor
HCC always returns 0 for regsPerBlock
HCC always returns 0 for l2CacheSize
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structtexture-members.html b/projects/hip/docs/RuntimeAPI/html/classFakeMutex-members.html
similarity index 79%
rename from projects/hip/docs/RuntimeAPI/html/structtexture-members.html
rename to projects/hip/docs/RuntimeAPI/html/classFakeMutex-members.html
index 04556bf525..bd3173d921 100644
--- a/projects/hip/docs/RuntimeAPI/html/structtexture-members.html
+++ b/projects/hip/docs/RuntimeAPI/html/classFakeMutex-members.html
@@ -84,20 +84,19 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
This is the complete list of members for texture< T, texType, hipTextureReadMode >, including all inherited members.
+This is the complete list of members for FakeMutex, including all inherited members.
| _dataPtr (defined in texture< T, texType, hipTextureReadMode >) | texture< T, texType, hipTextureReadMode > | |
| channelDesc (defined in textureReference) | textureReference | |
| filterMode (defined in textureReference) | textureReference | |
| normalized (defined in textureReference) | textureReference | |
| lock() (defined in FakeMutex) | FakeMutex | inline |
| try_lock() (defined in FakeMutex) | FakeMutex | inline |
| unlock() (defined in FakeMutex) | FakeMutex | inline |
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structchar3.html b/projects/hip/docs/RuntimeAPI/html/classFakeMutex.html
similarity index 70%
rename from projects/hip/docs/RuntimeAPI/html/structchar3.html
rename to projects/hip/docs/RuntimeAPI/html/classFakeMutex.html
index bc38841645..99265880e5 100644
--- a/projects/hip/docs/RuntimeAPI/html/structchar3.html
+++ b/projects/hip/docs/RuntimeAPI/html/classFakeMutex.html
@@ -4,7 +4,7 @@
--Public Attributes | |
| -char | x |
| -char | y |
| -char | z |
+Public Member Functions | |
| +void | lock () |
| +bool | try_lock () |
| +void | unlock () |
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/classLockedAccessor-members.html b/projects/hip/docs/RuntimeAPI/html/classLockedAccessor-members.html
new file mode 100644
index 0000000000..0440c28c7e
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/classLockedAccessor-members.html
@@ -0,0 +1,105 @@
+
+
+
+
+
+
+|
+ HIP: Heterogenous-computing Interface for Portability
+
+ |
+
This is the complete list of members for LockedAccessor< T >, including all inherited members.
+| LockedAccessor(T &criticalData, bool autoUnlock=true) (defined in LockedAccessor< T >) | LockedAccessor< T > | inline |
| operator->() (defined in LockedAccessor< T >) | LockedAccessor< T > | inline |
| unlock() (defined in LockedAccessor< T >) | LockedAccessor< T > | inline |
| ~LockedAccessor() (defined in LockedAccessor< T >) | LockedAccessor< T > | inline |
+ 1.8.6
+
+
+
diff --git a/projects/hip/docs/RuntimeAPI/html/classLockedAccessor.html b/projects/hip/docs/RuntimeAPI/html/classLockedAccessor.html
new file mode 100644
index 0000000000..1712e382f9
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/classLockedAccessor.html
@@ -0,0 +1,117 @@
+
+
+
+
+
+
+|
+ HIP: Heterogenous-computing Interface for Portability
+
+ |
+
+Public Member Functions | |
| + | LockedAccessor (T &criticalData, bool autoUnlock=true) |
| +void | unlock () |
| +T * | operator-> () |
+ 1.8.6
+
+
+
diff --git a/projects/hip/docs/RuntimeAPI/html/classes.html b/projects/hip/docs/RuntimeAPI/html/classes.html
index 205d994eda..a36250a427 100644
--- a/projects/hip/docs/RuntimeAPI/html/classes.html
+++ b/projects/hip/docs/RuntimeAPI/html/classes.html
@@ -87,28 +87,31 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/classihipDeviceCriticalBase__t-members.html b/projects/hip/docs/RuntimeAPI/html/classihipDeviceCriticalBase__t-members.html
new file mode 100644
index 0000000000..02331c2b9e
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/classihipDeviceCriticalBase__t-members.html
@@ -0,0 +1,116 @@
+
+
+
+
+
+
+|
+ HIP: Heterogenous-computing Interface for Portability
+
+ |
+
This is the complete list of members for ihipDeviceCriticalBase_t< MUTEX_TYPE >, including all inherited members.
+| _mutex (defined in LockedBase< MUTEX_TYPE >) | LockedBase< MUTEX_TYPE > | private |
| addPeer(ihipDevice_t *peer) (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >) | ihipDeviceCriticalBase_t< MUTEX_TYPE > | |
| const_streams() const (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >) | ihipDeviceCriticalBase_t< MUTEX_TYPE > | inline |
| ihipDeviceCriticalBase_t() (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >) | ihipDeviceCriticalBase_t< MUTEX_TYPE > | inline |
| incStreamId() (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >) | ihipDeviceCriticalBase_t< MUTEX_TYPE > | inline |
| init(unsigned deviceCnt) (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >) | ihipDeviceCriticalBase_t< MUTEX_TYPE > | inline |
| lock() (defined in LockedBase< MUTEX_TYPE >) | LockedBase< MUTEX_TYPE > | inlineprivate |
| LockedAccessor< ihipDeviceCriticalBase_t > (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >) | ihipDeviceCriticalBase_t< MUTEX_TYPE > | friend |
| peerAgents() const (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >) | ihipDeviceCriticalBase_t< MUTEX_TYPE > | inline |
| peerCnt() const (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >) | ihipDeviceCriticalBase_t< MUTEX_TYPE > | inline |
| removePeer(ihipDevice_t *peer) (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >) | ihipDeviceCriticalBase_t< MUTEX_TYPE > | |
| resetPeers(ihipDevice_t *thisDevice) (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >) | ihipDeviceCriticalBase_t< MUTEX_TYPE > | |
| streams() (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >) | ihipDeviceCriticalBase_t< MUTEX_TYPE > | inline |
| unlock() (defined in LockedBase< MUTEX_TYPE >) | LockedBase< MUTEX_TYPE > | inlineprivate |
| ~ihipDeviceCriticalBase_t() (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >) | ihipDeviceCriticalBase_t< MUTEX_TYPE > | inline |
+ 1.8.6
+
+
+
diff --git a/projects/hip/docs/RuntimeAPI/html/classihipDeviceCriticalBase__t.html b/projects/hip/docs/RuntimeAPI/html/classihipDeviceCriticalBase__t.html
new file mode 100644
index 0000000000..91ecb9dfe3
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/classihipDeviceCriticalBase__t.html
@@ -0,0 +1,151 @@
+
+
+
+
+
+
+|
+ HIP: Heterogenous-computing Interface for Portability
+
+ |
+
+
+ +Public Member Functions | |
| +void | init (unsigned deviceCnt) |
| +std::list< ihipStream_t * > & | streams () |
| +const std::list< ihipStream_t * > & | const_streams () const |
| +ihipStream_t::SeqNum_t | incStreamId () |
| +bool | addPeer (ihipDevice_t *peer) |
| +bool | removePeer (ihipDevice_t *peer) |
| +void | resetPeers (ihipDevice_t *thisDevice) |
| +uint32_t | peerCnt () const |
| +hsa_agent_t * | peerAgents () const |
+Friends | |
| +class | LockedAccessor< ihipDeviceCriticalBase_t > |
+ 1.8.6
+
+
+
diff --git a/projects/hip/docs/RuntimeAPI/html/classihipDeviceCriticalBase__t.png b/projects/hip/docs/RuntimeAPI/html/classihipDeviceCriticalBase__t.png
new file mode 100644
index 0000000000..5b18856aed
Binary files /dev/null and b/projects/hip/docs/RuntimeAPI/html/classihipDeviceCriticalBase__t.png differ
diff --git a/projects/hip/docs/RuntimeAPI/html/structihipDevice__t-members.html b/projects/hip/docs/RuntimeAPI/html/classihipDevice__t-members.html
similarity index 55%
rename from projects/hip/docs/RuntimeAPI/html/structihipDevice__t-members.html
rename to projects/hip/docs/RuntimeAPI/html/classihipDevice__t-members.html
index 18910d1c14..bc1a11bd75 100644
--- a/projects/hip/docs/RuntimeAPI/html/structihipDevice__t-members.html
+++ b/projects/hip/docs/RuntimeAPI/html/classihipDevice__t-members.html
@@ -88,33 +88,29 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
This is the complete list of members for ihipDevice_t, including all inherited members.
+This is the complete list of members for ihipDevice_t, including all inherited members.
| _acc (defined in ihipDevice_t) | ihipDevice_t | |
| _compute_units (defined in ihipDevice_t) | ihipDevice_t | |
| _copy_lock (defined in ihipDevice_t) | ihipDevice_t | |
| _default_stream (defined in ihipDevice_t) | ihipDevice_t | |
| _device_index (defined in ihipDevice_t) | ihipDevice_t | |
| _hsa_agent (defined in ihipDevice_t) | ihipDevice_t | |
| _null_stream (defined in ihipDevice_t) | ihipDevice_t | |
| _props (defined in ihipDevice_t) | ihipDevice_t | |
| _staging_buffer (defined in ihipDevice_t) | ihipDevice_t | |
| _stream_id (defined in ihipDevice_t) | ihipDevice_t | |
| _streams (defined in ihipDevice_t) | ihipDevice_t | |
| getProperties(hipDeviceProp_t *prop) | ihipDevice_t | |
| getProperties(hipDeviceProp_t *prop) (defined in ihipDevice_t) | ihipDevice_t | |
| init(unsigned device_index, hc::accelerator acc) (defined in ihipDevice_t) | ihipDevice_t | |
| init(unsigned device_index, hc::accelerator acc) (defined in ihipDevice_t) | ihipDevice_t | |
| reset() (defined in ihipDevice_t) | ihipDevice_t | |
| reset() (defined in ihipDevice_t) | ihipDevice_t | |
| syncDefaultStream(bool waitOnSelf) (defined in ihipDevice_t) | ihipDevice_t | inline |
| waitAllStreams() (defined in ihipDevice_t) | ihipDevice_t | inline |
| ~ihipDevice_t() (defined in ihipDevice_t) | ihipDevice_t | |
| ~ihipDevice_t() (defined in ihipDevice_t) | ihipDevice_t | |
| _acc (defined in ihipDevice_t) | ihipDevice_t | |
| _compute_units (defined in ihipDevice_t) | ihipDevice_t | |
| _default_stream (defined in ihipDevice_t) | ihipDevice_t | |
| _device_flags (defined in ihipDevice_t) | ihipDevice_t | |
| _device_index (defined in ihipDevice_t) | ihipDevice_t | |
| _hsa_agent (defined in ihipDevice_t) | ihipDevice_t | |
| _props (defined in ihipDevice_t) | ihipDevice_t | |
| _staging_buffer (defined in ihipDevice_t) | ihipDevice_t | |
| criticalData() (defined in ihipDevice_t) | ihipDevice_t | inline |
| ihipDevice_t() (defined in ihipDevice_t) | ihipDevice_t | inline |
| init(unsigned device_index, unsigned deviceCnt, hc::accelerator &acc, unsigned flags) (defined in ihipDevice_t) | ihipDevice_t | |
| locked_addStream(ihipStream_t *s) (defined in ihipDevice_t) | ihipDevice_t | |
| locked_removeStream(ihipStream_t *s) (defined in ihipDevice_t) | ihipDevice_t | |
| locked_reset() (defined in ihipDevice_t) | ihipDevice_t | |
| locked_syncDefaultStream(bool waitOnSelf) (defined in ihipDevice_t) | ihipDevice_t | |
| locked_waitAllStreams() (defined in ihipDevice_t) | ihipDevice_t | |
| ~ihipDevice_t() (defined in ihipDevice_t) | ihipDevice_t |
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structihipDevice__t.html b/projects/hip/docs/RuntimeAPI/html/classihipDevice__t.html
similarity index 62%
rename from projects/hip/docs/RuntimeAPI/html/structihipDevice__t.html
rename to projects/hip/docs/RuntimeAPI/html/classihipDevice__t.html
index 9b98762848..9f3ed0481d 100644
--- a/projects/hip/docs/RuntimeAPI/html/structihipDevice__t.html
+++ b/projects/hip/docs/RuntimeAPI/html/classihipDevice__t.html
@@ -4,7 +4,7 @@
-Public Member Functions | |
| -void | init (unsigned device_index, hc::accelerator acc) |
| -void | reset () |
| hipError_t | getProperties (hipDeviceProp_t *prop) |
| -void | waitAllStreams () |
| -void | syncDefaultStream (bool waitOnSelf) |
| -void | reset () |
| -void | init (unsigned device_index, hc::accelerator acc) |
| -hipError_t | getProperties (hipDeviceProp_t *prop) |
| +void | init (unsigned device_index, unsigned deviceCnt, hc::accelerator &acc, unsigned flags) |
| +void | locked_addStream (ihipStream_t *s) |
| +void | locked_removeStream (ihipStream_t *s) |
| +void | locked_reset () |
| +void | locked_waitAllStreams () |
| +void | locked_syncDefaultStream (bool waitOnSelf) |
| +ihipDeviceCritical_t & | criticalData () |
Public Attributes | _hsa_agent |
| ihipStream_t * | _default_stream |
| -std::list< ihipStream_t * > | _streams |
| unsigned | _compute_units |
| + | |
| StagingBuffer * | _staging_buffer [2] |
| -ihipStream_t::SeqNum_t | _stream_id |
| -ihipStream_t * | _null_stream |
| -std::mutex | _copy_lock [2] |
| +unsigned | _device_flags |
| hipError_t ihipDevice_t::getProperties | -( | -hipDeviceProp_t * | -prop | ) | -- |
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structihipStream__t-members.html b/projects/hip/docs/RuntimeAPI/html/classihipException-members.html
similarity index 77%
rename from projects/hip/docs/RuntimeAPI/html/structihipStream__t-members.html
rename to projects/hip/docs/RuntimeAPI/html/classihipException-members.html
index 57df3ae1ba..937af05387 100644
--- a/projects/hip/docs/RuntimeAPI/html/structihipStream__t-members.html
+++ b/projects/hip/docs/RuntimeAPI/html/classihipException-members.html
@@ -84,21 +84,18 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
This is the complete list of members for ihipStream_t, including all inherited members.
+This is the complete list of members for ihipException, including all inherited members.
| _av (defined in ihipStream_t) | ihipStream_t | |
| _device_index (defined in ihipStream_t) | ihipStream_t | |
| _flags (defined in ihipStream_t) | ihipStream_t | |
| _last_command (defined in ihipStream_t) | ihipStream_t | |
| ihipStream_t(unsigned device_index, hc::accelerator_view av, unsigned int flags) (defined in ihipStream_t) | ihipStream_t | inline |
| _code (defined in ihipException) | ihipException | |
| ihipException(hipError_t e) (defined in ihipException) | ihipException | inline |
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/classihipException.html b/projects/hip/docs/RuntimeAPI/html/classihipException.html
new file mode 100644
index 0000000000..1e57d7e471
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/classihipException.html
@@ -0,0 +1,126 @@
+
+
+
+
+
+
+|
+ HIP: Heterogenous-computing Interface for Portability
+
+ |
+
+
+ +Public Member Functions | |
| + | ihipException (hipError_t e) |
+Public Attributes | |
| +hipError_t | _code |
+ 1.8.6
+
+
+
diff --git a/projects/hip/docs/RuntimeAPI/html/classihipException.png b/projects/hip/docs/RuntimeAPI/html/classihipException.png
new file mode 100644
index 0000000000..36add951e6
Binary files /dev/null and b/projects/hip/docs/RuntimeAPI/html/classihipException.png differ
diff --git a/projects/hip/docs/RuntimeAPI/html/classihipStreamCriticalBase__t-members.html b/projects/hip/docs/RuntimeAPI/html/classihipStreamCriticalBase__t-members.html
new file mode 100644
index 0000000000..60f9c4996e
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/classihipStreamCriticalBase__t-members.html
@@ -0,0 +1,114 @@
+
+
+
+
+
+
+|
+ HIP: Heterogenous-computing Interface for Portability
+
+ |
+
This is the complete list of members for ihipStreamCriticalBase_t< MUTEX_TYPE >, including all inherited members.
+| _last_command_type (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >) | ihipStreamCriticalBase_t< MUTEX_TYPE > | |
| _last_copy_signal (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >) | ihipStreamCriticalBase_t< MUTEX_TYPE > | |
| _last_kernel_future (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >) | ihipStreamCriticalBase_t< MUTEX_TYPE > | |
| _mutex (defined in LockedBase< MUTEX_TYPE >) | LockedBase< MUTEX_TYPE > | |
| _oldest_live_sig_id (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >) | ihipStreamCriticalBase_t< MUTEX_TYPE > | |
| _signalCursor (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >) | ihipStreamCriticalBase_t< MUTEX_TYPE > | |
| _signalPool (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >) | ihipStreamCriticalBase_t< MUTEX_TYPE > | |
| _stream_sig_id (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >) | ihipStreamCriticalBase_t< MUTEX_TYPE > | |
| ihipStreamCriticalBase_t() (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >) | ihipStreamCriticalBase_t< MUTEX_TYPE > | inline |
| lock() (defined in LockedBase< MUTEX_TYPE >) | LockedBase< MUTEX_TYPE > | inline |
| mlock() (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >) | ihipStreamCriticalBase_t< MUTEX_TYPE > | inline |
| unlock() (defined in LockedBase< MUTEX_TYPE >) | LockedBase< MUTEX_TYPE > | inline |
| ~ihipStreamCriticalBase_t() (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >) | ihipStreamCriticalBase_t< MUTEX_TYPE > | inline |
+ 1.8.6
+
+
+
diff --git a/projects/hip/docs/RuntimeAPI/html/classihipStreamCriticalBase__t.html b/projects/hip/docs/RuntimeAPI/html/classihipStreamCriticalBase__t.html
new file mode 100644
index 0000000000..96f9d656fc
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/classihipStreamCriticalBase__t.html
@@ -0,0 +1,157 @@
+
+
+
+
+
+
+|
+ HIP: Heterogenous-computing Interface for Portability
+
+ |
+
+
+ +Public Member Functions | |
|
+ihipStreamCriticalBase_t +< StreamMutex > * | mlock () |
Public Member Functions inherited from LockedBase< MUTEX_TYPE > | |
| +void | lock () |
| +void | unlock () |
+Public Attributes | |
| +ihipCommand_t | _last_command_type |
| +ihipSignal_t * | _last_copy_signal |
| +hc::completion_future | _last_kernel_future |
| +int | _signalCursor |
| +SIGSEQNUM | _oldest_live_sig_id |
| +std::deque< ihipSignal_t > | _signalPool |
| +SIGSEQNUM | _stream_sig_id |
Public Attributes inherited from LockedBase< MUTEX_TYPE > | |
| +MUTEX_TYPE | _mutex |
+ 1.8.6
+
+
+
diff --git a/projects/hip/docs/RuntimeAPI/html/classihipStreamCriticalBase__t.png b/projects/hip/docs/RuntimeAPI/html/classihipStreamCriticalBase__t.png
new file mode 100644
index 0000000000..4d8990f4ca
Binary files /dev/null and b/projects/hip/docs/RuntimeAPI/html/classihipStreamCriticalBase__t.png differ
diff --git a/projects/hip/docs/RuntimeAPI/html/classihipStream__t-members.html b/projects/hip/docs/RuntimeAPI/html/classihipStream__t-members.html
new file mode 100644
index 0000000000..3a51df77a0
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/classihipStream__t-members.html
@@ -0,0 +1,121 @@
+
+
+
+
+
+
+|
+ HIP: Heterogenous-computing Interface for Portability
+
+ |
+
This is the complete list of members for ihipStream_t, including all inherited members.
+| _av (defined in ihipStream_t) | ihipStream_t | |
| _flags (defined in ihipStream_t) | ihipStream_t | |
| _id (defined in ihipStream_t) | ihipStream_t | |
| allocSignal(LockedAccessor_StreamCrit_t &crit) (defined in ihipStream_t) | ihipStream_t | |
| copyAsync(void *dst, const void *src, size_t sizeBytes, unsigned kind) (defined in ihipStream_t) | ihipStream_t | |
| copySync(LockedAccessor_StreamCrit_t &crit, void *dst, const void *src, size_t sizeBytes, unsigned kind) (defined in ihipStream_t) | ihipStream_t | |
| getDevice() const (defined in ihipStream_t) | ihipStream_t | |
| ihipStream_t(unsigned device_index, hc::accelerator_view av, unsigned int flags) (defined in ihipStream_t) | ihipStream_t | |
| lastCopySeqId(LockedAccessor_StreamCrit_t &crit) (defined in ihipStream_t) | ihipStream_t | inline |
| lockclose_postKernelCommand(hc::completion_future &kernel_future) (defined in ihipStream_t) | ihipStream_t | |
| locked_copySync(void *dst, const void *src, size_t sizeBytes, unsigned kind) (defined in ihipStream_t) | ihipStream_t | |
| locked_lastCopySeqId() (defined in ihipStream_t) | ihipStream_t | inline |
| locked_reclaimSignals(SIGSEQNUM sigNum) (defined in ihipStream_t) | ihipStream_t | |
| locked_wait(bool assertQueueEmpty=false) (defined in ihipStream_t) | ihipStream_t | |
| lockopen_preKernelCommand() (defined in ihipStream_t) | ihipStream_t | |
| operator<< (defined in ihipStream_t) | ihipStream_t | friend |
| preCopyCommand(LockedAccessor_StreamCrit_t &crit, ihipSignal_t *lastCopy, hsa_signal_t *waitSignal, ihipCommand_t copyType) (defined in ihipStream_t) | ihipStream_t | |
| SeqNum_t typedef (defined in ihipStream_t) | ihipStream_t | |
| wait(LockedAccessor_StreamCrit_t &crit, bool assertQueueEmpty=false) (defined in ihipStream_t) | ihipStream_t | |
| ~ihipStream_t() (defined in ihipStream_t) | ihipStream_t |
+ 1.8.6
+
+
+
diff --git a/projects/hip/docs/RuntimeAPI/html/classihipStream__t.html b/projects/hip/docs/RuntimeAPI/html/classihipStream__t.html
new file mode 100644
index 0000000000..3c101e9bc0
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/classihipStream__t.html
@@ -0,0 +1,178 @@
+
+
+
+
+
+
+|
+ HIP: Heterogenous-computing Interface for Portability
+
+ |
+
+Public Types | |
| +typedef uint64_t | SeqNum_t |
+Public Member Functions | |
| + | ihipStream_t (unsigned device_index, hc::accelerator_view av, unsigned int flags) |
| +void | copySync (LockedAccessor_StreamCrit_t &crit, void *dst, const void *src, size_t sizeBytes, unsigned kind) |
| +void | locked_copySync (void *dst, const void *src, size_t sizeBytes, unsigned kind) |
| +void | copyAsync (void *dst, const void *src, size_t sizeBytes, unsigned kind) |
| +bool | lockopen_preKernelCommand () |
| +void | lockclose_postKernelCommand (hc::completion_future &kernel_future) |
| +int | preCopyCommand (LockedAccessor_StreamCrit_t &crit, ihipSignal_t *lastCopy, hsa_signal_t *waitSignal, ihipCommand_t copyType) |
| +void | locked_reclaimSignals (SIGSEQNUM sigNum) |
| +void | locked_wait (bool assertQueueEmpty=false) |
| +SIGSEQNUM | locked_lastCopySeqId () |
| +void | wait (LockedAccessor_StreamCrit_t &crit, bool assertQueueEmpty=false) |
| +SIGSEQNUM | lastCopySeqId (LockedAccessor_StreamCrit_t &crit) |
| +ihipSignal_t * | allocSignal (LockedAccessor_StreamCrit_t &crit) |
| +ihipDevice_t * | getDevice () const |
+Public Attributes | |
| +SeqNum_t | _id |
| +hc::accelerator_view | _av |
| +unsigned | _flags |
+Friends | |
| +std::ostream & | operator<< (std::ostream &os, const ihipStream_t &s) |
+ 1.8.6
+
+
+
diff --git a/projects/hip/docs/RuntimeAPI/html/dir_68267d1309a1af8e8297ef4c3efbcdba.html b/projects/hip/docs/RuntimeAPI/html/dir_68267d1309a1af8e8297ef4c3efbcdba.html
index 71b55290ce..8ea47d84d0 100644
--- a/projects/hip/docs/RuntimeAPI/html/dir_68267d1309a1af8e8297ef4c3efbcdba.html
+++ b/projects/hip/docs/RuntimeAPI/html/dir_68267d1309a1af8e8297ef4c3efbcdba.html
@@ -4,7 +4,7 @@
-Files | |||||||||||||||||||||||
| file | device_util.cpp | ||||||||||||||||||||||
| file | hip_device.cpp | ||||||||||||||||||||||
| file | hip_error.cpp | ||||||||||||||||||||||
| file | hip_event.cpp | ||||||||||||||||||||||
| file | hip_hcc.cpp | ||||||||||||||||||||||
| file | hip_hcc2.cpp | ||||||||||||||||||||||
| file | hip_memory.cpp | ||||||||||||||||||||||
| file | hip_peer.cpp | ||||||||||||||||||||||
| file | hip_stream.cpp | ||||||||||||||||||||||
| file | staging_buffer.cpp | ||||||||||||||||||||||
Files | |
| file | hcc_acc.h [code] |
| file | hip_hcc.h [code] |
| file | hip_runtime.h [code] |
| Contains definitions of APIs for HIP runtime. | |
| file | hip_texture.h [code] |
| HIP C++ Texture API for hcc compiler. | |
| file | hip_util.h [code] |
| file | hip_vector_types.h [code] |
| Defines the different newt vector types for HIP runtime. | |
Files | |
| file | hcc.h [code] |
| file | hip_common.h [code] |
| file | hip_runtime.h [code] |
| Contains definitions of APIs for HIP runtime | |
| Contains C function APIs for HIP runtime. This file does not use any HCC builtin or special language extensions (-hc mode) ; those functions in hip_runtime.h | |
| HIP C++ Texture API for hcc compiler | |
| Defines the different newt vector types for HIP runtime | |
| TODO-doc | |
| Contains definitions of APIs for HIP runtime | |
| Contains C function APIs for HIP runtime. This file does not use any HCC builtin or special language extensions (-hc mode) ; those functions in hip_runtime.h | |
| HIP C++ Texture API for hcc compiler | |
| Defines the different newt vector types for HIP runtime | |
| TODO-doc | |
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/functions.html b/projects/hip/docs/RuntimeAPI/html/functions.html
index e6a4e60528..2eabb218cc 100644
--- a/projects/hip/docs/RuntimeAPI/html/functions.html
+++ b/projects/hip/docs/RuntimeAPI/html/functions.html
@@ -70,7 +70,6 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
@@ -78,7 +77,6 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/functions_vars.html b/projects/hip/docs/RuntimeAPI/html/functions_vars.html
index a000c0d646..5dc919231f 100644
--- a/projects/hip/docs/RuntimeAPI/html/functions_vars.html
+++ b/projects/hip/docs/RuntimeAPI/html/functions_vars.html
@@ -70,7 +70,6 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
@@ -310,7 +309,7 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/globals.html b/projects/hip/docs/RuntimeAPI/html/globals.html
index bc41f5d7cc..1e1f48fee6 100644
--- a/projects/hip/docs/RuntimeAPI/html/globals.html
+++ b/projects/hip/docs/RuntimeAPI/html/globals.html
@@ -69,7 +69,6 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/globals_defs.html b/projects/hip/docs/RuntimeAPI/html/globals_defs.html
index 43666cc30a..c98e741616 100644
--- a/projects/hip/docs/RuntimeAPI/html/globals_defs.html
+++ b/projects/hip/docs/RuntimeAPI/html/globals_defs.html
@@ -69,7 +69,6 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/globals_enum.html b/projects/hip/docs/RuntimeAPI/html/globals_enum.html
index e8a736e97d..21ee1800ad 100644
--- a/projects/hip/docs/RuntimeAPI/html/globals_enum.html
+++ b/projects/hip/docs/RuntimeAPI/html/globals_enum.html
@@ -69,7 +69,6 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/globals_eval.html b/projects/hip/docs/RuntimeAPI/html/globals_eval.html
index d4c28a5457..8c8143077d 100644
--- a/projects/hip/docs/RuntimeAPI/html/globals_eval.html
+++ b/projects/hip/docs/RuntimeAPI/html/globals_eval.html
@@ -69,7 +69,6 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/globals_func.html b/projects/hip/docs/RuntimeAPI/html/globals_func.html
index a61e5f84a9..66b5ca15dd 100644
--- a/projects/hip/docs/RuntimeAPI/html/globals_func.html
+++ b/projects/hip/docs/RuntimeAPI/html/globals_func.html
@@ -69,7 +69,6 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/globals_type.html b/projects/hip/docs/RuntimeAPI/html/globals_type.html
index 0310e6ead0..7730e8d003 100644
--- a/projects/hip/docs/RuntimeAPI/html/globals_type.html
+++ b/projects/hip/docs/RuntimeAPI/html/globals_type.html
@@ -69,7 +69,6 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/group__API.html b/projects/hip/docs/RuntimeAPI/html/group__API.html
index f26e9091d5..167a738125 100644
--- a/projects/hip/docs/RuntimeAPI/html/group__API.html
+++ b/projects/hip/docs/RuntimeAPI/html/group__API.html
@@ -110,7 +110,7 @@ Modules
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/group__Device.html b/projects/hip/docs/RuntimeAPI/html/group__Device.html
index 3332a36137..c03607d6ed 100644
--- a/projects/hip/docs/RuntimeAPI/html/group__Device.html
+++ b/projects/hip/docs/RuntimeAPI/html/group__Device.html
@@ -120,6 +120,9 @@ Functions
Populates hipGetDeviceProperties with information for the specified device.
HCC always returns 0 for maxThreadsPerMultiProcessor
-HCC always returns 0 for regsPerBlock
-HCC always returns 0 for l2CacheSize
-HCC always returns 0 for maxThreadsPerMultiProcessor
+HCC always returns 0 for maxThreadsPerMultiProcessor
HCC always returns 0 for regsPerBlock
HCC always returns 0 for l2CacheSize
| hipError_t hipSetDeviceFlags | +( | +unsigned | +flags | ) | ++ |
Set Device flags.
+Note: Only hipDeviceScheduleAuto and hipDeviceMapHost are supported
+
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/group__Enumerations.html b/projects/hip/docs/RuntimeAPI/html/group__Enumerations.html
deleted file mode 100644
index 9813d08bc5..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/group__Enumerations.html
+++ /dev/null
@@ -1,173 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Typedefs | |
| -typedef enum hipError_t | hipError_t |
-Enumerations | |
| enum | hipError_t { - hipSuccess = 0, -hipErrorMemoryAllocation, -hipErrorMemoryFree, -hipErrorUnknownSymbol, - - hipErrorOutOfResources, -hipErrorInvalidValue, -hipErrorInvalidResourceHandle, -hipErrorInvalidDevice, - - hipErrorNoDevice, -hipErrorNotReady, -hipErrorUnknown, -hipErrorTbd - - } |
| enum hipError_t | -
| Enumerator | |
|---|---|
| hipSuccess |
- No error. - |
| hipErrorMemoryAllocation |
- Memory allocation error. - |
| hipErrorMemoryFree |
- Memory free error. - |
| hipErrorUnknownSymbol |
- Unknown symbol. - |
| hipErrorOutOfResources |
- Out of resources error. - |
| hipErrorInvalidValue |
- One or more of the paramters passed to the API call is NULL or not in an acceptable range. - |
| hipErrorInvalidResourceHandle |
- Resource handle (hipEvent_t or hipStream_t) invalid. - |
| hipErrorInvalidDevice |
- DeviceID must be in range 0...#compute-devices. - |
| hipErrorNoDevice |
- Call to cudaGetDeviceCount returned 0 devices. - |
| hipErrorNotReady |
- indicates that asynchronous operations enqueued earlier are not ready. This is not actually an error, but is used to distinguish from hipSuccess (which indicates completion). APIs that return this error include hipEventQuery and hipStreamQuery. - |
| hipErrorUnknown |
- Unknown error. - |
| hipErrorTbd |
- Marker that more error codes are needed. - |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/group__Error.html b/projects/hip/docs/RuntimeAPI/html/group__Error.html
index 1855472492..e877b2624f 100644
--- a/projects/hip/docs/RuntimeAPI/html/group__Error.html
+++ b/projects/hip/docs/RuntimeAPI/html/group__Error.html
@@ -197,7 +197,7 @@ Functions
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/group__Event.html b/projects/hip/docs/RuntimeAPI/html/group__Event.html
index 3a2ff62eb2..c9756da0e4 100644
--- a/projects/hip/docs/RuntimeAPI/html/group__Event.html
+++ b/projects/hip/docs/RuntimeAPI/html/group__Event.html
@@ -87,9 +87,11 @@ Functions
| hipError_t hipEventCreate | +( | +hipEvent_t * | +event | ) | ++ |
Create an event
+| [in,out] | event | Returns the newly created event. |
| hipStream_t | -stream = NULL |
+ stream |
| @@ -315,7 +340,7 @@ Functions | hipHostRegisterIoMemory 0x4 |
| Not supported. | |
| +#define | hipDeviceScheduleAuto 0x0 |
| +#define | hipDeviceScheduleSpin 0x1 |
| +#define | hipDeviceScheduleYield 0x2 |
| +#define | hipDeviceBlockingSync 0x4 |
| +#define | hipDeviceMapHost 0x8 |
| +#define | hipDeviceLmemResizeToMax 0x16 |
Typedefs | |
| typedef struct dim3 | dim3 |
| typedef enum hipMemcpyKind | hipMemcpyKind |
Enumerations | |||||||||||||||||||||||
| typedef enum hipMemcpyKind hipMemcpyKind | +
Memory copy types
+Unknown error.
Peer access was never enabled from the current device.
+Peer access was already enabled from the current device.
+HSA runtime memory call returned error. Typically not seen in production systems.
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/group__HCC-Specific.html b/projects/hip/docs/RuntimeAPI/html/group__HCC-Specific.html
deleted file mode 100644
index df8399d027..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/group__HCC-Specific.html
+++ /dev/null
@@ -1,96 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
The following calls are only supported when compiler HIP with HCC. To produce portable code, use of these calls must be guarded #ifdef checks:
-
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/group__HCC__Specific.html b/projects/hip/docs/RuntimeAPI/html/group__HCC__Specific.html
index 7096290cc1..5ea57f348f 100644
--- a/projects/hip/docs/RuntimeAPI/html/group__HCC__Specific.html
+++ b/projects/hip/docs/RuntimeAPI/html/group__HCC__Specific.html
@@ -75,92 +75,20 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
-Functions | |
| hipError_t | hipHccGetAccelerator (int deviceId, hc::accelerator *acc) |
| Return hc::accelerator associated with the specified deviceId. More... | |
| hipError_t | hipHccGetAcceleratorView (hipStream_t stream, hc::accelerator_view **av) |
| Return hc::accelerator_view associated with the specified stream. More... | |
The following calls are only supported when compiler HIP with HCC. To produce portable code, use of these calls must be guarded #ifdef checks:
| hipError_t hipHccGetAccelerator | -( | -int | -deviceId, | -
| - | - | hc::accelerator * | -acc | -
| - | ) | -- |
Return hc::accelerator associated with the specified deviceId.
-| hipError_t hipHccGetAcceleratorView | -( | -hipStream_t | -stream, | -
| - | - | hc::accelerator_view ** | -av | -
| - | ) | -- |
Return hc::accelerator_view associated with the specified stream.
-
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/group__HIP-ENV.html b/projects/hip/docs/RuntimeAPI/html/group__HIP-ENV.html
index 50e713459f..dacfb02ec3 100644
--- a/projects/hip/docs/RuntimeAPI/html/group__HIP-ENV.html
+++ b/projects/hip/docs/RuntimeAPI/html/group__HIP-ENV.html
@@ -75,33 +75,14 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
-Variables | |
| -int | HIP_PRINT_ENV |
| Print all HIP-related environment variables. | |
| -int | HIP_TRACE_API |
| Trace HIP APIs. | |
| -int | HIP_LAUNCH_BLOCKING |
| Make all HIP APIs host-synchronous. | |
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/group__Memory.html b/projects/hip/docs/RuntimeAPI/html/group__Memory.html
index 1e2f0e1093..85d0a0390f 100644
--- a/projects/hip/docs/RuntimeAPI/html/group__Memory.html
+++ b/projects/hip/docs/RuntimeAPI/html/group__Memory.html
@@ -126,15 +126,15 @@ Functions
sizeBytes bytes from the memory area pointed to by src to the memory area pointed to by offset bytes from the start of symbol symbol. More...| [out] | dst | Pointer to device memory | |||||||||||||||||||||
Functions | |
| hipError_t | hipDeviceCanAccessPeer (int *canAccessPeer, int device, int peerDevice) |
| Determine if a device can access a peer's memory. More... | |
| hipError_t | hipDeviceDisablePeerAccess (int peerDevice) |
| Disables registering memory on peerDevice for direct access from the current device. More... | |
| hipError_t | hipDeviceEnablePeerAccess (int peerDevice, unsigned int flags) |
| Enables registering memory on peerDevice for direct access from the current device. More... | |
| hipError_t | hipMemcpyPeer (void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes) |
| Copies memory from one device to memory on another device. More... | |
| hipError_t | hipMemcpyPeerAsync (void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream=0) |
| Copies memory from one device to memory on another device. More... | |
| hipError_t | hipDeviceCanAccessPeer (int *canAccessPeer, int deviceId, int peerDeviceId) |
| Determine if a device can access a peer's memory. More... | |
| hipError_t | hipDeviceEnablePeerAccess (int peerDeviceId, unsigned int flags) |
| Enable direct access from current device's virtual address space to memory allocations physically located on a peer device. More... | |
| hipError_t | hipDeviceDisablePeerAccess (int peerDeviceId) |
| Disable direct access from current device's virtual address space to memory allocations physically located on a peer device. More... | |
| hipError_t | hipMemcpyPeer (void *dst, int dstDeviceId, const void *src, int srcDeviceId, size_t sizeBytes) |
| Copies memory from one device to memory on another device. More... | |
| hipError_t | hipMemcpyPeerAsync (void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream) |
| Copies memory from one device to memory on another device. More... | |
| int | -device, | +deviceId, | ||
| int | -peerDevice | +peerDeviceId | ||
| @@ -142,11 +142,15 @@ Functions |
Returns "0" in canAccessPeer if deviceId == peerDeviceId, and both are valid devices : a device is not a peer of itself.
| hipError_t hipDeviceDisablePeerAccess | ( | int | -peerDevice | ) | +peerDeviceId | ) |
Disables registering memory on peerDevice for direct access from the current device.
-If there are any allocations on peerDevice which were registered in the current device using hipPeerRegister() then these allocations will be automatically unregistered. Returns hipErrorPeerAccessNotEnabled if direct access to memory on peerDevice has not yet been enabled from the current device.
+Disable direct access from current device's virtual address space to memory allocations physically located on a peer device.
+Returns hipErrorPeerAccessNotEnabled if direct access to memory on peerDevice has not yet been enabled from the current device.
| [in] | peerDevice | TODO:cudaErrorPeerAccessNotEnabled and cudaErrorInvalidDevice error not supported in HIP, return hipErrorUnknown Returns hipSuccess, hipErrorUnknown |
| [in] | peerDeviceId | Returns hipSuccess, hipErrorPeerAccessNotEnabled |
| hipError_t hipDeviceEnablePeerAccess | ( | int | -peerDevice, | +peerDeviceId, |
| @@ -196,19 +199,20 @@ Functions |
Enables registering memory on peerDevice for direct access from the current device.
+Enable direct access from current device's virtual address space to memory allocations physically located on a peer device.
+Memory which already allocated on peer device will be mapped into the address space of the current device. In addition, all future memory allocations on peerDeviceId will be mapped into the address space of the current device when the memory is allocated. The peer memory remains accessible from the current device until a call to hipDeviceDisablePeerAccess or hipDeviceReset.
| [in] | peerDevice | |
| [in] | flags | TODO:cudaErrorInvalidDevice error not supported in HIP, return hipErrorUnknown Returns hipSuccess, hipErrorInvalidDevice, hipErrorInvalidValue, hipErrorUnknown |
| [in] | peerDeviceId | |
| [in] | flags | Returns hipSuccess, hipErrorInvalidDevice, hipErrorInvalidValue, |
| int | -dstDevice, | +dstDeviceId, | |||||||||||||||||||||
| @@ -234,7 +238,7 @@ Functions | int | -srcDevice, | +srcDeviceId, | ||||||||||||||||||||
| @@ -254,9 +258,9 @@ Functions | |||||||||||||||||||||||
| [out] | dst | - Destination device pointer. |
| [in] | dstDevice | - Destination device |
| [in] | dstDeviceId | - Destination device |
| [in] | src | - Source device pointer |
| [in] | srcDevice | - Source device |
| [in] | srcDeviceId | - Source device |
| [in] | sizeBytes | - Size of memory copy in bytes |
| hipError_t | hipStreamCreateWithFlags (hipStream_t *stream, unsigned int flags) | ||||
| Create an asynchronous stream. More... | |||||
| hipError_t | hipStreamCreate (hipStream_t *stream) | ||||
| Create an asynchronous stream. More... | |||||
| hipError_t | hipStreamWaitEvent (hipStream_t stream, hipEvent_t event, unsigned int flags) | ||||
| Make the specified compute stream wait for an event. More... | |||||
| hipError_t hipStreamCreate | +( | +hipStream_t * | +stream | ) | ++ |
Create an asynchronous stream.
+| [in,out] | stream | Valid pointer to hipStream_t. This function writes the memory with the newly created stream. |
Create a new asynchronous stream. stream returns an opaque handle that can be used to reference the newly created stream in subsequent hipStream* commands. The stream is allocated on the heap and will remain allocated even if the handle goes out-of-scope. To release the memory used by the stream, applicaiton must call hipStreamDestroy.
This function inserts a wait operation into the specified stream. All future work submitted to stream will wait until event reports completion before beginning execution. This function is host-asynchronous and the function may return before the wait has completed.
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/group__Texture.html b/projects/hip/docs/RuntimeAPI/html/group__Texture.html
index 158b63a9ad..0778a5319c 100644
--- a/projects/hip/docs/RuntimeAPI/html/group__Texture.html
+++ b/projects/hip/docs/RuntimeAPI/html/group__Texture.html
@@ -90,15 +90,15 @@ template<class T >
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/group__Version.html b/projects/hip/docs/RuntimeAPI/html/group__Version.html
index e1639f5f88..86b02f28a9 100644
--- a/projects/hip/docs/RuntimeAPI/html/group__Version.html
+++ b/projects/hip/docs/RuntimeAPI/html/group__Version.html
@@ -114,7 +114,7 @@ Functions
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/globals_vars.html b/projects/hip/docs/RuntimeAPI/html/hcc_8h_source.html
similarity index 73%
rename from projects/hip/docs/RuntimeAPI/html/globals_vars.html
rename to projects/hip/docs/RuntimeAPI/html/hcc_8h_source.html
index 8bc92d3188..5b2a7aa240 100644
--- a/projects/hip/docs/RuntimeAPI/html/globals_vars.html
+++ b/projects/hip/docs/RuntimeAPI/html/hcc_8h_source.html
@@ -4,7 +4,7 @@
-
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/hcc__acc_8h_source.html b/projects/hip/docs/RuntimeAPI/html/hcc__acc_8h_source.html
new file mode 100644
index 0000000000..5ae15a291a
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/hcc__acc_8h_source.html
@@ -0,0 +1,118 @@
+
+
+
+
+
+
+|
+ HIP: Heterogenous-computing Interface for Portability
+
+ |
+
+ 1.8.6
+
+
+
diff --git a/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime_8h.html b/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime_8h.html
index 3b02f3756a..950a3befde 100644
--- a/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime_8h.html
+++ b/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime_8h.html
@@ -4,7 +4,7 @@
-Contains definitions of APIs for HIP runtime. More...
-#include <cstring>#include <cmath>#include <string.h>#include <string.h>#include <stddef.h>#include <hip_runtime_api.h>#include <hc.hpp>#include <grid_launch.h>#include <hcc_detail/hip_texture.h>#include <hcc_detail/host_defines.h>#include <hc_math.hpp>Go to the source code of this file.
| #define | HIP_KERNEL_NAME(...) __VA_ARGS__ |
| #define | KERNELBEGIN |
| #define | KERNELEND |
Functions | c
|
__device__ clock_t | clock () | |
-__device__ int | atomicAdd (int *address, int val) | |
-__device__ unsigned int | atomicAdd (unsigned int *address, unsigned int val) | |
-__device__ unsigned long long int | atomicAdd (unsigned long long int *address, unsigned long long int val) | |
-__device__ float | atomicAdd (float *address, float val) | |
-__device__ int | atomicSub (int *address, int val) | |
-__device__ unsigned int | atomicSub (unsigned int *address, unsigned int val) | |
-__device__ int | atomicExch (int *address, int val) | |
-__device__ unsigned int | atomicExch (unsigned int *address, unsigned int val) | |
-__device__ unsigned long long int | atomicExch (unsigned long long int *address, unsigned long long int val) | |
-__device__ float | atomicExch (float *address, float val) | |
-__device__ int | atomicMin (int *address, int val) | |
-__device__ unsigned int | atomicMin (unsigned int *address, unsigned int val) | |
-__device__ unsigned long long int | atomicMin (unsigned long long int *address, unsigned long long int val) | |
-__device__ int | atomicMax (int *address, int val) | |
-__device__ unsigned int | atomicMax (unsigned int *address, unsigned int val) | |
-__device__ unsigned long long int | atomicMax (unsigned long long int *address, unsigned long long int val) | |
-__device__ int | atomicCAS (int *address, int compare, int val) | |
-__device__ unsigned int | atomicCAS (unsigned int *address, unsigned int compare, unsigned int val) | |
-__device__ unsigned long long int | atomicCAS (unsigned long long int *address, unsigned long long int compare, unsigned long long int val) | |
-__device__ int | atomicAnd (int *address, int val) | |
-__device__ unsigned int | atomicAnd (unsigned int *address, unsigned int val) | |
-__device__ unsigned long long int | atomicAnd (unsigned long long int *address, unsigned long long int val) | |
-__device__ int | atomicOr (int *address, int val) | |
-__device__ unsigned int | atomicOr (unsigned int *address, unsigned int val) | |
-__device__ unsigned long long int | atomicOr (unsigned long long int *address, unsigned long long int val) | |
-__device__ int | atomicXor (int *address, int val) | |
-__device__ unsigned int | atomicXor (unsigned int *address, unsigned int val) | |
-__device__ unsigned long long int | atomicXor (unsigned long long int *address, unsigned long long int val) | |
-__device__ unsigned int | __popc (unsigned int input) | |
-__device__ unsigned int | __popcll (unsigned long long int input) | |
-__device__ unsigned int | __clz (unsigned int input) | |
-__device__ unsigned int | __clzll (unsigned long long int input) | |
-__device__ unsigned int | __clz (int input) | |
-__device__ unsigned int | __clzll (long long int input) | |
-__device__ unsigned int | __ffs (unsigned int input) | |
-__device__ unsigned int | __ffsll (unsigned long long int input) | |
-__device__ unsigned int | __ffs (int input) | |
-__device__ unsigned int | __ffsll (long long int input) | |
-__device__ unsigned int | __brev (unsigned int input) | |
-__device__ unsigned long long int | __brevll (unsigned long long int input) | |
-__device__ int | __all (int input) | |
-__device__ int | __any (int input) | |
-__device__ unsigned long long int | __ballot (int input) | |
-__device__ int | __shfl (int input, int lane, int width=warpSize) | |
-__device__ int | __shfl_up (int input, unsigned int lane_delta, int width=warpSize) | |
-__device__ int | __shfl_down (int input, unsigned int lane_delta, int width=warpSize) | |
-__device__ int | __shfl_xor (int input, int lane_mask, int width=warpSize) | |
-__device__ float | __shfl (float input, int lane, int width=warpSize) | |
-__device__ float | __shfl_up (float input, unsigned int lane_delta, int width=warpSize) | |
-__device__ float | __shfl_down (float input, unsigned int lane_delta, int width=warpSize) | |
-__device__ float | __shfl_xor (float input, int lane_mask, int width=warpSize) | |
-int | min (int arg1, int arg2) __attribute((hc | |
-int | max (int arg1, int arg2) __attribute((hc | |
-__device__ float | __cosf (float x) | |
-__device__ float | __expf (float x) | |
-__device__ float | __frsqrt_rn (float x) | |
-__device__ float | __fsqrt_rd (float x) | |
-__device__ float | __fsqrt_rn (float x) | |
-__device__ float | __fsqrt_ru (float x) | |
-__device__ float | __fsqrt_rz (float x) | |
-__device__ float | __log10f (float x) | |
-__device__ float | __log2f (float x) | |
-__device__ float | __logf (float x) | |
-__device__ float | __powf (float base, float exponent) | |
-__device__ void | __sincosf (float x, float *s, float *c) | |
-__device__ float | __sinf (float x) | |
-__device__ float | __tanf (float x) | |
-__device__ float | __dsqrt_rd (double x) | |
-__device__ float | __dsqrt_rn (double x) | |
-__device__ float | __dsqrt_ru (double x) | |
-__device__ float | __dsqrt_rz (double x) | | |
Variables | |
| +int | HIP_TRACE_API |
| -const int | warpSize = 64 | warpSize |
| int | cpu |
| -int | HIP_PRINT_ENV |
| Print all HIP-related environment variables. | |
| -int | HIP_TRACE_API |
| Trace HIP APIs. | |
| -int | HIP_LAUNCH_BLOCKING |
| Make all HIP APIs host-synchronous. | |
Contains definitions of APIs for HIP runtime.
@@ -425,73 +192,12 @@ intKernel launching
- - - -| #define KERNELBEGIN | -
| #define KERNELEND | -
| int cpu | -
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime_8h_source.html b/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime_8h_source.html
index 4a9b0d1073..1ebb8604cd 100644
--- a/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime_8h_source.html
+++ b/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime_8h_source.html
@@ -4,7 +4,7 @@
-
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime__api_8h.html b/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime__api_8h.html
index eb2140c4e5..a8fc9f8a60 100644
--- a/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime__api_8h.html
+++ b/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime__api_8h.html
@@ -4,7 +4,7 @@
-#include <stdint.h>#include <stddef.h>#include <hcc_detail/host_defines.h>#include <hc.hpp>#include <hip_runtime_api.h>Go to the source code of this file.
Classes | |
| struct | dim3 |
| struct | hipEvent_t |
| struct | dim3 |
Macros | hipHostRegisterIoMemory 0x4 |
| Not supported. | |
| +#define | hipDeviceScheduleAuto 0x0 |
| +#define | hipDeviceScheduleSpin 0x1 |
| +#define | hipDeviceScheduleYield 0x2 |
| +#define | hipDeviceBlockingSync 0x4 |
| +#define | hipDeviceMapHost 0x8 |
| +#define | hipDeviceLmemResizeToMax 0x16 |
Typedefs | |
| +typedef struct ihipStream_t * | hipStream_t |
| +typedef struct hipEvent_t | hipEvent_t |
| typedef enum hipFuncCache | hipFuncCache |
| typedef enum hipSharedMemConfig | hipSharedMemConfig |
| typedef struct dim3 | dim3 |
| -typedef class ihipStream_t * | hipStream_t |
| -typedef struct hipEvent_t | hipEvent_t |
| typedef enum hipMemcpyKind | hipMemcpyKind |
Enumerations | |
| hipError_t | hipDeviceSetSharedMemConfig (hipSharedMemConfig config) |
| Set Shared memory bank configuration. More... | |
| hipError_t | hipSetDeviceFlags (unsigned flags) |
| Set Device flags. More... | |
| hipError_t | hipGetLastError (void) |
| Return last error returned by any HIP runtime API call and resets the stored error code to hipSuccess. More... | |
| hipError_t | hipStreamCreateWithFlags (hipStream_t *stream, unsigned int flags) |
| Create an asynchronous stream. More... | |
| hipError_t | hipStreamCreate (hipStream_t *stream) |
| Create an asynchronous stream. More... | |
| hipError_t | hipStreamWaitEvent (hipStream_t stream, hipEvent_t event, unsigned int flags) |
| Make the specified compute stream wait for an event. More... | |
| hipError_t | hipEventCreateWithFlags (hipEvent_t *event, unsigned flags) |
| Create an event with the specified flags. More... | |
| hipError_t | hipEventRecord (hipEvent_t event, hipStream_t stream=NULL) |
| Record an event in the specified stream. More... | |
| hipError_t | hipEventCreate (hipEvent_t *event) |
| hipError_t | hipEventRecord (hipEvent_t event, hipStream_t stream) |
| Record an event in the specified stream. More... | |
| hipError_t | hipEventDestroy (hipEvent_t event) |
| Destroy the specified event. More... | |
| hipError_t | hipMemcpyToSymbol (const char *symbolName, const void *src, size_t sizeBytes, size_t offset, hipMemcpyKind kind) |
Copies sizeBytes bytes from the memory area pointed to by src to the memory area pointed to by offset bytes from the start of symbol symbol. More... | |
| hipError_t | hipMemcpyAsync (void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind, hipStream_t stream=0) |
| Copy data from src to dst asynchronously. More... | |
| hipError_t | hipMemcpyAsync (void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind, hipStream_t stream) |
| Copy data from src to dst asynchronously. More... | |
| hipError_t | hipMemset (void *dst, int value, size_t sizeBytes) |
| Copy data from src to dst asynchronously. More... | |
| hipError_t | hipMemsetAsync (void *dst, int value, size_t sizeBytes, hipStream_t=0) |
| Fills the first sizeBytes bytes of the memory area pointed to by dev with the constant byte value value. More... | |
| hipError_t | hipMemsetAsync (void *dst, int value, size_t sizeBytes, hipStream_t stream) |
| Fills the first sizeBytes bytes of the memory area pointed to by dev with the constant byte value value. More... | |
| hipError_t | hipMemGetInfo (size_t *free, size_t *total) |
| Query memory info. Return snapshot of free memory, and total allocatable memory on the device. More... | |
| hipError_t | hipDeviceCanAccessPeer (int *canAccessPeer, int device, int peerDevice) |
| Determine if a device can access a peer's memory. More... | |
| hipError_t | hipDeviceDisablePeerAccess (int peerDevice) |
| Disables registering memory on peerDevice for direct access from the current device. More... | |
| hipError_t | hipDeviceEnablePeerAccess (int peerDevice, unsigned int flags) |
| Enables registering memory on peerDevice for direct access from the current device. More... | |
| hipError_t | hipMemcpyPeer (void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes) |
| Copies memory from one device to memory on another device. More... | |
| hipError_t | hipMemcpyPeerAsync (void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream=0) |
| Copies memory from one device to memory on another device. More... | |
| hipError_t | hipDeviceCanAccessPeer (int *canAccessPeer, int deviceId, int peerDeviceId) |
| Determine if a device can access a peer's memory. More... | |
| hipError_t | hipDeviceEnablePeerAccess (int peerDeviceId, unsigned int flags) |
| Enable direct access from current device's virtual address space to memory allocations physically located on a peer device. More... | |
| hipError_t | hipDeviceDisablePeerAccess (int peerDeviceId) |
| Disable direct access from current device's virtual address space to memory allocations physically located on a peer device. More... | |
| hipError_t | hipMemcpyPeer (void *dst, int dstDeviceId, const void *src, int srcDeviceId, size_t sizeBytes) |
| Copies memory from one device to memory on another device. More... | |
| hipError_t | hipMemcpyPeerAsync (void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream) |
| Copies memory from one device to memory on another device. More... | |
| hipError_t | hipDriverGetVersion (int *driverVersion) |
| Returns the approximate HIP driver version. More... | |
| hipError_t | hipHccGetAccelerator (int deviceId, hc::accelerator *acc) |
| Return hc::accelerator associated with the specified deviceId. More... | |
| hipError_t | hipHccGetAcceleratorView (hipStream_t stream, hc::accelerator_view **av) |
| Return hc::accelerator_view associated with the specified stream. More... | |
Contains C function APIs for HIP runtime. This file does not use any HCC builtin or special language extensions (-hc mode) ; those functions in hip_runtime.h.
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime__api_8h_source.html b/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime__api_8h_source.html
index b194fa5b33..51e0670d7f 100644
--- a/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime__api_8h_source.html
+++ b/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime__api_8h_source.html
@@ -4,7 +4,7 @@
-
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__vector__types_8h.html b/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__vector__types_8h.html
index e4dc64a7f8..ebed2f5949 100644
--- a/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__vector__types_8h.html
+++ b/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__vector__types_8h.html
@@ -4,7 +4,7 @@
-Defines the different newt vector types for HIP runtime. More...
-#include <hc_short_vector.hpp>Go to the source code of this file.
@@ -444,7 +443,7 @@ Functions | |||||||||||||||||||||||
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/hip__common_8h_source.html b/projects/hip/docs/RuntimeAPI/html/hip__common_8h_source.html
index 55d079f9f9..d0c7252e3a 100644
--- a/projects/hip/docs/RuntimeAPI/html/hip__common_8h_source.html
+++ b/projects/hip/docs/RuntimeAPI/html/hip__common_8h_source.html
@@ -4,7 +4,7 @@
-
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/hip__hcc_8cpp.html b/projects/hip/docs/RuntimeAPI/html/hip__hcc_8cpp.html
index f2cf85359c..e009208110 100644
--- a/projects/hip/docs/RuntimeAPI/html/hip__hcc_8cpp.html
+++ b/projects/hip/docs/RuntimeAPI/html/hip__hcc_8cpp.html
@@ -4,7 +4,7 @@
-#include <hc.hpp>#include <hc_am.hpp>#include "hip_runtime.h"#include "hcc_detail/hip_hcc.h"#include "hsa_ext_amd.h"#include "hcc_detail/staging_buffer.h"#include "hcc_detail/trace_helper.h"#include "staging_buffer.cpp"-Classes | |
| class | ihipException |
| struct | ihipSignal_t |
| class | FakeMutex |
| class | ihipStream_t |
| struct | ihipEvent_t |
| struct | ihipDevice_t |
Macros | |
| #define | HIP_HCC |
| -#define | USE_AV_COPY 0 |
| -#define | INLINE static inline |
| -#define | KNRM "\x1B[0m" |
| -#define | KRED "\x1B[31m" |
| -#define | KGRN "\x1B[32m" |
| -#define | KYEL "\x1B[33m" |
| -#define | KBLU "\x1B[34m" |
| -#define | KMAG "\x1B[35m" |
| -#define | KCYN "\x1B[36m" |
| -#define | KWHT "\x1B[37m" |
| -#define | API_COLOR KGRN |
| -#define | HIP_HCC |
| -#define | STREAM_THREAD_SAFE 1 |
| -#define | FORCE_SAMEDIR_COPY_DEP 1 |
| -#define | COMPILE_HIP_DB 1 |
| -#define | COMPILE_HIP_TRACE_API 0x3 |
| -#define | COMPILE_TRACE_MARKER 0 |
| -#define | ONE_OBJECT_FILE 1 |
| -#define | SCOPED_MARKER(markerName, group, userString) |
| #define | API_TRACE(...) |
| #define | HIP_INIT_API(...) |
| -#define | DB_API 0 /* 0x01 - shortcut to enable HIP_TRACE_API on single switch */ |
| -#define | DB_SYNC 1 /* 0x02 - trace synchronization pieces */ |
| -#define | DB_MEM 2 /* 0x04 - trace memory allocation / deallocation */ |
| -#define | DB_COPY1 3 /* 0x08 - trace memory copy commands. . */ |
| -#define | DB_SIGNAL 4 /* 0x10 - trace signal pool commands */ |
| -#define | DB_COPY2 5 /* 0x20 - trace memory copy commands. Detailed. */ |
| #define | tprintf(trace_level,...) |
| #define | DeviceErrorCheck(x) if (x != HSA_STATUS_SUCCESS) { return hipErrorInvalidDevice; } |
| #define | ErrorCheck(x) error_check(x, __LINE__, __FILE__) |
| #define | ihipLogStatus(_hip_status) |
| #define | READ_ENV_I(_build, _ENV_VAR, _ENV_VAR2, _description) |
-Typedefs | |
| -typedef uint64_t | SIGSEQNUM |
| -typedef std::mutex | StreamMutex |
-Enumerations | |
| enum | ihipCommand_t { - ihipCommandCopyH2H, -ihipCommandCopyH2D, -ihipCommandCopyD2H, -ihipCommandCopyD2D, - - ihipCommandKernel, -ihipCommandCopyH2H, -ihipCommandCopyH2D, -ihipCommandCopyD2H, - - ihipCommandCopyD2D, -ihipCommandKernel - - } |
| enum | hipEventStatus_t { - hipEventStatusUnitialized = 0, -hipEventStatusCreated = 1, -hipEventStatusRecording = 2, -hipEventStatusRecorded = 3, - - hipEventStatusUnitialized = 0, -hipEventStatusCreated = 1, -hipEventStatusRecording = 2, -hipEventStatusRecorded = 3 - - } |
Functions | |
| + | |
| const char * | ihipErrorString (hipError_t hip_error) |
| -INLINE bool | ihipIsValidDevice (unsigned deviceIndex) |
| +bool | ihipIsValidDevice (unsigned deviceIndex) |
| void | error_check (hsa_status_t hsa_error_code, int line_num, std::string str) |
| ihipReadEnv_I (in | |
| void | ihipInit () |
| -INLINE ihipDevice_t * | ihipGetTlsDefaultDevice () |
| -INLINE ihipDevice_t * | ihipGetDevice (int deviceId) |
| +ihipDevice_t * | ihipGetTlsDefaultDevice () |
| +ihipDevice_t * | ihipGetDevice (int deviceId) |
| hipStream_t | ihipSyncAndResolveStream (hipStream_t stream) |
ihipPreLaunchK
|
void | ihipPostLaunchKernel (hipStream_t stream, hc::completion_future &kernelFuture) | | hipError_t | hipGetDevice (int *device) | | Return the default device id for the calling host thread. More... | | hipError_t | hipGetDeviceCount (int *count) | | Return number of compute-capable devices. More... | | hipError_t | hipDeviceSetCacheConfig (hipFuncCache cacheConfig) | | Set L1/Shared cache partition. More... | | hipError_t | hipDeviceGetCacheConfig (hipFuncCache *cacheConfig) | | Set Cache configuration for a specific function. More... | | hipError_t | hipFuncSetCacheConfig (hipFuncCache cacheConfig) | | Set Cache configuration for a specific function. More... | | hipError_t | hipDeviceSetSharedMemConfig (hipSharedMemConfig config) | | Set Shared memory bank configuration. More... | | hipError_t | hipDeviceGetSharedMemConfig (hipSharedMemConfig *pConfig) | | Get Shared memory bank configuration. More... | | hipError_t | hipSetDevice (int device) | | Set default device to be used for subsequent hip API calls from this thread. More... | | hipError_t | hipDeviceSynchronize (void) | | Blocks until the default device has completed all preceding requested tasks. More... | | hipError_t | hipDeviceReset (void) | | Destroy all resources and reset all state on the default device in the current process. More... | | hipError_t | hipDeviceGetAttribute (int *pi, hipDeviceAttribute_t attr, int device) | | Query device attribute. More... | | hipError_t | hipGetDeviceProperties (hipDeviceProp_t *props, int device) | | Returns device properties. More... | | hipError_t | hipGetLastError () | | Return last error returned by any HIP runtime API call and resets the stored error code to hipSuccess. More... | |
-hipError_t | hipPeakAtLastError () | | const char * | hipGetErrorName (hipError_t hip_error) | | Return name of the specified error code in text form. More... | | const char * | hipGetErrorString (hipError_t hip_error) | | Return handy text string message to explain the error which occurred. More... | | hipError_t | hipStreamCreateWithFlags (hipStream_t *stream, unsigned int flags) | | Create an asynchronous stream. More... | | hipError_t | hipStreamWaitEvent (hipStream_t stream, hipEvent_t event, unsigned int flags) | | Make the specified compute stream wait for an event. More... | | hipError_t | hipStreamSynchronize (hipStream_t stream) | | Wait for all commands in stream to complete. More... | | hipError_t | hipStreamDestroy (hipStream_t stream) | | Destroys the specified stream. More... | | hipError_t | hipStreamGetFlags (hipStream_t stream, unsigned int *flags) | | Return flags associated with this stream. More... | | hipError_t | hipEventCreateWithFlags (hipEvent_t *event, unsigned flags) | | Create an event with the specified flags. More... | | hipError_t | hipEventRecord (hipEvent_t event, hipStream_t stream) | | Record an event in the specified stream. More... | | hipError_t | hipEventDestroy (hipEvent_t event) | | Destroy the specified event. More... | | hipError_t | hipEventSynchronize (hipEvent_t event) | | : Wait for an event to complete. More... | |
void | ihipSetTs (hipEvent_t e) | | hipError_t | hipEventElapsedTime (float *ms, hipEvent_t start, hipEvent_t stop) | | Return the elapsed time between two events. More... | | hipError_t | hipEventQuery (hipEvent_t event) | | Query event status. More... | | hipError_t | hipPointerGetAttributes (hipPointerAttribute_t *attributes, void *ptr) | | Return attributes for the specified pointer. More... | | hipError_t | hipHostGetDevicePointer (void **devicePointer, void *hostPointer, unsigned flags) | |
-template<typename T > | hc::completion_future | ihipMemcpyKernel (hipStream_t stream, T *c, const T *a, size_t sizeBytes) | |
-template<typename T > | hc::completion_future | ihipMemsetKernel (hipStream_t stream, T *ptr, T val, size_t sizeBytes) | | hipError_t | hipMalloc (void **ptr, size_t sizeBytes) | | Allocate memory on the default accelerator. More... | | hipError_t | hipMallocHost (void **ptr, size_t sizeBytes) | | Allocate pinned host memory. More... | | hipError_t | hipHostMalloc (void **ptr, size_t sizeBytes, unsigned int flags) | | Allocate device accessible page locked host memory. More... | |
-hipError_t | hipHostAlloc (void **ptr, size_t sizeBytes, unsigned int flags) | | hipError_t | hipHostGetFlags (unsigned int *flagsPtr, void *hostPtr) | | Get flags associated with host pointer. More... | | hipError_t | hipHostRegister (void *hostPtr, size_t sizeBytes, unsigned int flags) | | Register host memory so it can be accessed from the current device. More... | | hipError_t | hipHostUnregister (void *hostPtr) | | Un-register host pointer. More... | | hipError_t | hipMemcpyToSymbol (const char *symbolName, const void *src, size_t count, size_t offset, hipMemcpyKind kind) | | Copies | sizeBytes bytes from the memory area pointed to by src to the memory area pointed to by offset bytes from the start of symbol symbol. More... | hipError_t | hipMemcpy (void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind) | | Copy data from src to dst. More... | | hipError_t | hipMemcpyAsync (void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind, hipStream_t stream) | | Copy data from src to dst asynchronously. More... | | hipError_t | hipMemsetAsync (void *dst, int value, size_t sizeBytes, hipStream_t stream) | | Fills the first sizeBytes bytes of the memory area pointed to by dev with the constant byte value value. More... | | hipError_t | hipMemset (void *dst, int value, size_t sizeBytes) | | Copy data from src to dst asynchronously. More... | | hipError_t | hipMemGetInfo (size_t *free, size_t *total) | | Query memory info. Return snapshot of free memory, and total allocatable memory on the device. More... | | hipError_t | hipFree (void *ptr) | | Free memory allocated by the hcc hip memory allocation API. This API performs an implicit hipDeviceSynchronize() call. More... | | hipError_t | hipHostFree (void *ptr) | | Free memory allocated by the hcc hip host memory allocation API. More... | | hipError_t | hipFreeHost (void *ptr) | | Free memory allocated by the hcc hip host memory allocation API. More... | | hipError_t | hipDeviceCanAccessPeer (int *canAccessPeer, int device, int peerDevice) | | Determine if a device can access a peer's memory. More... | | hipError_t | hipDeviceDisablePeerAccess (int peerDevice) | | Disables registering memory on peerDevice for direct access from the current device. More... | | hipError_t | hipDeviceEnablePeerAccess (int peerDevice, unsigned int flags) | | Enables registering memory on peerDevice for direct access from the current device. More... | | hipError_t | hipMemcpyPeer (void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes) | | Copies memory from one device to memory on another device. More... | | hipError_t | hipMemcpyPeerAsync (void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream) | | Copies memory from one device to memory on another device. More... | | hipError_t | hipDriverGetVersion (int *driverVersion) | | Returns the approximate HIP driver version. More... | | hipError_t | hipHccGetAccelerator (int deviceId, hc::accelerator *acc) | | Return hc::accelerator associated with the specified deviceId. More... | | hipError_t | hipHccGetAcceleratorView (hipStream_t stream, hc::accelerator_view **av) | | Return hc::accelerator_view associated with the specified stream. More... | | hipError_t | hipHccGetAccelerator (int deviceId, hc::accelerator *acc) | | hipError_t | hipHccGetAcceleratorView (hipStream_t stream, hc::accelerator_view **av) | | |
Variables | ||||||
| -int | HIP_LAUNCH_BLOCKING = 0 | |||||
| Make all HIP APIs host-synchronous. | ||||||
| -int | HIP_PRINT_ENV = 0 | |||||
| Print all HIP-related environment variables. | ||||||
| -int | HIP_TRACE_API = 0 | |||||
| Trace HIP APIs. | ||||||
| +const int | release = 1 | |||||
| +int | HIP_LAUNCH_BLOCKING = 0 | |||||
| +int | HIP_PRINT_ENV = 0 | |||||
| +int | HIP_TRACE_API = 0 | |||||
| +int | HIP_ATP_MARKER = 0 | |||||
| int | HIP_DB = 0 | |||||
HIP_DISABLE_HW_KERNEL_
|
int | HIP_DISABLE_HW_COPY_DEP = 1 | | const char * | dbName [] | |
-const hipStream_t | hipStreamNull = 0x0 | | const char * | ihipCommandName [] | |
-thread_local hipError_t | tls_lastHipError = hipSuccess | |
thread_local int | tls_defaultDevice = 0 | |
+thread_local hipError_t | tls_lastHipError = hipSuccess | |
std::once_flag | hip_initialized | |
-ihipDevice_t * | g_devices | | g_devices |
| bool | g_visible_device = false | g_cpu_agentDetailed DescriptionContains definitions for functions that are large enough that we don't want to inline them everywhere. This file is compiled and linked into apps running HIP / HCC path. Macro Definition Documentation- -
-
-
-
-
-Value:
-{\
- std::string s = std::string(__func__) + " (" + ToString(__VA_ARGS__) + ')';\
- if (COMPILE_HIP_DB && HIP_TRACE_API) {\
- fprintf (stderr, API_COLOR "<<hip-api: %s\n" KNRM, s.c_str());\
- }\
- SCOPED_MARKER(s.c_str(), "HIP", NULL);\
-}
-
-
-
-
-
-
-Value:
-std::call_once(hip_initialized, ihipInit);\
- API_TRACE(__VA_ARGS__);
-
-
-
-Value:
-({\
- tls_lastHipError = _hip_status;\
- \
- if ((COMPILE_HIP_TRACE_API & 0x2) && HIP_TRACE_API) {\
- fprintf(stderr, " %ship-api: %-30s ret=%2d (%s)>>\n" KNRM, (_hip_status == 0) ? API_COLOR:KRED, __func__, _hip_status, ihipErrorString(_hip_status));\
- }\
- _hip_status;\
- })
-
-
@@ -653,61 +277,22 @@ hsa_agent_t | g_cpu_agent
-
-
-
-
-Value:
-{\
- if (HIP_DB & (1<<(trace_level))) {\
- fprintf (stderr, " %s:", dbName[trace_level]); \
- fprintf (stderr, __VA_ARGS__);\
- fprintf (stderr, "%s", KNRM); \
- }\
-}
-Function Documentation- +
-
Variable Documentation- +
-Initial value:
-=
-{
- KNRM "hip-api",
- KYEL "hip-sync",
- KCYN "hip-mem",
- KMAG "hip-copy1",
- KRED "hip-signal",
- KNRM "hip-copy2",
-}
-
-
-
-Initial value:
= {
- "CopyH2H", "CopyH2D", "CopyD2H", "CopyD2D", "Kernel"
-}
-
-Generated on Wed Mar 23 2016 23:11:07 for HIP: Heterogenous-computing Interface for Portability by +Generated on Sat Apr 16 2016 14:52:10 for HIP: Heterogenous-computing Interface for Portability by
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/hip__hcc_8h_source.html b/projects/hip/docs/RuntimeAPI/html/hip__hcc_8h_source.html
new file mode 100644
index 0000000000..55c1a023fa
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/hip__hcc_8h_source.html
@@ -0,0 +1,815 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+hip_hcc.h
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 51 // Intended to distinguish whether an environment variable should be visible only in debug mode, or in debug+release.
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 104 // If FORCE_COPY_DEP=0 data copies of the same kind (H2H, H2D, D2H, D2D) are assumed to be implicitly ordered.
+
+
+
+ 108 // If not, we can simplify the copy dependency tracking by collapsing to a single Copy type, and always forcing dependencies for copy commands.
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 126 // ATP is standard CodeXL format that includes timestamps for kernels, HSA RT APIs, and HIP APIs.
+
+
+
+
+
+
+
+
+
+ 136 // Compile support for trace markers that are displayed on CodeXL GUI at start/stop of each function boundary.
+ 137 // TODO - currently we print the trace message at the beginning. if we waited, we could also include return codes, and any values returned
+
+
+
+ 141 #define SCOPED_MARKER(markerName,group,userString) amdtScopedMarker(markerName, group, userString)
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 179 fprintf(stderr, " %ship-api: %-30s ret=%2d (%s)>>\n" KNRM, (_local_hip_status == 0) ? API_COLOR:KRED, __func__, _local_hip_status, ihipErrorString(_local_hip_status));\
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 369 ihipStreamCriticalBase_t<StreamMutex> * mlock() { LockedBase<MUTEX_TYPE>::lock(); return this;};
+
+
+
+
+
+
+
+ 377 // May be NULL, indicating the previous command has completley finished and future commands don't need to create a dependency.
+
+
+
+ 381 hc::completion_future _last_kernel_future; // Completion future of last kernel command sent to GPU.
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 407 void copySync (LockedAccessor_StreamCrit_t &crit, void* dst, const void* src, size_t sizeBytes, unsigned kind);
+
+
+
+
+
+
+
+
+
+ 417 int preCopyCommand(LockedAccessor_StreamCrit_t &crit, ihipSignal_t *lastCopy, hsa_signal_t *waitSignal, ihipCommand_t copyType);
+
+
+
+ 421 SIGSEQNUM locked_lastCopySeqId() {LockedAccessor_StreamCrit_t crit(_criticalData); return lastCopySeqId(crit); };
+
+
+
+
+
+
+ 428 // Non-threadsafe accessors - must be protected by high-level stream lock with accessor passed to function.
+ 429 SIGSEQNUM lastCopySeqId (LockedAccessor_StreamCrit_t &crit) { return crit->_last_copy_signal ? crit->_last_copy_signal->_sig_id : 0; };
+
+
+
+
+ 434 // These functions access fields set at initialization time and are non-racy (so do not acquire mutex)
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 454 void setCopyAgents(unsigned kind, ihipCommand_t *commandType, hsa_agent_t *srcAgent, hsa_agent_t *dstAgent);
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 504 // MUTEX_TYPE is template argument so can easily convert to FakeMutex for performance or stress testing.
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 558 //-------------------------------------------------------------------------------------------------
+
+ 560 // ihipDevice_t does not use recursive locks so the ihip implementation must avoid calling a locked_ function from within a locked_ function.
+ 561 // External functions which call several locked_ functions will acquire and release the lock for each function. if this occurs in
+ 562 // performance-sensitive code we may want to refactor by adding non-locked functions and creating a new locked_ member function to call them all.
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 602 // Search for LockedAccessor<ihipDeviceCritical_t> for examples; do not access _criticalData directly.
+
+
+
+
+
+
+
+
+ 611 extern ihipDevice_t *g_devices; // Array of all non-emulated (ie GPU) accelerators in the system.
+
+
+ 614 extern std::vector<int> g_hip_visible_devices; /* vector of integers that contains the visible device IDs */
+
+ 616 //=================================================================================================
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+Definition: hip_hcc.h:563 Definition: hip_hcc.h:340 Definition: hip_hcc.h:279 Definition: hip_runtime_api.h:47 Definition: hip_hcc.h:506 Definition: hip_hcc.h:266 Definition: hip_runtime_api.h:74 Definition: staging_buffer.h:40 Definition: hip_hcc.h:483 Definition: hip_hcc.h:220 Definition: hip_hcc.h:399 Definition: hip_hcc.h:352 Definition: hip_hcc.h:307 +Generated on Sat Apr 16 2016 14:52:09 for HIP: Heterogenous-computing Interface for Portability by +
+ 1.8.6
+
+
+
diff --git a/projects/hip/docs/RuntimeAPI/html/hip__runtime_8h_source.html b/projects/hip/docs/RuntimeAPI/html/hip__runtime_8h_source.html
index d01ac13ca9..1fff5853a6 100644
--- a/projects/hip/docs/RuntimeAPI/html/hip__runtime_8h_source.html
+++ b/projects/hip/docs/RuntimeAPI/html/hip__runtime_8h_source.html
@@ -4,7 +4,7 @@
--Generated on Wed Mar 23 2016 23:11:07 for HIP: Heterogenous-computing Interface for Portability by +Generated on Sat Apr 16 2016 14:52:09 for HIP: Heterogenous-computing Interface for Portability by
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/hip__runtime__api_8h_source.html b/projects/hip/docs/RuntimeAPI/html/hip__runtime__api_8h_source.html
index 885302e6f0..0e70e6336e 100644
--- a/projects/hip/docs/RuntimeAPI/html/hip__runtime__api_8h_source.html
+++ b/projects/hip/docs/RuntimeAPI/html/hip__runtime__api_8h_source.html
@@ -4,7 +4,7 @@
- 141 // Developer note - when updating these, update the hipErrorName and hipErrorString functions in NVCC and HCC paths
@@ -222,131 +222,135 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
- 223 // Provide an override to automatically typecast the pointer type from void**, and also provide a default for the flags.
-
- 225 static inline hipError_t hipHostMalloc( T** ptr, size_t size, unsigned int flags = hipHostMallocDefault)
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 225 // Provide an override to automatically typecast the pointer type from void**, and also provide a default for the flags.
+
+ 227 static inline hipError_t hipHostMalloc( T** ptr, size_t size, unsigned int flags = hipHostMallocDefault)
+
+
+
+
size_t totalConstMem Size of shared memory region (in bytes). Definition: hip_runtime_api.h:86 Maximum Shared Memory Per Multiprocessor. Definition: hip_runtime_api.h:192 Maximum Shared Memory Per Multiprocessor. Definition: hip_runtime_api.h:194 Peer access was already enabled from the current device. Definition: hip_runtime_api.h:159 HSA runtime memory call returned error. Typically not seen in production systems. ... Definition: hip_runtime_api.h:158 HSA runtime memory call returned error. Typically not seen in production systems. ... Definition: hip_runtime_api.h:160 int minor Minor compute capability. On HCC, this is an approximation and features may differ from CUDA CC... Definition: hip_runtime_api.h:88 int canMapHostMemory Check whether HIP can map host memory. Definition: hip_runtime_api.h:100 Maximum number of 32-bit registers available to a thread block. This number is shared by all thread b... Definition: hip_runtime_api.h:179 Maximum number of 32-bit registers available to a thread block. This number is shared by all thread b... Definition: hip_runtime_api.h:181 Size of L2 cache in bytes. 0 if the device doesn't have L2 cache. Definition: hip_runtime_api.h:185 #define hipHostMallocDefault Flags that can be used with hipHostMalloc. Definition: hip_runtime_api.h:60 HSA runtime call other than memory returned error. Typically not seen in production systems... Definition: hip_runtime_api.h:159 Size of L2 cache in bytes. 0 if the device doesn't have L2 cache. Definition: hip_runtime_api.h:187 #define hipHostMallocDefault Flags that can be used with hipHostMalloc. Definition: hip_runtime_api.h:69 HSA runtime call other than memory returned error. Typically not seen in production systems... Definition: hip_runtime_api.h:161 int isMultiGpuBoard 1 if device is on a multi-GPU board, 0 if not. Definition: hip_runtime_api.h:99 DeviceID must be in range 0...#compute-devices. Definition: hip_runtime_api.h:150 Definition: hip_runtime_api.h:117 int clockRate Max clock frequency of the multiProcessors in khz. Definition: hip_runtime_api.h:83 Minor compute capability version number. Definition: hip_runtime_api.h:188 Maximum shared memory available per block in bytes. Definition: hip_runtime_api.h:176 Minor compute capability version number. Definition: hip_runtime_api.h:190 Maximum shared memory available per block in bytes. Definition: hip_runtime_api.h:178 int maxThreadsPerBlock Max work items per work group or workgroup max size. Definition: hip_runtime_api.h:80 hipError_t hipHostMalloc(void **ptr, size_t size, unsigned int flags) Allocate device accessible page locked host memory. Definition: hip_hcc.cpp:2214 hipError_t hipHostMalloc(void **ptr, size_t size, unsigned int flags) Allocate device accessible page locked host memory. Definition: hip_memory.cpp:152 size_t sharedMemPerBlock Size of shared memory region (in bytes). Definition: hip_runtime_api.h:77 int maxThreadsPerMultiProcessor Maximum resident threads per multi-processor. Definition: hip_runtime_api.h:91 Major compute capability version number. Definition: hip_runtime_api.h:187 Maximum number of threads per block. Definition: hip_runtime_api.h:169 Major compute capability version number. Definition: hip_runtime_api.h:189 Peer access was never enabled from the current device. Definition: hip_runtime_api.h:158 Maximum number of threads per block. Definition: hip_runtime_api.h:171 Resource handle (hipEvent_t or hipStream_t) invalid. Definition: hip_runtime_api.h:149 hipDeviceArch_t arch Architectural feature flags. New for HIP. Definition: hip_runtime_api.h:94 int maxGridSize[3] Max grid dimensions (XYZ). Definition: hip_runtime_api.h:82 int major Major compute capability. On HCC, this is an approximation and features may differ from CUDA CC... Definition: hip_runtime_api.h:87 Peak memory clock frequency in kilohertz. Definition: hip_runtime_api.h:181 Maximum resident threads per multiprocessor. Definition: hip_runtime_api.h:186 Peak memory clock frequency in kilohertz. Definition: hip_runtime_api.h:183 Maximum resident threads per multiprocessor. Definition: hip_runtime_api.h:188 int clockInstructionRate Frequency in khz of the timer used by the device-side "clock*" instructions. New for HIP... Definition: hip_runtime_api.h:93 Constant memory size in bytes. Definition: hip_runtime_api.h:177 Constant memory size in bytes. Definition: hip_runtime_api.h:179 int concurrentKernels Device can possibly execute multiple kernels concurrently. Definition: hip_runtime_api.h:95 size_t totalGlobalMem Size of global memory region (in bytes). Definition: hip_runtime_api.h:76 hipError_t hipMalloc(void **ptr, size_t size) Allocate memory on the default accelerator. Definition: hip_hcc.cpp:2165 Compute mode that device is currently in. Definition: hip_runtime_api.h:184 hipError_t hipMalloc(void **ptr, size_t size) Allocate memory on the default accelerator. Definition: hip_memory.cpp:117 Compute mode that device is currently in. Definition: hip_runtime_api.h:186 int maxThreadsDim[3] Max number of threads in each dimension (XYZ) of a block. Definition: hip_runtime_api.h:81 Number of multiprocessors on the device. Definition: hip_runtime_api.h:183 Number of multiprocessors on the device. Definition: hip_runtime_api.h:185 int memoryBusWidth Global memory bus width in bits. Definition: hip_runtime_api.h:85 One or more of the parameters passed to the API call is NULL or not in an acceptable range... Definition: hip_runtime_api.h:148 Definition: hip_runtime_api.h:74 Contains C function APIs for HIP runtime. This file does not use any HCC builtin or special language ... int memoryClockRate Max global memory clock frequency in khz. Definition: hip_runtime_api.h:84 TODO comment from hipErrorInitializationError. Definition: hip_runtime_api.h:153 Device can possibly execute multiple kernels concurrently. Definition: hip_runtime_api.h:189 Device can possibly execute multiple kernels concurrently. Definition: hip_runtime_api.h:191 int multiProcessorCount Number of multi-processors (compute units). Definition: hip_runtime_api.h:89 -Generated on Wed Mar 23 2016 23:11:07 for HIP: Heterogenous-computing Interface for Portability by +Generated on Sat Apr 16 2016 14:52:10 for HIP: Heterogenous-computing Interface for Portability by
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/hip__texture_8h.html b/projects/hip/docs/RuntimeAPI/html/hip__texture_8h.html
index ed20a765ae..1e7af77260 100644
--- a/projects/hip/docs/RuntimeAPI/html/hip__texture_8h.html
+++ b/projects/hip/docs/RuntimeAPI/html/hip__texture_8h.html
@@ -4,7 +4,7 @@
- |
|||
| struct | textureReference | |||||
| struct | texture< T, texType, hipTextureReadMode > | |||||
Macros | |
| template<class T , int dim, enum hipTextureReadMode readMode> | |
| hipError_t | hipBindTexture (size_t *offset, struct texture< T, dim, readMode > &tex, const void *devPtr, const struct hipChannelFormatDesc *desc, size_t size=UINT_MAX) |
| hipError_t | hipBindTexture (size_t *offset, struct texture< T, dim, readMode > &tex, const void *devPtr, const struct hipChannelFormatDesc *desc, size_t size=UINT_MAX) |
| template<class T , int dim, enum hipTextureReadMode readMode> | |
| hipError_t | hipBindTexture (size_t *offset, struct texture< T, dim, readMode > &tex, const void *devPtr, size_t size=UINT_MAX) |
| hipError_t | hipBindTexture (size_t *offset, struct texture< T, dim, readMode > &tex, const void *devPtr, size_t size=UINT_MAX) |
| template<class T , int dim, enum hipTextureReadMode readMode> | |
| hipError_t | hipUnbindTexture (struct texture< T, dim, readMode > *tex) |
| hipError_t | hipUnbindTexture (struct texture< T, dim, readMode > *tex) |
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/hip__texture_8h_source.html b/projects/hip/docs/RuntimeAPI/html/hip__texture_8h_source.html
index b115611916..87da06ba10 100644
--- a/projects/hip/docs/RuntimeAPI/html/hip__texture_8h_source.html
+++ b/projects/hip/docs/RuntimeAPI/html/hip__texture_8h_source.html
@@ -4,7 +4,7 @@
-
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/hip__util_8h_source.html b/projects/hip/docs/RuntimeAPI/html/hip__util_8h_source.html
new file mode 100644
index 0000000000..e5e363a20a
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/hip__util_8h_source.html
@@ -0,0 +1,136 @@
+
+
+
+
+
+
+|
+ HIP: Heterogenous-computing Interface for Portability
+
+ |
+
+ 1.8.6
+
+
+
diff --git a/projects/hip/docs/RuntimeAPI/html/hip__vector__types_8h_source.html b/projects/hip/docs/RuntimeAPI/html/hip__vector__types_8h_source.html
index 52cb0c33fa..f1dc0033b2 100644
--- a/projects/hip/docs/RuntimeAPI/html/hip__vector__types_8h_source.html
+++ b/projects/hip/docs/RuntimeAPI/html/hip__vector__types_8h_source.html
@@ -4,7 +4,7 @@
-
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/host__defines_8h.html b/projects/hip/docs/RuntimeAPI/html/host__defines_8h.html
index 9a14820ade..872875a617 100644
--- a/projects/hip/docs/RuntimeAPI/html/host__defines_8h.html
+++ b/projects/hip/docs/RuntimeAPI/html/host__defines_8h.html
@@ -4,7 +4,7 @@
-
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/host__defines_8h_source.html b/projects/hip/docs/RuntimeAPI/html/host__defines_8h_source.html
index 29d87ca30f..e99cb884f2 100644
--- a/projects/hip/docs/RuntimeAPI/html/host__defines_8h_source.html
+++ b/projects/hip/docs/RuntimeAPI/html/host__defines_8h_source.html
@@ -4,7 +4,7 @@
-
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/index.html b/projects/hip/docs/RuntimeAPI/html/index.html
index 4797eae7a6..4cf966b886 100644
--- a/projects/hip/docs/RuntimeAPI/html/index.html
+++ b/projects/hip/docs/RuntimeAPI/html/index.html
@@ -91,7 +91,7 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/modules.html b/projects/hip/docs/RuntimeAPI/html/modules.html
index 61a5a00089..2cc2f1d979 100644
--- a/projects/hip/docs/RuntimeAPI/html/modules.html
+++ b/projects/hip/docs/RuntimeAPI/html/modules.html
@@ -99,7 +99,7 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/pages.html b/projects/hip/docs/RuntimeAPI/html/pages.html
index d09976f7e7..2a0866d812 100644
--- a/projects/hip/docs/RuntimeAPI/html/pages.html
+++ b/projects/hip/docs/RuntimeAPI/html/pages.html
@@ -88,7 +88,7 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/search/all_11.js b/projects/hip/docs/RuntimeAPI/html/search/all_11.js
index 9043ae6945..bb8f6295d1 100644
--- a/projects/hip/docs/RuntimeAPI/html/search/all_11.js
+++ b/projects/hip/docs/RuntimeAPI/html/search/all_11.js
@@ -1,6 +1,6 @@
var searchData=
[
- ['texture',['texture',['../structtexture.html',1,'texture< T, texType, hipTextureReadMode >'],['../group__Texture.html',1,'(Global Namespace)']]],
+ ['texture_20reference_20management',['Texture Reference Management',['../group__Texture.html',1,'']]],
['texturereference',['textureReference',['../structtextureReference.html',1,'']]],
['totalconstmem',['totalConstMem',['../structhipDeviceProp__t.html#a29880232c56120be3455ce00d5379665',1,'hipDeviceProp_t']]],
['totalglobalmem',['totalGlobalMem',['../structhipDeviceProp__t.html#acedd6a2d23423441e4bf51c4a1b719f9',1,'hipDeviceProp_t']]]
diff --git a/projects/hip/docs/RuntimeAPI/html/search/groups_8.html b/projects/hip/docs/RuntimeAPI/html/search/all_15.html
similarity index 94%
rename from projects/hip/docs/RuntimeAPI/html/search/groups_8.html
rename to projects/hip/docs/RuntimeAPI/html/search/all_15.html
index 863d13654f..d3b5274ba7 100644
--- a/projects/hip/docs/RuntimeAPI/html/search/groups_8.html
+++ b/projects/hip/docs/RuntimeAPI/html/search/all_15.html
@@ -3,7 +3,7 @@
-
+
diff --git a/projects/hip/docs/RuntimeAPI/html/search/all_15.js b/projects/hip/docs/RuntimeAPI/html/search/all_15.js
new file mode 100644
index 0000000000..e8bf38b99c
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/search/all_15.js
@@ -0,0 +1,4 @@
+var searchData=
+[
+ ['z',['z',['../structdim3.html#a866e38993ecc4e76fd47311236c16b04',1,'dim3']]]
+];
diff --git a/projects/hip/docs/RuntimeAPI/html/search/all_7.js b/projects/hip/docs/RuntimeAPI/html/search/all_7.js
index 4bdb9b1c13..529e9394c3 100644
--- a/projects/hip/docs/RuntimeAPI/html/search/all_7.js
+++ b/projects/hip/docs/RuntimeAPI/html/search/all_7.js
@@ -1,5 +1,4 @@
var searchData=
[
- ['getproperties',['getProperties',['../structihipDevice__t.html#a0abb382f1bcdda80028f9a8307e50561',1,'ihipDevice_t']]],
['global_20enum_20and_20defines',['Global enum and defines',['../group__GlobalDefs.html',1,'']]]
];
diff --git a/projects/hip/docs/RuntimeAPI/html/search/all_8.js b/projects/hip/docs/RuntimeAPI/html/search/all_8.js
index 56dd3932c8..223696d7f7 100644
--- a/projects/hip/docs/RuntimeAPI/html/search/all_8.js
+++ b/projects/hip/docs/RuntimeAPI/html/search/all_8.js
@@ -21,12 +21,9 @@ var searchData=
['hcc_2dspecific_20accessors',['HCC-Specific Accessors',['../group__HCC__Specific.html',1,'']]],
['hip_20environment_20variables',['HIP Environment Variables',['../group__HIP-ENV.html',1,'']]],
['hip_5fhcc_2ecpp',['hip_hcc.cpp',['../hip__hcc_8cpp.html',1,'']]],
- ['hip_5flaunch_5fblocking',['HIP_LAUNCH_BLOCKING',['../group__HIP-ENV.html#ga8049b329f2663b4572d81e7a9aa8a155',1,'HIP_LAUNCH_BLOCKING(): hip_hcc.cpp'],['../group__HIP-ENV.html#ga8049b329f2663b4572d81e7a9aa8a155',1,'HIP_LAUNCH_BLOCKING(): hip_hcc.cpp'],['../group__HIP-ENV.html#ga8049b329f2663b4572d81e7a9aa8a155',1,'HIP_LAUNCH_BLOCKING(): hip_hcc2.cpp']]],
- ['hip_5fprint_5fenv',['HIP_PRINT_ENV',['../group__HIP-ENV.html#ga1e1c85dbb250f1acfb484c1be1f3b28a',1,'HIP_PRINT_ENV(): hip_hcc.cpp'],['../group__HIP-ENV.html#ga1e1c85dbb250f1acfb484c1be1f3b28a',1,'HIP_PRINT_ENV(): hip_hcc.cpp'],['../group__HIP-ENV.html#ga1e1c85dbb250f1acfb484c1be1f3b28a',1,'HIP_PRINT_ENV(): hip_hcc2.cpp']]],
['hip_5fruntime_2eh',['hip_runtime.h',['../hcc__detail_2hip__runtime_8h.html',1,'']]],
['hip_5fruntime_5fapi_2eh',['hip_runtime_api.h',['../hcc__detail_2hip__runtime__api_8h.html',1,'']]],
['hip_5ftexture_2eh',['hip_texture.h',['../hip__texture_8h.html',1,'']]],
- ['hip_5ftrace_5fapi',['HIP_TRACE_API',['../group__HIP-ENV.html#gaae9c541f3e25b8f002762337a03fec28',1,'HIP_TRACE_API(): hip_hcc.cpp'],['../group__HIP-ENV.html#gaae9c541f3e25b8f002762337a03fec28',1,'HIP_TRACE_API(): hip_hcc.cpp'],['../group__HIP-ENV.html#gaae9c541f3e25b8f002762337a03fec28',1,'HIP_TRACE_API(): hip_hcc2.cpp']]],
['hip_5fvector_5ftypes_2eh',['hip_vector_types.h',['../hcc__detail_2hip__vector__types_8h.html',1,'']]],
['hipchannelformatdesc',['hipChannelFormatDesc',['../structhipChannelFormatDesc.html',1,'']]],
['hipdevicearch_5ft',['hipDeviceArch_t',['../structhipDeviceArch__t.html',1,'']]],
@@ -56,18 +53,18 @@ var searchData=
['hipdeviceattributepcideviceid',['hipDeviceAttributePciDeviceId',['../group__GlobalDefs.html#ggacc0acd7b9bda126c6bb3dfd6e2796d7ca955d90286e87be9e3528f0b817ab32ff',1,'hip_runtime_api.h']]],
['hipdeviceattributetotalconstantmemory',['hipDeviceAttributeTotalConstantMemory',['../group__GlobalDefs.html#ggacc0acd7b9bda126c6bb3dfd6e2796d7cac6089ac3a0f9c77cc382fb0eaa73ae9c',1,'hip_runtime_api.h']]],
['hipdeviceattributewarpsize',['hipDeviceAttributeWarpSize',['../group__GlobalDefs.html#ggacc0acd7b9bda126c6bb3dfd6e2796d7caffd94133e823247a6f1215343232f6ec',1,'hip_runtime_api.h']]],
- ['hipdevicecanaccesspeer',['hipDeviceCanAccessPeer',['../group__PeerToPeer.html#gab53a55dbc087ff659918fd04287de3d3',1,'hipDeviceCanAccessPeer(int *canAccessPeer, int device, int peerDevice): hip_hcc.cpp'],['../group__PeerToPeer.html#gab53a55dbc087ff659918fd04287de3d3',1,'hipDeviceCanAccessPeer(int *canAccessPeer, int device, int peerDevice): hip_hcc.cpp'],['../group__PeerToPeer.html#gab53a55dbc087ff659918fd04287de3d3',1,'hipDeviceCanAccessPeer(int *canAccessPeer, int device, int peerDevice): hip_hcc2.cpp']]],
- ['hipdevicedisablepeeraccess',['hipDeviceDisablePeerAccess',['../group__PeerToPeer.html#ga41e60c01f63597529da1cd77bdd55379',1,'hipDeviceDisablePeerAccess(int peerDevice): hip_hcc.cpp'],['../group__PeerToPeer.html#ga41e60c01f63597529da1cd77bdd55379',1,'hipDeviceDisablePeerAccess(int peerDevice): hip_hcc.cpp'],['../group__PeerToPeer.html#ga41e60c01f63597529da1cd77bdd55379',1,'hipDeviceDisablePeerAccess(int peerDevice): hip_hcc2.cpp']]],
- ['hipdeviceenablepeeraccess',['hipDeviceEnablePeerAccess',['../group__PeerToPeer.html#ga098e0d626edbfb69b66d141a5a8b7dc6',1,'hipDeviceEnablePeerAccess(int peerDevice, unsigned int flags): hip_hcc.cpp'],['../group__PeerToPeer.html#ga098e0d626edbfb69b66d141a5a8b7dc6',1,'hipDeviceEnablePeerAccess(int peerDevice, unsigned int flags): hip_hcc.cpp'],['../group__PeerToPeer.html#ga098e0d626edbfb69b66d141a5a8b7dc6',1,'hipDeviceEnablePeerAccess(int peerDevice, unsigned int flags): hip_hcc2.cpp']]],
- ['hipdevicegetattribute',['hipDeviceGetAttribute',['../group__Device.html#gac49518ff2b26b98ea2ec9e9268761a24',1,'hipDeviceGetAttribute(int *pi, hipDeviceAttribute_t attr, int device): hip_hcc.cpp'],['../group__Device.html#gac49518ff2b26b98ea2ec9e9268761a24',1,'hipDeviceGetAttribute(int *pi, hipDeviceAttribute_t attr, int device): hip_hcc.cpp'],['../group__Device.html#gac49518ff2b26b98ea2ec9e9268761a24',1,'hipDeviceGetAttribute(int *pi, hipDeviceAttribute_t attr, int device): hip_hcc2.cpp']]],
- ['hipdevicegetcacheconfig',['hipDeviceGetCacheConfig',['../group__Device.html#gaeeffa2456c5430400bea75ecd6ad1e68',1,'hipDeviceGetCacheConfig(hipFuncCache *cacheConfig): hip_hcc.cpp'],['../group__Device.html#gaeeffa2456c5430400bea75ecd6ad1e68',1,'hipDeviceGetCacheConfig(hipFuncCache *cacheConfig): hip_hcc.cpp'],['../group__Device.html#gaeeffa2456c5430400bea75ecd6ad1e68',1,'hipDeviceGetCacheConfig(hipFuncCache *cacheConfig): hip_hcc2.cpp']]],
- ['hipdevicegetsharedmemconfig',['hipDeviceGetSharedMemConfig',['../group__Device.html#ga1bb08f774a34a468d969a8a04791c9bb',1,'hipDeviceGetSharedMemConfig(hipSharedMemConfig *pConfig): hip_hcc.cpp'],['../group__Device.html#ga1bb08f774a34a468d969a8a04791c9bb',1,'hipDeviceGetSharedMemConfig(hipSharedMemConfig *pConfig): hip_hcc.cpp'],['../group__Device.html#ga1bb08f774a34a468d969a8a04791c9bb',1,'hipDeviceGetSharedMemConfig(hipSharedMemConfig *pConfig): hip_hcc2.cpp']]],
+ ['hipdevicecanaccesspeer',['hipDeviceCanAccessPeer',['../group__PeerToPeer.html#ga0a1c9ccd775758d9d7d5b5a1f525b719',1,'hipDeviceCanAccessPeer(int *canAccessPeer, int deviceId, int peerDeviceId): hip_peer.cpp'],['../group__PeerToPeer.html#ga0a1c9ccd775758d9d7d5b5a1f525b719',1,'hipDeviceCanAccessPeer(int *canAccessPeer, int deviceId, int peerDeviceId): hip_peer.cpp']]],
+ ['hipdevicedisablepeeraccess',['hipDeviceDisablePeerAccess',['../group__PeerToPeer.html#ga85030c72824fb60aaddc7374ab60481b',1,'hipDeviceDisablePeerAccess(int peerDeviceId): hip_peer.cpp'],['../group__PeerToPeer.html#ga85030c72824fb60aaddc7374ab60481b',1,'hipDeviceDisablePeerAccess(int peerDeviceId): hip_peer.cpp']]],
+ ['hipdeviceenablepeeraccess',['hipDeviceEnablePeerAccess',['../group__PeerToPeer.html#ga0caca59034134d7a7bb893cc1caa653e',1,'hipDeviceEnablePeerAccess(int peerDeviceId, unsigned int flags): hip_peer.cpp'],['../group__PeerToPeer.html#ga0caca59034134d7a7bb893cc1caa653e',1,'hipDeviceEnablePeerAccess(int peerDeviceId, unsigned int flags): hip_peer.cpp']]],
+ ['hipdevicegetattribute',['hipDeviceGetAttribute',['../group__Device.html#gac49518ff2b26b98ea2ec9e9268761a24',1,'hipDeviceGetAttribute(int *pi, hipDeviceAttribute_t attr, int device): hip_device.cpp'],['../group__Device.html#gac49518ff2b26b98ea2ec9e9268761a24',1,'hipDeviceGetAttribute(int *pi, hipDeviceAttribute_t attr, int device): hip_device.cpp']]],
+ ['hipdevicegetcacheconfig',['hipDeviceGetCacheConfig',['../group__Device.html#gaeeffa2456c5430400bea75ecd6ad1e68',1,'hipDeviceGetCacheConfig(hipFuncCache *cacheConfig): hip_device.cpp'],['../group__Device.html#gaeeffa2456c5430400bea75ecd6ad1e68',1,'hipDeviceGetCacheConfig(hipFuncCache *cacheConfig): hip_device.cpp']]],
+ ['hipdevicegetsharedmemconfig',['hipDeviceGetSharedMemConfig',['../group__Device.html#ga1bb08f774a34a468d969a8a04791c9bb',1,'hipDeviceGetSharedMemConfig(hipSharedMemConfig *pConfig): hip_device.cpp'],['../group__Device.html#ga1bb08f774a34a468d969a8a04791c9bb',1,'hipDeviceGetSharedMemConfig(hipSharedMemConfig *pConfig): hip_device.cpp']]],
['hipdeviceprop_5ft',['hipDeviceProp_t',['../structhipDeviceProp__t.html',1,'']]],
- ['hipdevicereset',['hipDeviceReset',['../group__Device.html#ga8d57161ae56a8edc46eeda447417bf6c',1,'hipDeviceReset(void): hip_hcc.cpp'],['../group__Device.html#ga8d57161ae56a8edc46eeda447417bf6c',1,'hipDeviceReset(void): hip_hcc.cpp'],['../group__Device.html#ga8d57161ae56a8edc46eeda447417bf6c',1,'hipDeviceReset(void): hip_hcc2.cpp']]],
- ['hipdevicesetcacheconfig',['hipDeviceSetCacheConfig',['../group__Device.html#gac2b282179f29c4c0ca7b5391242c6a4c',1,'hipDeviceSetCacheConfig(hipFuncCache cacheConfig): hip_hcc.cpp'],['../group__Device.html#gac2b282179f29c4c0ca7b5391242c6a4c',1,'hipDeviceSetCacheConfig(hipFuncCache cacheConfig): hip_hcc.cpp'],['../group__Device.html#gac2b282179f29c4c0ca7b5391242c6a4c',1,'hipDeviceSetCacheConfig(hipFuncCache cacheConfig): hip_hcc2.cpp']]],
- ['hipdevicesetsharedmemconfig',['hipDeviceSetSharedMemConfig',['../group__Device.html#ga9b1f279084e76691cedfbfadf9c717ee',1,'hipDeviceSetSharedMemConfig(hipSharedMemConfig config): hip_hcc.cpp'],['../group__Device.html#ga9b1f279084e76691cedfbfadf9c717ee',1,'hipDeviceSetSharedMemConfig(hipSharedMemConfig config): hip_hcc.cpp'],['../group__Device.html#ga9b1f279084e76691cedfbfadf9c717ee',1,'hipDeviceSetSharedMemConfig(hipSharedMemConfig config): hip_hcc2.cpp']]],
- ['hipdevicesynchronize',['hipDeviceSynchronize',['../group__Device.html#gaefdc2847fb1d6c3fb1354e827a191ebd',1,'hipDeviceSynchronize(void): hip_hcc.cpp'],['../group__Device.html#gaefdc2847fb1d6c3fb1354e827a191ebd',1,'hipDeviceSynchronize(void): hip_hcc.cpp'],['../group__Device.html#gaefdc2847fb1d6c3fb1354e827a191ebd',1,'hipDeviceSynchronize(void): hip_hcc2.cpp']]],
- ['hipdrivergetversion',['hipDriverGetVersion',['../group__Version.html#gaf6c342f52d2a29a0aca5cdd89b4dd47c',1,'hipDriverGetVersion(int *driverVersion): hip_hcc.cpp'],['../group__Version.html#gaf6c342f52d2a29a0aca5cdd89b4dd47c',1,'hipDriverGetVersion(int *driverVersion): hip_hcc.cpp'],['../group__Version.html#gaf6c342f52d2a29a0aca5cdd89b4dd47c',1,'hipDriverGetVersion(int *driverVersion): hip_hcc2.cpp']]],
+ ['hipdevicereset',['hipDeviceReset',['../group__Device.html#ga8d57161ae56a8edc46eeda447417bf6c',1,'hipDeviceReset(void): hip_device.cpp'],['../group__Device.html#ga8d57161ae56a8edc46eeda447417bf6c',1,'hipDeviceReset(void): hip_device.cpp']]],
+ ['hipdevicesetcacheconfig',['hipDeviceSetCacheConfig',['../group__Device.html#gac2b282179f29c4c0ca7b5391242c6a4c',1,'hipDeviceSetCacheConfig(hipFuncCache cacheConfig): hip_device.cpp'],['../group__Device.html#gac2b282179f29c4c0ca7b5391242c6a4c',1,'hipDeviceSetCacheConfig(hipFuncCache cacheConfig): hip_device.cpp']]],
+ ['hipdevicesetsharedmemconfig',['hipDeviceSetSharedMemConfig',['../group__Device.html#ga9b1f279084e76691cedfbfadf9c717ee',1,'hipDeviceSetSharedMemConfig(hipSharedMemConfig config): hip_device.cpp'],['../group__Device.html#ga9b1f279084e76691cedfbfadf9c717ee',1,'hipDeviceSetSharedMemConfig(hipSharedMemConfig config): hip_device.cpp']]],
+ ['hipdevicesynchronize',['hipDeviceSynchronize',['../group__Device.html#gaefdc2847fb1d6c3fb1354e827a191ebd',1,'hipDeviceSynchronize(void): hip_device.cpp'],['../group__Device.html#gaefdc2847fb1d6c3fb1354e827a191ebd',1,'hipDeviceSynchronize(void): hip_device.cpp']]],
+ ['hipdrivergetversion',['hipDriverGetVersion',['../group__Version.html#gaf6c342f52d2a29a0aca5cdd89b4dd47c',1,'hipDriverGetVersion(int *driverVersion): hip_peer.cpp'],['../group__Version.html#gaf6c342f52d2a29a0aca5cdd89b4dd47c',1,'hipDriverGetVersion(int *driverVersion): hip_peer.cpp']]],
['hiperror_5ft',['hipError_t',['../group__GlobalDefs.html#gadf5010f6e140a53ecbdf949e73e87594',1,'hip_runtime_api.h']]],
['hiperrorinitializationerror',['hipErrorInitializationError',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a7e935ae88ee1f9ff3920156ac6864520',1,'hip_runtime_api.h']]],
['hiperrorinvaliddevice',['hipErrorInvalidDevice',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a07ab9b704ea693c1781a52741c60cd0d',1,'hip_runtime_api.h']]],
@@ -80,6 +77,8 @@ var searchData=
['hiperrornodevice',['hipErrorNoDevice',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594ad4406972c318df36d231310a15131c24',1,'hip_runtime_api.h']]],
['hiperrornotready',['hipErrorNotReady',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594aa9638063c8746a9d1fda2b2069a0a9f1',1,'hip_runtime_api.h']]],
['hiperroroutofresources',['hipErrorOutOfResources',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a60c1c080b79bdde9ef5e808f974ac9ed',1,'hip_runtime_api.h']]],
+ ['hiperrorpeeraccessalreadyenabled',['hipErrorPeerAccessAlreadyEnabled',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a5399c146f91246f8b77abcd4ea30e7ac',1,'hip_runtime_api.h']]],
+ ['hiperrorpeeraccessnotenabled',['hipErrorPeerAccessNotEnabled',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a2ee0bf2e64840f253e4a1b12bbaf2d09',1,'hip_runtime_api.h']]],
['hiperrorruntimememory',['hipErrorRuntimeMemory',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a1159eb9a6be66bea740a8bfb61378723',1,'hip_runtime_api.h']]],
['hiperrorruntimeother',['hipErrorRuntimeOther',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a44f847c5914be2177feac107dcb096d1',1,'hip_runtime_api.h']]],
['hiperrortbd',['hipErrorTbd',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594ab556409e11ddb0c4cf77a2f4fc91ea9e',1,'hip_runtime_api.h']]],
@@ -87,75 +86,78 @@ var searchData=
['hiperrorunknownsymbol',['hipErrorUnknownSymbol',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a45b297e6c3b2029dce1348658421481b',1,'hip_runtime_api.h']]],
['hipevent_5ft',['hipEvent_t',['../structhipEvent__t.html',1,'']]],
['hipeventblockingsync',['hipEventBlockingSync',['../group__GlobalDefs.html#gafa1c076a5b991763a98695063f1ea11d',1,'hip_runtime_api.h']]],
- ['hipeventcreatewithflags',['hipEventCreateWithFlags',['../group__Event.html#gae86a5acb1b22b61bc9ecb9c28fc71b75',1,'hipEventCreateWithFlags(hipEvent_t *event, unsigned flags): hip_hcc.cpp'],['../group__Event.html#gae86a5acb1b22b61bc9ecb9c28fc71b75',1,'hipEventCreateWithFlags(hipEvent_t *event, unsigned flags): hip_hcc.cpp'],['../group__Event.html#gae86a5acb1b22b61bc9ecb9c28fc71b75',1,'hipEventCreateWithFlags(hipEvent_t *event, unsigned flags): hip_hcc2.cpp']]],
+ ['hipeventcreate',['hipEventCreate',['../group__Event.html#ga5df2309c9f29ca4c8e669db658d411b4',1,'hipEventCreate(hipEvent_t *event): hip_event.cpp'],['../group__Event.html#ga5df2309c9f29ca4c8e669db658d411b4',1,'hipEventCreate(hipEvent_t *event): hip_event.cpp']]],
+ ['hipeventcreatewithflags',['hipEventCreateWithFlags',['../group__Event.html#gae86a5acb1b22b61bc9ecb9c28fc71b75',1,'hipEventCreateWithFlags(hipEvent_t *event, unsigned flags): hip_event.cpp'],['../group__Event.html#gae86a5acb1b22b61bc9ecb9c28fc71b75',1,'hipEventCreateWithFlags(hipEvent_t *event, unsigned flags): hip_event.cpp']]],
['hipeventdefault',['hipEventDefault',['../group__GlobalDefs.html#ga122a5853359eba97cf047ddd153740f0',1,'hip_runtime_api.h']]],
- ['hipeventdestroy',['hipEventDestroy',['../group__Event.html#ga83260357dce0c39e8c6a3c74ec97484c',1,'hipEventDestroy(hipEvent_t event): hip_hcc.cpp'],['../group__Event.html#ga83260357dce0c39e8c6a3c74ec97484c',1,'hipEventDestroy(hipEvent_t event): hip_hcc.cpp'],['../group__Event.html#ga83260357dce0c39e8c6a3c74ec97484c',1,'hipEventDestroy(hipEvent_t event): hip_hcc2.cpp']]],
+ ['hipeventdestroy',['hipEventDestroy',['../group__Event.html#ga83260357dce0c39e8c6a3c74ec97484c',1,'hipEventDestroy(hipEvent_t event): hip_event.cpp'],['../group__Event.html#ga83260357dce0c39e8c6a3c74ec97484c',1,'hipEventDestroy(hipEvent_t event): hip_event.cpp']]],
['hipeventdisabletiming',['hipEventDisableTiming',['../group__GlobalDefs.html#ga3c0f44a85e36a4c67671da6bcdad0351',1,'hip_runtime_api.h']]],
- ['hipeventelapsedtime',['hipEventElapsedTime',['../group__Event.html#gad4128b815cb475c8e13c7e66ff6250b7',1,'hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop): hip_hcc.cpp'],['../group__Event.html#gad4128b815cb475c8e13c7e66ff6250b7',1,'hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop): hip_hcc.cpp'],['../group__Event.html#gad4128b815cb475c8e13c7e66ff6250b7',1,'hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop): hip_hcc2.cpp']]],
+ ['hipeventelapsedtime',['hipEventElapsedTime',['../group__Event.html#gad4128b815cb475c8e13c7e66ff6250b7',1,'hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop): hip_event.cpp'],['../group__Event.html#gad4128b815cb475c8e13c7e66ff6250b7',1,'hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop): hip_event.cpp']]],
['hipeventinterprocess',['hipEventInterprocess',['../group__GlobalDefs.html#ga0f01d74059baa704e42aeff8222166bb',1,'hip_runtime_api.h']]],
- ['hipeventquery',['hipEventQuery',['../group__Event.html#ga5d12d7b798b5ceb5932d1ac21f5ac776',1,'hipEventQuery(hipEvent_t event): hip_hcc.cpp'],['../group__Event.html#ga5d12d7b798b5ceb5932d1ac21f5ac776',1,'hipEventQuery(hipEvent_t event): hip_hcc.cpp'],['../group__Event.html#ga5d12d7b798b5ceb5932d1ac21f5ac776',1,'hipEventQuery(hipEvent_t event): hip_hcc2.cpp']]],
- ['hipeventrecord',['hipEventRecord',['../group__Event.html#gace88ebd8c7ec42a6c2cebda2e8b0cb38',1,'hipEventRecord(hipEvent_t event, hipStream_t stream=NULL): hip_hcc.cpp'],['../group__Event.html#gace88ebd8c7ec42a6c2cebda2e8b0cb38',1,'hipEventRecord(hipEvent_t event, hipStream_t stream): hip_hcc.cpp'],['../group__Event.html#gace88ebd8c7ec42a6c2cebda2e8b0cb38',1,'hipEventRecord(hipEvent_t event, hipStream_t stream): hip_hcc2.cpp']]],
- ['hipeventsynchronize',['hipEventSynchronize',['../group__Event.html#ga1f72d98ba5d6f7dc3da54e0c41fe38b1',1,'hipEventSynchronize(hipEvent_t event): hip_hcc.cpp'],['../group__Event.html#ga1f72d98ba5d6f7dc3da54e0c41fe38b1',1,'hipEventSynchronize(hipEvent_t event): hip_hcc.cpp'],['../group__Event.html#ga1f72d98ba5d6f7dc3da54e0c41fe38b1',1,'hipEventSynchronize(hipEvent_t event): hip_hcc2.cpp']]],
+ ['hipeventquery',['hipEventQuery',['../group__Event.html#ga5d12d7b798b5ceb5932d1ac21f5ac776',1,'hipEventQuery(hipEvent_t event): hip_event.cpp'],['../group__Event.html#ga5d12d7b798b5ceb5932d1ac21f5ac776',1,'hipEventQuery(hipEvent_t event): hip_event.cpp']]],
+ ['hipeventrecord',['hipEventRecord',['../group__Event.html#ga553b6f7a8e7b7dd9536d8a64c24d7e29',1,'hipEventRecord(hipEvent_t event, hipStream_t stream): hip_event.cpp'],['../group__Event.html#ga553b6f7a8e7b7dd9536d8a64c24d7e29',1,'hipEventRecord(hipEvent_t event, hipStream_t stream): hip_event.cpp']]],
+ ['hipeventsynchronize',['hipEventSynchronize',['../group__Event.html#ga1f72d98ba5d6f7dc3da54e0c41fe38b1',1,'hipEventSynchronize(hipEvent_t event): hip_event.cpp'],['../group__Event.html#ga1f72d98ba5d6f7dc3da54e0c41fe38b1',1,'hipEventSynchronize(hipEvent_t event): hip_event.cpp']]],
['hipfiltermodepoint',['hipFilterModePoint',['../hip__texture_8h.html#aa2f0b6002b81d0a43a808cb880bb21e6a56ede038ab7c805ec4b5b61d2b678dfc',1,'hip_texture.h']]],
- ['hipfree',['hipFree',['../group__Memory.html#ga740d08da65cae1441ba32f8fedb863d1',1,'hipFree(void *ptr): hip_hcc.cpp'],['../group__Memory.html#ga740d08da65cae1441ba32f8fedb863d1',1,'hipFree(void *ptr): hip_hcc.cpp'],['../group__Memory.html#ga740d08da65cae1441ba32f8fedb863d1',1,'hipFree(void *ptr): hip_hcc2.cpp']]],
- ['hipfreehost',['hipFreeHost',['../group__Memory.html#gad2164cc3d49da53052f4b83b789e90c9',1,'hipFreeHost(void *ptr) __attribute__((deprecated("use hipHostFree instead"))): hip_hcc.cpp'],['../group__Memory.html#gad2164cc3d49da53052f4b83b789e90c9',1,'hipFreeHost(void *ptr): hip_hcc.cpp'],['../group__Memory.html#gad2164cc3d49da53052f4b83b789e90c9',1,'hipFreeHost(void *ptr): hip_hcc2.cpp']]],
+ ['hipfree',['hipFree',['../group__Memory.html#ga740d08da65cae1441ba32f8fedb863d1',1,'hipFree(void *ptr): hip_memory.cpp'],['../group__Memory.html#ga740d08da65cae1441ba32f8fedb863d1',1,'hipFree(void *ptr): hip_memory.cpp']]],
+ ['hipfreehost',['hipFreeHost',['../group__Memory.html#gad2164cc3d49da53052f4b83b789e90c9',1,'hipFreeHost(void *ptr) __attribute__((deprecated("use hipHostFree instead"))): hip_memory.cpp'],['../group__Memory.html#gad2164cc3d49da53052f4b83b789e90c9',1,'hipFreeHost(void *ptr): hip_memory.cpp']]],
['hipfunccache',['hipFuncCache',['../group__GlobalDefs.html#gac7e4bfd88340fc06642136c839a3d822',1,'hipFuncCache(): hip_runtime_api.h'],['../group__GlobalDefs.html#gaad15dc7939a0a25b16e4aa161fb41eee',1,'hipFuncCache(): hip_runtime_api.h']]],
['hipfunccachepreferequal',['hipFuncCachePreferEqual',['../group__GlobalDefs.html#ggac7e4bfd88340fc06642136c839a3d822a0ddab0e840107634a152033103be44d7',1,'hip_runtime_api.h']]],
['hipfunccachepreferl1',['hipFuncCachePreferL1',['../group__GlobalDefs.html#ggac7e4bfd88340fc06642136c839a3d822a636a3c140db6b9d4a8bf7d5a61c398c5',1,'hip_runtime_api.h']]],
['hipfunccacheprefernone',['hipFuncCachePreferNone',['../group__GlobalDefs.html#ggac7e4bfd88340fc06642136c839a3d822a0813fbaa008ce1231ff9fed3911eb3af',1,'hip_runtime_api.h']]],
['hipfunccacheprefershared',['hipFuncCachePreferShared',['../group__GlobalDefs.html#ggac7e4bfd88340fc06642136c839a3d822a9b34337dfbadba25ed2aa270bbcabc43',1,'hip_runtime_api.h']]],
- ['hipfuncsetcacheconfig',['hipFuncSetCacheConfig',['../group__Device.html#gadd94a910c2b840833cc325b1e5425702',1,'hipFuncSetCacheConfig(hipFuncCache config): hip_hcc.cpp'],['../group__Device.html#gadd94a910c2b840833cc325b1e5425702',1,'hipFuncSetCacheConfig(hipFuncCache cacheConfig): hip_hcc.cpp'],['../group__Device.html#gadd94a910c2b840833cc325b1e5425702',1,'hipFuncSetCacheConfig(hipFuncCache cacheConfig): hip_hcc2.cpp']]],
- ['hipgetdevice',['hipGetDevice',['../group__Device.html#gaffc83567f2df3bbe2d37a19872d60f24',1,'hipGetDevice(int *device): hip_hcc.cpp'],['../group__Device.html#gaffc83567f2df3bbe2d37a19872d60f24',1,'hipGetDevice(int *device): hip_hcc.cpp'],['../group__Device.html#gaffc83567f2df3bbe2d37a19872d60f24',1,'hipGetDevice(int *device): hip_hcc2.cpp']]],
- ['hipgetdevicecount',['hipGetDeviceCount',['../group__Device.html#ga8555d5c76d88c50ddbf54ae70b568394',1,'hipGetDeviceCount(int *count): hip_hcc.cpp'],['../group__Device.html#ga8555d5c76d88c50ddbf54ae70b568394',1,'hipGetDeviceCount(int *count): hip_hcc.cpp'],['../group__Device.html#ga8555d5c76d88c50ddbf54ae70b568394',1,'hipGetDeviceCount(int *count): hip_hcc2.cpp']]],
- ['hipgetdeviceproperties',['hipGetDeviceProperties',['../group__Device.html#ga77c20744e2a88c31440992d6c7754b5f',1,'hipGetDeviceProperties(hipDeviceProp_t *prop, int device): hip_hcc.cpp'],['../group__Device.html#ga77c20744e2a88c31440992d6c7754b5f',1,'hipGetDeviceProperties(hipDeviceProp_t *props, int device): hip_hcc.cpp'],['../group__Device.html#ga77c20744e2a88c31440992d6c7754b5f',1,'hipGetDeviceProperties(hipDeviceProp_t *props, int device): hip_hcc2.cpp']]],
- ['hipgeterrorname',['hipGetErrorName',['../group__Error.html#ga88c474d77635523dbf6ca67be7b56999',1,'hipGetErrorName(hipError_t hip_error): hip_hcc.cpp'],['../group__Error.html#ga88c474d77635523dbf6ca67be7b56999',1,'hipGetErrorName(hipError_t hip_error): hip_hcc.cpp'],['../group__Error.html#ga88c474d77635523dbf6ca67be7b56999',1,'hipGetErrorName(hipError_t hip_error): hip_hcc2.cpp']]],
- ['hipgeterrorstring',['hipGetErrorString',['../group__Error.html#ga5959779a654bbc98ffe6d36ab536740a',1,'hipGetErrorString(hipError_t hip_error): hip_hcc.cpp'],['../group__Error.html#ga5959779a654bbc98ffe6d36ab536740a',1,'hipGetErrorString(hipError_t hip_error): hip_hcc.cpp'],['../group__Error.html#ga5959779a654bbc98ffe6d36ab536740a',1,'hipGetErrorString(hipError_t hip_error): hip_hcc2.cpp']]],
- ['hipgetlasterror',['hipGetLastError',['../group__Error.html#ga533daeb9114d7fc2db8d867adf9e419b',1,'hipGetLastError(void): hip_hcc.cpp'],['../group__Error.html#ga533daeb9114d7fc2db8d867adf9e419b',1,'hipGetLastError(): hip_hcc.cpp'],['../group__Error.html#ga533daeb9114d7fc2db8d867adf9e419b',1,'hipGetLastError(): hip_hcc2.cpp']]],
- ['hiphccgetaccelerator',['hipHccGetAccelerator',['../group__HCC__Specific.html#ga0d24b3157fd1b16d38672bb157ec4cd4',1,'hipHccGetAccelerator(int deviceId, hc::accelerator *acc): hip_hcc.cpp'],['../group__HCC__Specific.html#ga0d24b3157fd1b16d38672bb157ec4cd4',1,'hipHccGetAccelerator(int deviceId, hc::accelerator *acc): hip_hcc.cpp'],['../group__HCC__Specific.html#ga0d24b3157fd1b16d38672bb157ec4cd4',1,'hipHccGetAccelerator(int deviceId, hc::accelerator *acc): hip_hcc2.cpp']]],
- ['hiphccgetacceleratorview',['hipHccGetAcceleratorView',['../group__HCC__Specific.html#ga1a7087ea9c3c3323270d7cce73650b44',1,'hipHccGetAcceleratorView(hipStream_t stream, hc::accelerator_view **av): hip_hcc.cpp'],['../group__HCC__Specific.html#ga1a7087ea9c3c3323270d7cce73650b44',1,'hipHccGetAcceleratorView(hipStream_t stream, hc::accelerator_view **av): hip_hcc.cpp'],['../group__HCC__Specific.html#ga1a7087ea9c3c3323270d7cce73650b44',1,'hipHccGetAcceleratorView(hipStream_t stream, hc::accelerator_view **av): hip_hcc2.cpp']]],
- ['hiphostfree',['hipHostFree',['../group__Memory.html#ga2e543f58ee4544e317cd695d6d82e0a3',1,'hipHostFree(void *ptr): hip_hcc.cpp'],['../group__Memory.html#ga2e543f58ee4544e317cd695d6d82e0a3',1,'hipHostFree(void *ptr): hip_hcc.cpp']]],
- ['hiphostgetdevicepointer',['hipHostGetDevicePointer',['../group__Memory.html#ga8fa7a0478020b835a24785cd6bb89725',1,'hipHostGetDevicePointer(void **devPtr, void *hstPtr, unsigned int flags): hip_runtime_api.h'],['../hip__hcc_8cpp.html#a59f9f57c495531c8bb12f506e915399e',1,'hipHostGetDevicePointer(void **devicePointer, void *hostPointer, unsigned flags): hip_hcc.cpp']]],
- ['hiphostgetflags',['hipHostGetFlags',['../group__Memory.html#ga4d26915873b3e3534ceb4dc310f8709a',1,'hipHostGetFlags(unsigned int *flagsPtr, void *hostPtr): hip_hcc.cpp'],['../group__Memory.html#ga4d26915873b3e3534ceb4dc310f8709a',1,'hipHostGetFlags(unsigned int *flagsPtr, void *hostPtr): hip_hcc.cpp'],['../group__Memory.html#ga4d26915873b3e3534ceb4dc310f8709a',1,'hipHostGetFlags(unsigned int *flagsPtr, void *hostPtr): hip_hcc2.cpp']]],
- ['hiphostmalloc',['hipHostMalloc',['../group__Memory.html#gaad40bc7d97ccc799403ef5a9a8c246e1',1,'hipHostMalloc(void **ptr, size_t size, unsigned int flags): hip_hcc.cpp'],['../group__Memory.html#gaad40bc7d97ccc799403ef5a9a8c246e1',1,'hipHostMalloc(void **ptr, size_t sizeBytes, unsigned int flags): hip_hcc.cpp']]],
+ ['hipfuncsetcacheconfig',['hipFuncSetCacheConfig',['../group__Device.html#gadd94a910c2b840833cc325b1e5425702',1,'hipFuncSetCacheConfig(hipFuncCache config): hip_device.cpp'],['../group__Device.html#gadd94a910c2b840833cc325b1e5425702',1,'hipFuncSetCacheConfig(hipFuncCache cacheConfig): hip_device.cpp']]],
+ ['hipgetdevice',['hipGetDevice',['../group__Device.html#gaffc83567f2df3bbe2d37a19872d60f24',1,'hipGetDevice(int *device): hip_device.cpp'],['../group__Device.html#gaffc83567f2df3bbe2d37a19872d60f24',1,'hipGetDevice(int *device): hip_device.cpp']]],
+ ['hipgetdevicecount',['hipGetDeviceCount',['../group__Device.html#ga8555d5c76d88c50ddbf54ae70b568394',1,'hipGetDeviceCount(int *count): hip_device.cpp'],['../group__Device.html#ga8555d5c76d88c50ddbf54ae70b568394',1,'hipGetDeviceCount(int *count): hip_device.cpp']]],
+ ['hipgetdeviceproperties',['hipGetDeviceProperties',['../group__Device.html#ga77c20744e2a88c31440992d6c7754b5f',1,'hipGetDeviceProperties(hipDeviceProp_t *prop, int device): hip_device.cpp'],['../group__Device.html#ga77c20744e2a88c31440992d6c7754b5f',1,'hipGetDeviceProperties(hipDeviceProp_t *props, int device): hip_device.cpp']]],
+ ['hipgeterrorname',['hipGetErrorName',['../group__Error.html#ga88c474d77635523dbf6ca67be7b56999',1,'hipGetErrorName(hipError_t hip_error): hip_error.cpp'],['../group__Error.html#ga88c474d77635523dbf6ca67be7b56999',1,'hipGetErrorName(hipError_t hip_error): hip_error.cpp']]],
+ ['hipgeterrorstring',['hipGetErrorString',['../group__Error.html#ga5959779a654bbc98ffe6d36ab536740a',1,'hipGetErrorString(hipError_t hip_error): hip_error.cpp'],['../group__Error.html#ga5959779a654bbc98ffe6d36ab536740a',1,'hipGetErrorString(hipError_t hip_error): hip_error.cpp']]],
+ ['hipgetlasterror',['hipGetLastError',['../group__Error.html#ga533daeb9114d7fc2db8d867adf9e419b',1,'hipGetLastError(void): hip_error.cpp'],['../group__Error.html#ga533daeb9114d7fc2db8d867adf9e419b',1,'hipGetLastError(): hip_error.cpp']]],
+ ['hiphccgetaccelerator',['hipHccGetAccelerator',['../hip__hcc_8cpp.html#a0d24b3157fd1b16d38672bb157ec4cd4',1,'hip_hcc.cpp']]],
+ ['hiphccgetacceleratorview',['hipHccGetAcceleratorView',['../hip__hcc_8cpp.html#a1a7087ea9c3c3323270d7cce73650b44',1,'hip_hcc.cpp']]],
+ ['hiphostfree',['hipHostFree',['../group__Memory.html#ga2e543f58ee4544e317cd695d6d82e0a3',1,'hipHostFree(void *ptr): hip_memory.cpp'],['../group__Memory.html#ga2e543f58ee4544e317cd695d6d82e0a3',1,'hipHostFree(void *ptr): hip_memory.cpp']]],
+ ['hiphostgetdevicepointer',['hipHostGetDevicePointer',['../group__Memory.html#ga8fa7a0478020b835a24785cd6bb89725',1,'hip_runtime_api.h']]],
+ ['hiphostgetflags',['hipHostGetFlags',['../group__Memory.html#ga4d26915873b3e3534ceb4dc310f8709a',1,'hipHostGetFlags(unsigned int *flagsPtr, void *hostPtr): hip_memory.cpp'],['../group__Memory.html#ga4d26915873b3e3534ceb4dc310f8709a',1,'hipHostGetFlags(unsigned int *flagsPtr, void *hostPtr): hip_memory.cpp']]],
+ ['hiphostmalloc',['hipHostMalloc',['../group__Memory.html#gaad40bc7d97ccc799403ef5a9a8c246e1',1,'hipHostMalloc(void **ptr, size_t size, unsigned int flags): hip_memory.cpp'],['../group__Memory.html#gaad40bc7d97ccc799403ef5a9a8c246e1',1,'hipHostMalloc(void **ptr, size_t sizeBytes, unsigned int flags): hip_memory.cpp']]],
['hiphostmallocdefault',['hipHostMallocDefault',['../group__GlobalDefs.html#gad594ec51cb5b5e946c1e354bf80bddc7',1,'hip_runtime_api.h']]],
- ['hiphostregister',['hipHostRegister',['../group__Memory.html#gab8258f051e1a1f7385f794a15300e674',1,'hipHostRegister(void *hostPtr, size_t sizeBytes, unsigned int flags): hip_hcc.cpp'],['../group__Memory.html#gab8258f051e1a1f7385f794a15300e674',1,'hipHostRegister(void *hostPtr, size_t sizeBytes, unsigned int flags): hip_hcc.cpp'],['../group__Memory.html#gab8258f051e1a1f7385f794a15300e674',1,'hipHostRegister(void *hostPtr, size_t sizeBytes, unsigned int flags): hip_hcc2.cpp']]],
+ ['hiphostregister',['hipHostRegister',['../group__Memory.html#gab8258f051e1a1f7385f794a15300e674',1,'hipHostRegister(void *hostPtr, size_t sizeBytes, unsigned int flags): hip_memory.cpp'],['../group__Memory.html#gab8258f051e1a1f7385f794a15300e674',1,'hipHostRegister(void *hostPtr, size_t sizeBytes, unsigned int flags): hip_memory.cpp']]],
['hiphostregisterdefault',['hipHostRegisterDefault',['../group__GlobalDefs.html#gac7c100d241ff84ad10109bb00b7b25dc',1,'hip_runtime_api.h']]],
['hiphostregisteriomemory',['hipHostRegisterIoMemory',['../group__GlobalDefs.html#gaefa79f1b4481d6a1d1091c14b24f33d0',1,'hip_runtime_api.h']]],
['hiphostregistermapped',['hipHostRegisterMapped',['../group__GlobalDefs.html#gacfa4edcfcb39fc61bff6bdecb14d7618',1,'hip_runtime_api.h']]],
['hiphostregisterportable',['hipHostRegisterPortable',['../group__GlobalDefs.html#ga2db444f2315d412d3c7ba80ec6049583',1,'hip_runtime_api.h']]],
- ['hiphostunregister',['hipHostUnregister',['../group__Memory.html#ga4c9e1810b9f5858d36c4d28c91c86924',1,'hipHostUnregister(void *hostPtr): hip_hcc.cpp'],['../group__Memory.html#ga4c9e1810b9f5858d36c4d28c91c86924',1,'hipHostUnregister(void *hostPtr): hip_hcc.cpp'],['../group__Memory.html#ga4c9e1810b9f5858d36c4d28c91c86924',1,'hipHostUnregister(void *hostPtr): hip_hcc2.cpp']]],
- ['hipmalloc',['hipMalloc',['../group__Memory.html#ga4c6fcfe80010069d2792780d00dcead2',1,'hipMalloc(void **ptr, size_t size): hip_hcc.cpp'],['../group__Memory.html#ga4c6fcfe80010069d2792780d00dcead2',1,'hipMalloc(void **ptr, size_t sizeBytes): hip_hcc.cpp'],['../group__Memory.html#ga4c6fcfe80010069d2792780d00dcead2',1,'hipMalloc(void **ptr, size_t sizeBytes): hip_hcc2.cpp']]],
- ['hipmallochost',['hipMallocHost',['../group__Memory.html#gad3d3cdf82eb0058fc9eac1f939cd9d30',1,'hipMallocHost(void **ptr, size_t size) __attribute__((deprecated("use hipHostMalloc instead"))): hip_hcc.cpp'],['../group__Memory.html#gad3d3cdf82eb0058fc9eac1f939cd9d30',1,'hipMallocHost(void **ptr, size_t sizeBytes): hip_hcc.cpp'],['../group__Memory.html#gad3d3cdf82eb0058fc9eac1f939cd9d30',1,'hipMallocHost(void **ptr, size_t sizeBytes): hip_hcc2.cpp']]],
- ['hipmemcpy',['hipMemcpy',['../group__Memory.html#gac1a055d288302edd641c6d7416858e1e',1,'hipMemcpy(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind): hip_hcc.cpp'],['../group__Memory.html#gac1a055d288302edd641c6d7416858e1e',1,'hipMemcpy(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind): hip_hcc.cpp'],['../group__Memory.html#gac1a055d288302edd641c6d7416858e1e',1,'hipMemcpy(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind): hip_hcc2.cpp']]],
- ['hipmemcpyasync',['hipMemcpyAsync',['../group__Memory.html#ga8ad5a0b13458917e1b9437732b21af54',1,'hipMemcpyAsync(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind, hipStream_t stream=0): hip_hcc.cpp'],['../group__Memory.html#ga8ad5a0b13458917e1b9437732b21af54',1,'hipMemcpyAsync(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind, hipStream_t stream): hip_hcc.cpp'],['../group__Memory.html#ga8ad5a0b13458917e1b9437732b21af54',1,'hipMemcpyAsync(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind, hipStream_t stream): hip_hcc2.cpp']]],
+ ['hiphostunregister',['hipHostUnregister',['../group__Memory.html#ga4c9e1810b9f5858d36c4d28c91c86924',1,'hipHostUnregister(void *hostPtr): hip_memory.cpp'],['../group__Memory.html#ga4c9e1810b9f5858d36c4d28c91c86924',1,'hipHostUnregister(void *hostPtr): hip_memory.cpp']]],
+ ['hipmalloc',['hipMalloc',['../group__Memory.html#ga4c6fcfe80010069d2792780d00dcead2',1,'hipMalloc(void **ptr, size_t size): hip_memory.cpp'],['../group__Memory.html#ga4c6fcfe80010069d2792780d00dcead2',1,'hipMalloc(void **ptr, size_t sizeBytes): hip_memory.cpp']]],
+ ['hipmallochost',['hipMallocHost',['../group__Memory.html#gad3d3cdf82eb0058fc9eac1f939cd9d30',1,'hipMallocHost(void **ptr, size_t size) __attribute__((deprecated("use hipHostMalloc instead"))): hip_memory.cpp'],['../group__Memory.html#gad3d3cdf82eb0058fc9eac1f939cd9d30',1,'hipMallocHost(void **ptr, size_t sizeBytes): hip_memory.cpp']]],
+ ['hipmemcpy',['hipMemcpy',['../group__Memory.html#gac1a055d288302edd641c6d7416858e1e',1,'hipMemcpy(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind): hip_memory.cpp'],['../group__Memory.html#gac1a055d288302edd641c6d7416858e1e',1,'hipMemcpy(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind): hip_memory.cpp']]],
+ ['hipmemcpyasync',['hipMemcpyAsync',['../group__Memory.html#gad55fa9f5980b711bc93c52820149ba18',1,'hipMemcpyAsync(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind, hipStream_t stream): hip_memory.cpp'],['../group__Memory.html#gad55fa9f5980b711bc93c52820149ba18',1,'hipMemcpyAsync(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind, hipStream_t stream): hip_memory.cpp']]],
['hipmemcpydefault',['hipMemcpyDefault',['../group__GlobalDefs.html#gga232e222db36b1fc672ba98054d036a18a4e37107e416f79a2edf2b6534163c823',1,'hip_runtime_api.h']]],
['hipmemcpydevicetodevice',['hipMemcpyDeviceToDevice',['../group__GlobalDefs.html#gga232e222db36b1fc672ba98054d036a18abd05a09d3105e0ce25b34dd91cf83f88',1,'hip_runtime_api.h']]],
['hipmemcpydevicetohost',['hipMemcpyDeviceToHost',['../group__GlobalDefs.html#gga232e222db36b1fc672ba98054d036a18aba2505e9ce1e5382f17730bc670917d1',1,'hip_runtime_api.h']]],
['hipmemcpyhosttodevice',['hipMemcpyHostToDevice',['../group__GlobalDefs.html#gga232e222db36b1fc672ba98054d036a18aff32175ecb0c7113200286eff8211008',1,'hip_runtime_api.h']]],
['hipmemcpyhosttohost',['hipMemcpyHostToHost',['../group__GlobalDefs.html#gga232e222db36b1fc672ba98054d036a18a9d66b705aa85a9c83f0f533cef70d0af',1,'hip_runtime_api.h']]],
- ['hipmemcpykind',['hipMemcpyKind',['../group__GlobalDefs.html#ga232e222db36b1fc672ba98054d036a18',1,'hip_runtime_api.h']]],
- ['hipmemcpypeer',['hipMemcpyPeer',['../group__PeerToPeer.html#ga72ae9e7f498ab5684580892a5d7d8e2d',1,'hipMemcpyPeer(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes): hip_hcc.cpp'],['../group__PeerToPeer.html#ga72ae9e7f498ab5684580892a5d7d8e2d',1,'hipMemcpyPeer(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes): hip_hcc.cpp'],['../group__PeerToPeer.html#ga72ae9e7f498ab5684580892a5d7d8e2d',1,'hipMemcpyPeer(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes): hip_hcc2.cpp']]],
- ['hipmemcpypeerasync',['hipMemcpyPeerAsync',['../group__PeerToPeer.html#gab6211c18ca1e23252ef080cd6be855ca',1,'hipMemcpyPeerAsync(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream=0): hip_hcc.cpp'],['../group__PeerToPeer.html#gab6211c18ca1e23252ef080cd6be855ca',1,'hipMemcpyPeerAsync(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream): hip_hcc.cpp'],['../group__PeerToPeer.html#gab6211c18ca1e23252ef080cd6be855ca',1,'hipMemcpyPeerAsync(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream): hip_hcc2.cpp']]],
- ['hipmemcpytosymbol',['hipMemcpyToSymbol',['../group__Memory.html#ga131ac5c1ba04e186112491cb9bf964bc',1,'hipMemcpyToSymbol(const char *symbolName, const void *src, size_t sizeBytes, size_t offset, hipMemcpyKind kind): hip_hcc.cpp'],['../group__Memory.html#ga131ac5c1ba04e186112491cb9bf964bc',1,'hipMemcpyToSymbol(const char *symbolName, const void *src, size_t count, size_t offset, hipMemcpyKind kind): hip_hcc.cpp'],['../group__Memory.html#ga131ac5c1ba04e186112491cb9bf964bc',1,'hipMemcpyToSymbol(const char *symbolName, const void *src, size_t count, size_t offset, hipMemcpyKind kind): hip_hcc2.cpp']]],
- ['hipmemgetinfo',['hipMemGetInfo',['../group__Memory.html#ga311c3e246a21590de14478b8bd063be2',1,'hipMemGetInfo(size_t *free, size_t *total): hip_hcc.cpp'],['../group__Memory.html#ga311c3e246a21590de14478b8bd063be2',1,'hipMemGetInfo(size_t *free, size_t *total): hip_hcc.cpp'],['../group__Memory.html#ga311c3e246a21590de14478b8bd063be2',1,'hipMemGetInfo(size_t *free, size_t *total): hip_hcc2.cpp']]],
- ['hipmemset',['hipMemset',['../group__Memory.html#gac7441e74affcce4b8b69dba996c5ebc4',1,'hipMemset(void *dst, int value, size_t sizeBytes): hip_hcc.cpp'],['../group__Memory.html#gac7441e74affcce4b8b69dba996c5ebc4',1,'hipMemset(void *dst, int value, size_t sizeBytes): hip_hcc.cpp'],['../group__Memory.html#gac7441e74affcce4b8b69dba996c5ebc4',1,'hipMemset(void *dst, int value, size_t sizeBytes): hip_hcc2.cpp']]],
- ['hipmemsetasync',['hipMemsetAsync',['../group__Memory.html#gaee4ed665ce0a60c661a809c175320a0c',1,'hipMemsetAsync(void *dst, int value, size_t sizeBytes, hipStream_t=0): hip_hcc.cpp'],['../group__Memory.html#gaee4ed665ce0a60c661a809c175320a0c',1,'hipMemsetAsync(void *dst, int value, size_t sizeBytes, hipStream_t stream): hip_hcc.cpp'],['../group__Memory.html#gaee4ed665ce0a60c661a809c175320a0c',1,'hipMemsetAsync(void *dst, int value, size_t sizeBytes, hipStream_t stream): hip_hcc2.cpp']]],
+ ['hipmemcpykind',['hipMemcpyKind',['../group__GlobalDefs.html#ga232e222db36b1fc672ba98054d036a18',1,'hipMemcpyKind(): hip_runtime_api.h'],['../group__GlobalDefs.html#ga0c04e67413ce030817361f02673e5c85',1,'hipMemcpyKind(): hip_runtime_api.h']]],
+ ['hipmemcpypeer',['hipMemcpyPeer',['../group__PeerToPeer.html#ga5512f45e25c08052667c8ffe7162333b',1,'hipMemcpyPeer(void *dst, int dstDeviceId, const void *src, int srcDeviceId, size_t sizeBytes): hip_peer.cpp'],['../group__PeerToPeer.html#ga5512f45e25c08052667c8ffe7162333b',1,'hipMemcpyPeer(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes): hip_peer.cpp']]],
+ ['hipmemcpypeerasync',['hipMemcpyPeerAsync',['../group__PeerToPeer.html#ga216f951370c931d22e80c089ab724ed9',1,'hipMemcpyPeerAsync(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream): hip_peer.cpp'],['../group__PeerToPeer.html#ga216f951370c931d22e80c089ab724ed9',1,'hipMemcpyPeerAsync(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream): hip_peer.cpp']]],
+ ['hipmemcpytosymbol',['hipMemcpyToSymbol',['../group__Memory.html#ga131ac5c1ba04e186112491cb9bf964bc',1,'hipMemcpyToSymbol(const char *symbolName, const void *src, size_t sizeBytes, size_t offset, hipMemcpyKind kind): hip_memory.cpp'],['../group__Memory.html#ga131ac5c1ba04e186112491cb9bf964bc',1,'hipMemcpyToSymbol(const char *symbolName, const void *src, size_t count, size_t offset, hipMemcpyKind kind): hip_memory.cpp']]],
+ ['hipmemgetinfo',['hipMemGetInfo',['../group__Memory.html#ga311c3e246a21590de14478b8bd063be2',1,'hipMemGetInfo(size_t *free, size_t *total): hip_memory.cpp'],['../group__Memory.html#ga311c3e246a21590de14478b8bd063be2',1,'hipMemGetInfo(size_t *free, size_t *total): hip_memory.cpp']]],
+ ['hipmemset',['hipMemset',['../group__Memory.html#gac7441e74affcce4b8b69dba996c5ebc4',1,'hipMemset(void *dst, int value, size_t sizeBytes): hip_memory.cpp'],['../group__Memory.html#gac7441e74affcce4b8b69dba996c5ebc4',1,'hipMemset(void *dst, int value, size_t sizeBytes): hip_memory.cpp']]],
+ ['hipmemsetasync',['hipMemsetAsync',['../group__Memory.html#gae7d90e14c387e49f10db597f12915c54',1,'hipMemsetAsync(void *dst, int value, size_t sizeBytes, hipStream_t stream): hip_memory.cpp'],['../group__Memory.html#gae7d90e14c387e49f10db597f12915c54',1,'hipMemsetAsync(void *dst, int value, size_t sizeBytes, hipStream_t stream): hip_memory.cpp']]],
['hippeekatlasterror',['hipPeekAtLastError',['../group__Error.html#ga1dd660bc739f7e13edd34615660f0148',1,'hip_runtime_api.h']]],
['hippointerattribute_5ft',['hipPointerAttribute_t',['../structhipPointerAttribute__t.html',1,'']]],
- ['hippointergetattributes',['hipPointerGetAttributes',['../group__Memory.html#ga3d68ba64959615d4ab84f10caa12433b',1,'hipPointerGetAttributes(hipPointerAttribute_t *attributes, void *ptr): hip_hcc.cpp'],['../group__Memory.html#ga3d68ba64959615d4ab84f10caa12433b',1,'hipPointerGetAttributes(hipPointerAttribute_t *attributes, void *ptr): hip_hcc.cpp'],['../group__Memory.html#ga3d68ba64959615d4ab84f10caa12433b',1,'hipPointerGetAttributes(hipPointerAttribute_t *attributes, void *ptr): hip_hcc2.cpp']]],
+ ['hippointergetattributes',['hipPointerGetAttributes',['../group__Memory.html#ga3d68ba64959615d4ab84f10caa12433b',1,'hipPointerGetAttributes(hipPointerAttribute_t *attributes, void *ptr): hip_memory.cpp'],['../group__Memory.html#ga3d68ba64959615d4ab84f10caa12433b',1,'hipPointerGetAttributes(hipPointerAttribute_t *attributes, void *ptr): hip_memory.cpp']]],
['hipreadmodeelementtype',['hipReadModeElementType',['../hip__texture_8h.html#a442e950774f7306dc33692e358c92c94a829645801202174d052d667ffa4e1b8d',1,'hip_texture.h']]],
- ['hipsetdevice',['hipSetDevice',['../group__Device.html#ga8ec0b093af0adadc7fe98bf33fa21620',1,'hipSetDevice(int device): hip_hcc.cpp'],['../group__Device.html#ga8ec0b093af0adadc7fe98bf33fa21620',1,'hipSetDevice(int device): hip_hcc.cpp'],['../group__Device.html#ga8ec0b093af0adadc7fe98bf33fa21620',1,'hipSetDevice(int device): hip_hcc2.cpp']]],
+ ['hipsetdevice',['hipSetDevice',['../group__Device.html#ga8ec0b093af0adadc7fe98bf33fa21620',1,'hipSetDevice(int device): hip_device.cpp'],['../group__Device.html#ga8ec0b093af0adadc7fe98bf33fa21620',1,'hipSetDevice(int device): hip_device.cpp']]],
+ ['hipsetdeviceflags',['hipSetDeviceFlags',['../group__Device.html#ga6e54db382768827e84725632018307aa',1,'hip_runtime_api.h']]],
['hipsharedmembanksizedefault',['hipSharedMemBankSizeDefault',['../group__GlobalDefs.html#gga2e17b71d94ac350f2ccd914fd49d104eaf5b325c9b7bde878913f768eaba5014d',1,'hip_runtime_api.h']]],
['hipsharedmembanksizeeightbyte',['hipSharedMemBankSizeEightByte',['../group__GlobalDefs.html#gga2e17b71d94ac350f2ccd914fd49d104ea64518b4f5a25f536c883330167e79258',1,'hip_runtime_api.h']]],
['hipsharedmembanksizefourbyte',['hipSharedMemBankSizeFourByte',['../group__GlobalDefs.html#gga2e17b71d94ac350f2ccd914fd49d104ea0a95a6e0c33106c42d66ab9476ff954a',1,'hip_runtime_api.h']]],
['hipsharedmemconfig',['hipSharedMemConfig',['../group__GlobalDefs.html#ga2e17b71d94ac350f2ccd914fd49d104e',1,'hipSharedMemConfig(): hip_runtime_api.h'],['../group__GlobalDefs.html#ga6b1ca424fa26a5fb718937d662eaee7f',1,'hipSharedMemConfig(): hip_runtime_api.h']]],
- ['hipstreamcreatewithflags',['hipStreamCreateWithFlags',['../group__Stream.html#gaf2382e3cc6632332a8983a0f58e43494',1,'hipStreamCreateWithFlags(hipStream_t *stream, unsigned int flags): hip_hcc.cpp'],['../group__Stream.html#gaf2382e3cc6632332a8983a0f58e43494',1,'hipStreamCreateWithFlags(hipStream_t *stream, unsigned int flags): hip_hcc.cpp'],['../group__Stream.html#gaf2382e3cc6632332a8983a0f58e43494',1,'hipStreamCreateWithFlags(hipStream_t *stream, unsigned int flags): hip_hcc2.cpp']]],
+ ['hipstreamcreate',['hipStreamCreate',['../group__Stream.html#gaff5b62d6e9502d80879f7176f4d03102',1,'hipStreamCreate(hipStream_t *stream): hip_stream.cpp'],['../group__Stream.html#gaff5b62d6e9502d80879f7176f4d03102',1,'hipStreamCreate(hipStream_t *stream): hip_stream.cpp']]],
+ ['hipstreamcreatewithflags',['hipStreamCreateWithFlags',['../group__Stream.html#gaf2382e3cc6632332a8983a0f58e43494',1,'hipStreamCreateWithFlags(hipStream_t *stream, unsigned int flags): hip_stream.cpp'],['../group__Stream.html#gaf2382e3cc6632332a8983a0f58e43494',1,'hipStreamCreateWithFlags(hipStream_t *stream, unsigned int flags): hip_stream.cpp']]],
['hipstreamdefault',['hipStreamDefault',['../group__GlobalDefs.html#ga6df5f70eb976836ab3598cacf0ffcdf9',1,'hip_runtime_api.h']]],
- ['hipstreamdestroy',['hipStreamDestroy',['../group__Stream.html#ga3076a3499ed2c7821311006100bb95ec',1,'hipStreamDestroy(hipStream_t stream): hip_hcc.cpp'],['../group__Stream.html#ga3076a3499ed2c7821311006100bb95ec',1,'hipStreamDestroy(hipStream_t stream): hip_hcc.cpp'],['../group__Stream.html#ga3076a3499ed2c7821311006100bb95ec',1,'hipStreamDestroy(hipStream_t stream): hip_hcc2.cpp']]],
- ['hipstreamgetflags',['hipStreamGetFlags',['../group__Stream.html#ga3249555a26439591b8873f70b39bb116',1,'hipStreamGetFlags(hipStream_t stream, unsigned int *flags): hip_hcc.cpp'],['../group__Stream.html#ga3249555a26439591b8873f70b39bb116',1,'hipStreamGetFlags(hipStream_t stream, unsigned int *flags): hip_hcc.cpp'],['../group__Stream.html#ga3249555a26439591b8873f70b39bb116',1,'hipStreamGetFlags(hipStream_t stream, unsigned int *flags): hip_hcc2.cpp']]],
+ ['hipstreamdestroy',['hipStreamDestroy',['../group__Stream.html#ga3076a3499ed2c7821311006100bb95ec',1,'hipStreamDestroy(hipStream_t stream): hip_stream.cpp'],['../group__Stream.html#ga3076a3499ed2c7821311006100bb95ec',1,'hipStreamDestroy(hipStream_t stream): hip_stream.cpp']]],
+ ['hipstreamgetflags',['hipStreamGetFlags',['../group__Stream.html#ga3249555a26439591b8873f70b39bb116',1,'hipStreamGetFlags(hipStream_t stream, unsigned int *flags): hip_stream.cpp'],['../group__Stream.html#ga3249555a26439591b8873f70b39bb116',1,'hipStreamGetFlags(hipStream_t stream, unsigned int *flags): hip_stream.cpp']]],
['hipstreamnonblocking',['hipStreamNonBlocking',['../group__GlobalDefs.html#gaaba9ae995d9b43b7d1ee70c6fa12c57d',1,'hip_runtime_api.h']]],
- ['hipstreamsynchronize',['hipStreamSynchronize',['../group__Stream.html#gabbfb9f573a6ebe8c478605ecb5504a74',1,'hipStreamSynchronize(hipStream_t stream): hip_hcc.cpp'],['../group__Stream.html#gabbfb9f573a6ebe8c478605ecb5504a74',1,'hipStreamSynchronize(hipStream_t stream): hip_hcc.cpp'],['../group__Stream.html#gabbfb9f573a6ebe8c478605ecb5504a74',1,'hipStreamSynchronize(hipStream_t stream): hip_hcc2.cpp']]],
- ['hipstreamwaitevent',['hipStreamWaitEvent',['../group__Stream.html#gacdd84c8f8ef1539c96c57c1d5bcae633',1,'hipStreamWaitEvent(hipStream_t stream, hipEvent_t event, unsigned int flags): hip_hcc.cpp'],['../group__Stream.html#gacdd84c8f8ef1539c96c57c1d5bcae633',1,'hipStreamWaitEvent(hipStream_t stream, hipEvent_t event, unsigned int flags): hip_hcc.cpp'],['../group__Stream.html#gacdd84c8f8ef1539c96c57c1d5bcae633',1,'hipStreamWaitEvent(hipStream_t stream, hipEvent_t event, unsigned int flags): hip_hcc2.cpp']]],
+ ['hipstreamsynchronize',['hipStreamSynchronize',['../group__Stream.html#gabbfb9f573a6ebe8c478605ecb5504a74',1,'hipStreamSynchronize(hipStream_t stream): hip_stream.cpp'],['../group__Stream.html#gabbfb9f573a6ebe8c478605ecb5504a74',1,'hipStreamSynchronize(hipStream_t stream): hip_stream.cpp']]],
+ ['hipstreamwaitevent',['hipStreamWaitEvent',['../group__Stream.html#gacdd84c8f8ef1539c96c57c1d5bcae633',1,'hipStreamWaitEvent(hipStream_t stream, hipEvent_t event, unsigned int flags): hip_stream.cpp'],['../group__Stream.html#gacdd84c8f8ef1539c96c57c1d5bcae633',1,'hipStreamWaitEvent(hipStream_t stream, hipEvent_t event, unsigned int flags): hip_stream.cpp']]],
['hipsuccess',['hipSuccess',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594aadfbdb847b149723c684ebd764556063',1,'hip_runtime_api.h']]],
['hiptexturefiltermode',['hipTextureFilterMode',['../hip__texture_8h.html#aa2f0b6002b81d0a43a808cb880bb21e6',1,'hip_texture.h']]],
['hiptexturereadmode',['hipTextureReadMode',['../hip__texture_8h.html#a442e950774f7306dc33692e358c92c94',1,'hip_texture.h']]],
diff --git a/projects/hip/docs/RuntimeAPI/html/search/all_9.js b/projects/hip/docs/RuntimeAPI/html/search/all_9.js
index 9c19d12ead..ae0e44d79e 100644
--- a/projects/hip/docs/RuntimeAPI/html/search/all_9.js
+++ b/projects/hip/docs/RuntimeAPI/html/search/all_9.js
@@ -1,9 +1,13 @@
var searchData=
[
- ['ihipdevice_5ft',['ihipDevice_t',['../structihipDevice__t.html',1,'']]],
+ ['ihipdevice_5ft',['ihipDevice_t',['../classihipDevice__t.html',1,'']]],
+ ['ihipdevicecriticalbase_5ft',['ihipDeviceCriticalBase_t',['../classihipDeviceCriticalBase__t.html',1,'']]],
+ ['ihipdevicecriticalbase_5ft_3c_20devicemutex_20_3e',['ihipDeviceCriticalBase_t< DeviceMutex >',['../classihipDeviceCriticalBase__t.html',1,'']]],
['ihipevent_5ft',['ihipEvent_t',['../structihipEvent__t.html',1,'']]],
['ihipexception',['ihipException',['../classihipException.html',1,'']]],
['ihipsignal_5ft',['ihipSignal_t',['../structihipSignal__t.html',1,'']]],
['ihipstream_5ft',['ihipStream_t',['../classihipStream__t.html',1,'']]],
+ ['ihipstreamcriticalbase_5ft',['ihipStreamCriticalBase_t',['../classihipStreamCriticalBase__t.html',1,'']]],
+ ['ihipstreamcriticalbase_5ft_3c_20streammutex_20_3e',['ihipStreamCriticalBase_t< StreamMutex >',['../classihipStreamCriticalBase__t.html',1,'']]],
['ismultigpuboard',['isMultiGpuBoard',['../structhipDeviceProp__t.html#a9bb19b2b0cdee8977ed63964532d639d',1,'hipDeviceProp_t']]]
];
diff --git a/projects/hip/docs/RuntimeAPI/html/search/all_a.js b/projects/hip/docs/RuntimeAPI/html/search/all_a.js
index 41a7c59602..8cf55c56bd 100644
--- a/projects/hip/docs/RuntimeAPI/html/search/all_a.js
+++ b/projects/hip/docs/RuntimeAPI/html/search/all_a.js
@@ -1,4 +1,8 @@
var searchData=
[
- ['l2cachesize',['l2CacheSize',['../structhipDeviceProp__t.html#a24404decccc16833973c803ced6f3a51',1,'hipDeviceProp_t']]]
+ ['l2cachesize',['l2CacheSize',['../structhipDeviceProp__t.html#a24404decccc16833973c803ced6f3a51',1,'hipDeviceProp_t']]],
+ ['lockedaccessor',['LockedAccessor',['../classLockedAccessor.html',1,'']]],
+ ['lockedbase',['LockedBase',['../structLockedBase.html',1,'']]],
+ ['lockedbase_3c_20devicemutex_20_3e',['LockedBase< DeviceMutex >',['../structLockedBase.html',1,'']]],
+ ['lockedbase_3c_20streammutex_20_3e',['LockedBase< StreamMutex >',['../structLockedBase.html',1,'']]]
];
diff --git a/projects/hip/docs/RuntimeAPI/html/search/classes_3.js b/projects/hip/docs/RuntimeAPI/html/search/classes_3.js
index 7b99529bec..87ba8606aa 100644
--- a/projects/hip/docs/RuntimeAPI/html/search/classes_3.js
+++ b/projects/hip/docs/RuntimeAPI/html/search/classes_3.js
@@ -1,8 +1,12 @@
var searchData=
[
- ['ihipdevice_5ft',['ihipDevice_t',['../structihipDevice__t.html',1,'']]],
+ ['ihipdevice_5ft',['ihipDevice_t',['../classihipDevice__t.html',1,'']]],
+ ['ihipdevicecriticalbase_5ft',['ihipDeviceCriticalBase_t',['../classihipDeviceCriticalBase__t.html',1,'']]],
+ ['ihipdevicecriticalbase_5ft_3c_20devicemutex_20_3e',['ihipDeviceCriticalBase_t< DeviceMutex >',['../classihipDeviceCriticalBase__t.html',1,'']]],
['ihipevent_5ft',['ihipEvent_t',['../structihipEvent__t.html',1,'']]],
['ihipexception',['ihipException',['../classihipException.html',1,'']]],
['ihipsignal_5ft',['ihipSignal_t',['../structihipSignal__t.html',1,'']]],
- ['ihipstream_5ft',['ihipStream_t',['../classihipStream__t.html',1,'']]]
+ ['ihipstream_5ft',['ihipStream_t',['../classihipStream__t.html',1,'']]],
+ ['ihipstreamcriticalbase_5ft',['ihipStreamCriticalBase_t',['../classihipStreamCriticalBase__t.html',1,'']]],
+ ['ihipstreamcriticalbase_5ft_3c_20streammutex_20_3e',['ihipStreamCriticalBase_t< StreamMutex >',['../classihipStreamCriticalBase__t.html',1,'']]]
];
diff --git a/projects/hip/docs/RuntimeAPI/html/search/classes_4.js b/projects/hip/docs/RuntimeAPI/html/search/classes_4.js
index 7708af376c..09019c00b4 100644
--- a/projects/hip/docs/RuntimeAPI/html/search/classes_4.js
+++ b/projects/hip/docs/RuntimeAPI/html/search/classes_4.js
@@ -1,4 +1,7 @@
var searchData=
[
- ['stagingbuffer',['StagingBuffer',['../structStagingBuffer.html',1,'']]]
+ ['lockedaccessor',['LockedAccessor',['../classLockedAccessor.html',1,'']]],
+ ['lockedbase',['LockedBase',['../structLockedBase.html',1,'']]],
+ ['lockedbase_3c_20devicemutex_20_3e',['LockedBase< DeviceMutex >',['../structLockedBase.html',1,'']]],
+ ['lockedbase_3c_20streammutex_20_3e',['LockedBase< StreamMutex >',['../structLockedBase.html',1,'']]]
];
diff --git a/projects/hip/docs/RuntimeAPI/html/search/classes_5.js b/projects/hip/docs/RuntimeAPI/html/search/classes_5.js
index 67b71f7499..7708af376c 100644
--- a/projects/hip/docs/RuntimeAPI/html/search/classes_5.js
+++ b/projects/hip/docs/RuntimeAPI/html/search/classes_5.js
@@ -1,5 +1,4 @@
var searchData=
[
- ['texture',['texture',['../structtexture.html',1,'']]],
- ['texturereference',['textureReference',['../structtextureReference.html',1,'']]]
+ ['stagingbuffer',['StagingBuffer',['../structStagingBuffer.html',1,'']]]
];
diff --git a/projects/hip/docs/RuntimeAPI/html/search/classes_6.js b/projects/hip/docs/RuntimeAPI/html/search/classes_6.js
index e2e16672fb..8ced671759 100644
--- a/projects/hip/docs/RuntimeAPI/html/search/classes_6.js
+++ b/projects/hip/docs/RuntimeAPI/html/search/classes_6.js
@@ -1,4 +1,4 @@
var searchData=
[
- ['short1',['short1',['../structshort1.html',1,'']]]
+ ['texturereference',['textureReference',['../structtextureReference.html',1,'']]]
];
diff --git a/projects/hip/docs/RuntimeAPI/html/search/classes_7.html b/projects/hip/docs/RuntimeAPI/html/search/classes_7.html
deleted file mode 100644
index 9e5f5c9861..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/search/classes_7.html
+++ /dev/null
@@ -1,26 +0,0 @@
-
-|
+ HIP: Heterogenous-computing Interface for Portability
+
+ |
+
+ 1.8.6
+
+
+
diff --git a/projects/hip/docs/RuntimeAPI/html/structchar1-members.html b/projects/hip/docs/RuntimeAPI/html/structLockedBase-members.html
similarity index 71%
rename from projects/hip/docs/RuntimeAPI/html/structchar1-members.html
rename to projects/hip/docs/RuntimeAPI/html/structLockedBase-members.html
index b618c69432..f61745aef7 100644
--- a/projects/hip/docs/RuntimeAPI/html/structchar1-members.html
+++ b/projects/hip/docs/RuntimeAPI/html/structLockedBase-members.html
@@ -72,7 +72,7 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
onmouseover="return searchBox.OnSearchSelectShow()"
onmouseout="return searchBox.OnSearchSelectHide()"
onkeydown="return searchBox.OnSearchSelectKey(event)">
- All Classes Files Functions Variables Enumerations Enumerator Macros Groups Pages
+ All Classes Files Functions Variables Typedefs Enumerations Enumerator Macros Groups Pages
This is the complete list of members for char1, including all inherited members.
+This is the complete list of members for LockedBase< MUTEX_TYPE >, including all inherited members.
| x (defined in char1) | char1 | |
| _mutex (defined in LockedBase< MUTEX_TYPE >) | LockedBase< MUTEX_TYPE > | |
| lock() (defined in LockedBase< MUTEX_TYPE >) | LockedBase< MUTEX_TYPE > | inline |
| unlock() (defined in LockedBase< MUTEX_TYPE >) | LockedBase< MUTEX_TYPE > | inline |
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structtexture.html b/projects/hip/docs/RuntimeAPI/html/structLockedBase.html
similarity index 66%
rename from projects/hip/docs/RuntimeAPI/html/structtexture.html
rename to projects/hip/docs/RuntimeAPI/html/structLockedBase.html
index a904f4e7d8..989ab46e91 100644
--- a/projects/hip/docs/RuntimeAPI/html/structtexture.html
+++ b/projects/hip/docs/RuntimeAPI/html/structLockedBase.html
@@ -4,7 +4,7 @@
-
- +Public Member Functions | |
| +void | lock () |
| +void | unlock () |
Public Attributes | |
| -const T * | _dataPtr |
Public Attributes inherited from textureReference | |
| -hipTextureFilterMode | filterMode |
| -bool | normalized |
| -hipChannelFormatDesc | channelDesc |
| +MUTEX_TYPE | _mutex |
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structLockedBase.png b/projects/hip/docs/RuntimeAPI/html/structLockedBase.png
new file mode 100644
index 0000000000..9677c74a19
Binary files /dev/null and b/projects/hip/docs/RuntimeAPI/html/structLockedBase.png differ
diff --git a/projects/hip/docs/RuntimeAPI/html/structStagingBuffer-members.html b/projects/hip/docs/RuntimeAPI/html/structStagingBuffer-members.html
new file mode 100644
index 0000000000..4f4e5a39b8
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/structStagingBuffer-members.html
@@ -0,0 +1,108 @@
+
+
+
+
+
+
+|
+ HIP: Heterogenous-computing Interface for Portability
+
+ |
+
This is the complete list of members for StagingBuffer, including all inherited members.
+| _max_buffers (defined in StagingBuffer) | StagingBuffer | static |
| CopyDeviceToHost(void *dst, const void *src, size_t sizeBytes, hsa_signal_t *waitFor) (defined in StagingBuffer) | StagingBuffer | |
| CopyDeviceToHostPinInPlace(void *dst, const void *src, size_t sizeBytes, hsa_signal_t *waitFor) (defined in StagingBuffer) | StagingBuffer | |
| CopyHostToDevice(void *dst, const void *src, size_t sizeBytes, hsa_signal_t *waitFor) (defined in StagingBuffer) | StagingBuffer | |
| CopyHostToDevicePinInPlace(void *dst, const void *src, size_t sizeBytes, hsa_signal_t *waitFor) (defined in StagingBuffer) | StagingBuffer | |
| StagingBuffer(hsa_agent_t hsaAgent, hsa_region_t systemRegion, size_t bufferSize, int numBuffers) (defined in StagingBuffer) | StagingBuffer | |
| ~StagingBuffer() (defined in StagingBuffer) | StagingBuffer |
+ 1.8.6
+
+
+
diff --git a/projects/hip/docs/RuntimeAPI/html/structStagingBuffer.html b/projects/hip/docs/RuntimeAPI/html/structStagingBuffer.html
new file mode 100644
index 0000000000..e42819ba22
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/structStagingBuffer.html
@@ -0,0 +1,131 @@
+
+
+
+
+
+
+|
+ HIP: Heterogenous-computing Interface for Portability
+
+ |
+
+Public Member Functions | |
| + | StagingBuffer (hsa_agent_t hsaAgent, hsa_region_t systemRegion, size_t bufferSize, int numBuffers) |
| +void | CopyHostToDevice (void *dst, const void *src, size_t sizeBytes, hsa_signal_t *waitFor) |
| +void | CopyHostToDevicePinInPlace (void *dst, const void *src, size_t sizeBytes, hsa_signal_t *waitFor) |
| +void | CopyDeviceToHost (void *dst, const void *src, size_t sizeBytes, hsa_signal_t *waitFor) |
| +void | CopyDeviceToHostPinInPlace (void *dst, const void *src, size_t sizeBytes, hsa_signal_t *waitFor) |
+Static Public Attributes | |
| +static const int | _max_buffers = 4 |
+ 1.8.6
+
+
+
diff --git a/projects/hip/docs/RuntimeAPI/html/structchar1.html b/projects/hip/docs/RuntimeAPI/html/structchar1.html
deleted file mode 100644
index e0e553098d..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structchar1.html
+++ /dev/null
@@ -1,111 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -char | x |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structchar2-members.html b/projects/hip/docs/RuntimeAPI/html/structchar2-members.html
deleted file mode 100644
index 8fa9a8ee43..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structchar2-members.html
+++ /dev/null
@@ -1,103 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for char2, including all inherited members.
-| x (defined in char2) | char2 | |
| y (defined in char2) | char2 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structchar2.html b/projects/hip/docs/RuntimeAPI/html/structchar2.html
deleted file mode 100644
index d7ccd64d98..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structchar2.html
+++ /dev/null
@@ -1,114 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -char | x |
| -char | y |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structchar3-members.html b/projects/hip/docs/RuntimeAPI/html/structchar3-members.html
deleted file mode 100644
index 978710913c..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structchar3-members.html
+++ /dev/null
@@ -1,104 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for char3, including all inherited members.
-| x (defined in char3) | char3 | |
| y (defined in char3) | char3 | |
| z (defined in char3) | char3 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structchar4-members.html b/projects/hip/docs/RuntimeAPI/html/structchar4-members.html
deleted file mode 100644
index a5f97d7a05..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structchar4-members.html
+++ /dev/null
@@ -1,105 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for char4, including all inherited members.
-| w (defined in char4) | char4 | |
| x (defined in char4) | char4 | |
| y (defined in char4) | char4 | |
| z (defined in char4) | char4 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structchar4.html b/projects/hip/docs/RuntimeAPI/html/structchar4.html
deleted file mode 100644
index a303937bad..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structchar4.html
+++ /dev/null
@@ -1,120 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -char | x |
| -char | y |
| -char | z |
| -char | w |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structdim3-members.html b/projects/hip/docs/RuntimeAPI/html/structdim3-members.html
index 8d97c64f1c..d032c0681f 100644
--- a/projects/hip/docs/RuntimeAPI/html/structdim3-members.html
+++ b/projects/hip/docs/RuntimeAPI/html/structdim3-members.html
@@ -90,14 +90,13 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
This is the complete list of members for dim3, including all inherited members.
| dim3(uint32_t _x=1, uint32_t _y=1, uint32_t _z=1) (defined in dim3) | dim3 | inline |
| x | dim3 | |
| y | dim3 | |
| z | dim3 | |
| x | dim3 | |
| y | dim3 | |
| z | dim3 |
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structdim3.html b/projects/hip/docs/RuntimeAPI/html/structdim3.html
index 6cfaad88ee..09fd3810a8 100644
--- a/projects/hip/docs/RuntimeAPI/html/structdim3.html
+++ b/projects/hip/docs/RuntimeAPI/html/structdim3.html
@@ -84,7 +84,6 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
#include <hip_runtime_api.h>
-Public Member Functions | |
| - | dim3 (uint32_t _x=1, uint32_t _y=1, uint32_t _z=1) |
Public Attributes | |||||||||||||||||||||||
| @@ -118,12 +111,12 @@ uint32_t | Detailed DescriptionStruct for data in 3D The documentation for this struct was generated from the following file:
-Generated on Wed Mar 23 2016 23:11:07 for HIP: Heterogenous-computing Interface for Portability by +Generated on Sat Apr 16 2016 14:52:10 for HIP: Heterogenous-computing Interface for Portability by
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structdouble1-members.html b/projects/hip/docs/RuntimeAPI/html/structdouble1-members.html
deleted file mode 100644
index f4f400e1fa..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structdouble1-members.html
+++ /dev/null
@@ -1,102 +0,0 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-double1 Member List
-
-
-
-This is the complete list of members for double1, including all inherited members. -
-Generated on Sat Jan 16 2016 05:08:52 for HIP: Heterogenous-computing Interface for Portability by -
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structdouble1.html b/projects/hip/docs/RuntimeAPI/html/structdouble1.html
deleted file mode 100644
index 3441ab9e4c..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structdouble1.html
+++ /dev/null
@@ -1,111 +0,0 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-double1 Struct Reference
-
-
-
The documentation for this struct was generated from the following file:
-Generated on Sat Jan 16 2016 05:08:52 for HIP: Heterogenous-computing Interface for Portability by -
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structfloat1-members.html b/projects/hip/docs/RuntimeAPI/html/structfloat1-members.html
deleted file mode 100644
index 944fcad6bf..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structfloat1-members.html
+++ /dev/null
@@ -1,102 +0,0 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-float1 Member List
-
-
-
-This is the complete list of members for float1, including all inherited members. -
-Generated on Sat Jan 16 2016 05:08:52 for HIP: Heterogenous-computing Interface for Portability by -
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structfloat1.html b/projects/hip/docs/RuntimeAPI/html/structfloat1.html
deleted file mode 100644
index 0220f939d6..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structfloat1.html
+++ /dev/null
@@ -1,111 +0,0 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-float1 Struct Reference
-
-
-
The documentation for this struct was generated from the following file:
-Generated on Sat Jan 16 2016 05:08:52 for HIP: Heterogenous-computing Interface for Portability by -
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structhipChannelFormatDesc-members.html b/projects/hip/docs/RuntimeAPI/html/structhipChannelFormatDesc-members.html
index bd5d2c1651..39c50e6d86 100644
--- a/projects/hip/docs/RuntimeAPI/html/structhipChannelFormatDesc-members.html
+++ b/projects/hip/docs/RuntimeAPI/html/structhipChannelFormatDesc-members.html
@@ -94,7 +94,7 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
| ||||||||||||||||||||||
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structhipChannelFormatDesc.html b/projects/hip/docs/RuntimeAPI/html/structhipChannelFormatDesc.html
index c6c6e9ee5b..c41de11d98 100644
--- a/projects/hip/docs/RuntimeAPI/html/structhipChannelFormatDesc.html
+++ b/projects/hip/docs/RuntimeAPI/html/structhipChannelFormatDesc.html
@@ -98,12 +98,12 @@ int
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structhipDeviceArch__t-members.html b/projects/hip/docs/RuntimeAPI/html/structhipDeviceArch__t-members.html
index d04626c34d..0e942bc0f6 100644
--- a/projects/hip/docs/RuntimeAPI/html/structhipDeviceArch__t-members.html
+++ b/projects/hip/docs/RuntimeAPI/html/structhipDeviceArch__t-members.html
@@ -110,7 +110,7 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structhipDeviceArch__t.html b/projects/hip/docs/RuntimeAPI/html/structhipDeviceArch__t.html
index d09c7d3c6d..6f4c668d1a 100644
--- a/projects/hip/docs/RuntimeAPI/html/structhipDeviceArch__t.html
+++ b/projects/hip/docs/RuntimeAPI/html/structhipDeviceArch__t.html
@@ -163,12 +163,12 @@ unsigned
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structhipDeviceProp__t-members.html b/projects/hip/docs/RuntimeAPI/html/structhipDeviceProp__t-members.html
index 4dc810d670..192f0b81d3 100644
--- a/projects/hip/docs/RuntimeAPI/html/structhipDeviceProp__t-members.html
+++ b/projects/hip/docs/RuntimeAPI/html/structhipDeviceProp__t-members.html
@@ -119,7 +119,7 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structhipDeviceProp__t.html b/projects/hip/docs/RuntimeAPI/html/structhipDeviceProp__t.html
index 913cab44ed..fdf4a3eb4a 100644
--- a/projects/hip/docs/RuntimeAPI/html/structhipDeviceProp__t.html
+++ b/projects/hip/docs/RuntimeAPI/html/structhipDeviceProp__t.html
@@ -203,12 +203,12 @@ int hipDeviceProp
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structhipEvent__t-members.html b/projects/hip/docs/RuntimeAPI/html/structhipEvent__t-members.html
index 9f26bc8827..2b65f6f763 100644
--- a/projects/hip/docs/RuntimeAPI/html/structhipEvent__t-members.html
+++ b/projects/hip/docs/RuntimeAPI/html/structhipEvent__t-members.html
@@ -94,7 +94,7 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structhipEvent__t.html b/projects/hip/docs/RuntimeAPI/html/structhipEvent__t.html
index 5513b7a405..cf54bdab84 100644
--- a/projects/hip/docs/RuntimeAPI/html/structhipEvent__t.html
+++ b/projects/hip/docs/RuntimeAPI/html/structhipEvent__t.html
@@ -98,12 +98,12 @@ struct ihipEvent_t *
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structhipPointerAttribute__t-members.html b/projects/hip/docs/RuntimeAPI/html/structhipPointerAttribute__t-members.html
new file mode 100644
index 0000000000..eef653815e
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/structhipPointerAttribute__t-members.html
@@ -0,0 +1,107 @@
+
+
+
+
+
+
+|
+ HIP: Heterogenous-computing Interface for Portability
+
+ |
+
This is the complete list of members for hipPointerAttribute_t, including all inherited members.
+| allocationFlags (defined in hipPointerAttribute_t) | hipPointerAttribute_t | |
| device (defined in hipPointerAttribute_t) | hipPointerAttribute_t | |
| devicePointer (defined in hipPointerAttribute_t) | hipPointerAttribute_t | |
| hostPointer (defined in hipPointerAttribute_t) | hipPointerAttribute_t | |
| isManaged (defined in hipPointerAttribute_t) | hipPointerAttribute_t | |
| memoryType (defined in hipPointerAttribute_t) | hipPointerAttribute_t |
+ 1.8.6
+
+
+
diff --git a/projects/hip/docs/RuntimeAPI/html/structhipPointerAttribute__t.html b/projects/hip/docs/RuntimeAPI/html/structhipPointerAttribute__t.html
new file mode 100644
index 0000000000..87021957d5
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/structhipPointerAttribute__t.html
@@ -0,0 +1,130 @@
+
+
+
+
+
+
+|
+ HIP: Heterogenous-computing Interface for Portability
+
+ |
+
#include <hip_runtime_api.h>
+Public Attributes | |
| +enum hipMemoryType | memoryType |
| +int | device |
| +void * | devicePointer |
| +void * | hostPointer |
| +int | isManaged |
| +unsigned | allocationFlags |
Pointer attributes
+
+ 1.8.6
+
+
+
diff --git a/projects/hip/docs/RuntimeAPI/html/structihipEvent__t-members.html b/projects/hip/docs/RuntimeAPI/html/structihipEvent__t-members.html
index 7035ef34e3..7623e17249 100644
--- a/projects/hip/docs/RuntimeAPI/html/structihipEvent__t-members.html
+++ b/projects/hip/docs/RuntimeAPI/html/structihipEvent__t-members.html
@@ -99,7 +99,7 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structihipEvent__t.html b/projects/hip/docs/RuntimeAPI/html/structihipEvent__t.html
index b0f9f2c7ef..26b4c2a9cf 100644
--- a/projects/hip/docs/RuntimeAPI/html/structihipEvent__t.html
+++ b/projects/hip/docs/RuntimeAPI/html/structihipEvent__t.html
@@ -112,14 +112,13 @@ uint64_t
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structihipSignal__t-members.html b/projects/hip/docs/RuntimeAPI/html/structihipSignal__t-members.html
new file mode 100644
index 0000000000..6461109109
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/structihipSignal__t-members.html
@@ -0,0 +1,107 @@
+
+
+
+
+
+
+|
+ HIP: Heterogenous-computing Interface for Portability
+
+ |
+
This is the complete list of members for ihipSignal_t, including all inherited members.
+| _hsa_signal (defined in ihipSignal_t) | ihipSignal_t | |
| _index (defined in ihipSignal_t) | ihipSignal_t | |
| _sig_id (defined in ihipSignal_t) | ihipSignal_t | |
| ihipSignal_t() (defined in ihipSignal_t) | ihipSignal_t | |
| release() (defined in ihipSignal_t) | ihipSignal_t | |
| ~ihipSignal_t() (defined in ihipSignal_t) | ihipSignal_t |
+ 1.8.6
+
+
+
diff --git a/projects/hip/docs/RuntimeAPI/html/structihipStream__t.html b/projects/hip/docs/RuntimeAPI/html/structihipSignal__t.html
similarity index 77%
rename from projects/hip/docs/RuntimeAPI/html/structihipStream__t.html
rename to projects/hip/docs/RuntimeAPI/html/structihipSignal__t.html
index 264d5ffd81..6d1372a29d 100644
--- a/projects/hip/docs/RuntimeAPI/html/structihipStream__t.html
+++ b/projects/hip/docs/RuntimeAPI/html/structihipSignal__t.html
@@ -4,7 +4,7 @@
-Public Member Functions | |
| - | ihipStream_t (unsigned device_index, hc::accelerator_view av, unsigned int flags) |
| +void | release () |
Public Attributes | |
| -unsigned | _device_index |
| -hc::accelerator_view | _av |
| -unsigned | _flags |
| -ihipCommand_t | _last_command |
| +hsa_signal_t | _hsa_signal |
| +int | _index |
| +SIGSEQNUM | _sig_id |
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structint1-members.html b/projects/hip/docs/RuntimeAPI/html/structint1-members.html
deleted file mode 100644
index 196b794b05..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structint1-members.html
+++ /dev/null
@@ -1,102 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for int1, including all inherited members.
-| x (defined in int1) | int1 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structint1.html b/projects/hip/docs/RuntimeAPI/html/structint1.html
deleted file mode 100644
index 927f152743..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structint1.html
+++ /dev/null
@@ -1,111 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -int | x |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structlong1-members.html b/projects/hip/docs/RuntimeAPI/html/structlong1-members.html
deleted file mode 100644
index c8e0926d51..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structlong1-members.html
+++ /dev/null
@@ -1,102 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for long1, including all inherited members.
-| x (defined in long1) | long1 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structlong1.html b/projects/hip/docs/RuntimeAPI/html/structlong1.html
deleted file mode 100644
index 632e9e5a74..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structlong1.html
+++ /dev/null
@@ -1,111 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -long | x |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structlong2-members.html b/projects/hip/docs/RuntimeAPI/html/structlong2-members.html
deleted file mode 100644
index e11171e23e..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structlong2-members.html
+++ /dev/null
@@ -1,103 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for long2, including all inherited members.
-| x (defined in long2) | long2 | |
| y (defined in long2) | long2 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structlong2.html b/projects/hip/docs/RuntimeAPI/html/structlong2.html
deleted file mode 100644
index 004fa1f3fa..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structlong2.html
+++ /dev/null
@@ -1,114 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -long | x |
| -long | y |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structlong3-members.html b/projects/hip/docs/RuntimeAPI/html/structlong3-members.html
deleted file mode 100644
index 1546f481c4..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structlong3-members.html
+++ /dev/null
@@ -1,104 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for long3, including all inherited members.
-| x (defined in long3) | long3 | |
| y (defined in long3) | long3 | |
| z (defined in long3) | long3 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structlong3.html b/projects/hip/docs/RuntimeAPI/html/structlong3.html
deleted file mode 100644
index 228ab4bb71..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structlong3.html
+++ /dev/null
@@ -1,117 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -long | x |
| -long | y |
| -long | z |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structlong4-members.html b/projects/hip/docs/RuntimeAPI/html/structlong4-members.html
deleted file mode 100644
index c05faa32fb..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structlong4-members.html
+++ /dev/null
@@ -1,105 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for long4, including all inherited members.
-| w (defined in long4) | long4 | |
| x (defined in long4) | long4 | |
| y (defined in long4) | long4 | |
| z (defined in long4) | long4 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structlong4.html b/projects/hip/docs/RuntimeAPI/html/structlong4.html
deleted file mode 100644
index 8cf6b0e925..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structlong4.html
+++ /dev/null
@@ -1,120 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -long | x |
| -long | y |
| -long | z |
| -long | w |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structlonglong1-members.html b/projects/hip/docs/RuntimeAPI/html/structlonglong1-members.html
deleted file mode 100644
index cc8483c650..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structlonglong1-members.html
+++ /dev/null
@@ -1,102 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for longlong1, including all inherited members.
-| x (defined in longlong1) | longlong1 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structlonglong1.html b/projects/hip/docs/RuntimeAPI/html/structlonglong1.html
deleted file mode 100644
index f347efcba4..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structlonglong1.html
+++ /dev/null
@@ -1,111 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -long long | x |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structlonglong2-members.html b/projects/hip/docs/RuntimeAPI/html/structlonglong2-members.html
deleted file mode 100644
index d60b7542b7..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structlonglong2-members.html
+++ /dev/null
@@ -1,103 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for longlong2, including all inherited members.
-| x (defined in longlong2) | longlong2 | |
| y (defined in longlong2) | longlong2 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structlonglong2.html b/projects/hip/docs/RuntimeAPI/html/structlonglong2.html
deleted file mode 100644
index 2aae373a41..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structlonglong2.html
+++ /dev/null
@@ -1,114 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -long long | x |
| -long long | y |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structlonglong3-members.html b/projects/hip/docs/RuntimeAPI/html/structlonglong3-members.html
deleted file mode 100644
index 71f382899c..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structlonglong3-members.html
+++ /dev/null
@@ -1,104 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for longlong3, including all inherited members.
-| x (defined in longlong3) | longlong3 | |
| y (defined in longlong3) | longlong3 | |
| z (defined in longlong3) | longlong3 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structlonglong3.html b/projects/hip/docs/RuntimeAPI/html/structlonglong3.html
deleted file mode 100644
index 7ffce23e52..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structlonglong3.html
+++ /dev/null
@@ -1,117 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -long long | x |
| -long long | y |
| -long long | z |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structlonglong4-members.html b/projects/hip/docs/RuntimeAPI/html/structlonglong4-members.html
deleted file mode 100644
index 797d534178..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structlonglong4-members.html
+++ /dev/null
@@ -1,105 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for longlong4, including all inherited members.
-| w (defined in longlong4) | longlong4 | |
| x (defined in longlong4) | longlong4 | |
| y (defined in longlong4) | longlong4 | |
| z (defined in longlong4) | longlong4 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structlonglong4.html b/projects/hip/docs/RuntimeAPI/html/structlonglong4.html
deleted file mode 100644
index bfe3df64b5..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structlonglong4.html
+++ /dev/null
@@ -1,120 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -long long | x |
| -long long | y |
| -long long | z |
| -long long | w |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structshort1-members.html b/projects/hip/docs/RuntimeAPI/html/structshort1-members.html
deleted file mode 100644
index 4e4a62fe07..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structshort1-members.html
+++ /dev/null
@@ -1,102 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for short1, including all inherited members.
-| x (defined in short1) | short1 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structshort1.html b/projects/hip/docs/RuntimeAPI/html/structshort1.html
deleted file mode 100644
index c2e9809d03..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structshort1.html
+++ /dev/null
@@ -1,111 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -short | x |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structshort2-members.html b/projects/hip/docs/RuntimeAPI/html/structshort2-members.html
deleted file mode 100644
index cb6de02834..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structshort2-members.html
+++ /dev/null
@@ -1,103 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for short2, including all inherited members.
-| x (defined in short2) | short2 | |
| y (defined in short2) | short2 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structshort2.html b/projects/hip/docs/RuntimeAPI/html/structshort2.html
deleted file mode 100644
index 48067316f6..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structshort2.html
+++ /dev/null
@@ -1,114 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -short | x |
| -short | y |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structshort3-members.html b/projects/hip/docs/RuntimeAPI/html/structshort3-members.html
deleted file mode 100644
index 7b07235a40..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structshort3-members.html
+++ /dev/null
@@ -1,104 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for short3, including all inherited members.
-| x (defined in short3) | short3 | |
| y (defined in short3) | short3 | |
| z (defined in short3) | short3 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structshort3.html b/projects/hip/docs/RuntimeAPI/html/structshort3.html
deleted file mode 100644
index b7c9d15748..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structshort3.html
+++ /dev/null
@@ -1,117 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -short | x |
| -short | y |
| -short | z |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structshort4-members.html b/projects/hip/docs/RuntimeAPI/html/structshort4-members.html
deleted file mode 100644
index 43b44879e2..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structshort4-members.html
+++ /dev/null
@@ -1,105 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for short4, including all inherited members.
-| w (defined in short4) | short4 | |
| x (defined in short4) | short4 | |
| y (defined in short4) | short4 | |
| z (defined in short4) | short4 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structshort4.html b/projects/hip/docs/RuntimeAPI/html/structshort4.html
deleted file mode 100644
index 86a8622443..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structshort4.html
+++ /dev/null
@@ -1,120 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -short | x |
| -short | y |
| -short | z |
| -short | w |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structtexture.png b/projects/hip/docs/RuntimeAPI/html/structtexture.png
deleted file mode 100644
index 3a32b1fdbc..0000000000
Binary files a/projects/hip/docs/RuntimeAPI/html/structtexture.png and /dev/null differ
diff --git a/projects/hip/docs/RuntimeAPI/html/structtextureReference-members.html b/projects/hip/docs/RuntimeAPI/html/structtextureReference-members.html
index f971eeabae..6e42d07c6d 100644
--- a/projects/hip/docs/RuntimeAPI/html/structtextureReference-members.html
+++ b/projects/hip/docs/RuntimeAPI/html/structtextureReference-members.html
@@ -96,7 +96,7 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structtextureReference.html b/projects/hip/docs/RuntimeAPI/html/structtextureReference.html
index 042d943628..a7592835bd 100644
--- a/projects/hip/docs/RuntimeAPI/html/structtextureReference.html
+++ b/projects/hip/docs/RuntimeAPI/html/structtextureReference.html
@@ -90,15 +90,6 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
- Public Attributes | normalized |
1.8.6
diff --git a/projects/hip/docs/RuntimeAPI/html/structtextureReference.png b/projects/hip/docs/RuntimeAPI/html/structtextureReference.png
deleted file mode 100644
index 5447140274..0000000000
Binary files a/projects/hip/docs/RuntimeAPI/html/structtextureReference.png and /dev/null differ
diff --git a/projects/hip/docs/RuntimeAPI/html/structuchar1-members.html b/projects/hip/docs/RuntimeAPI/html/structuchar1-members.html
deleted file mode 100644
index a2d9e5a75c..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structuchar1-members.html
+++ /dev/null
@@ -1,102 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for uchar1, including all inherited members.
-| x (defined in uchar1) | uchar1 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structuchar1.html b/projects/hip/docs/RuntimeAPI/html/structuchar1.html
deleted file mode 100644
index e1ccab91c2..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structuchar1.html
+++ /dev/null
@@ -1,111 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -unsigned char | x |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structuchar2-members.html b/projects/hip/docs/RuntimeAPI/html/structuchar2-members.html
deleted file mode 100644
index f6195412b8..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structuchar2-members.html
+++ /dev/null
@@ -1,103 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for uchar2, including all inherited members.
-| x (defined in uchar2) | uchar2 | |
| y (defined in uchar2) | uchar2 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structuchar2.html b/projects/hip/docs/RuntimeAPI/html/structuchar2.html
deleted file mode 100644
index e50d42f883..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structuchar2.html
+++ /dev/null
@@ -1,114 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -unsigned char | x |
| -unsigned char | y |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structuchar3-members.html b/projects/hip/docs/RuntimeAPI/html/structuchar3-members.html
deleted file mode 100644
index 2ad6db7003..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structuchar3-members.html
+++ /dev/null
@@ -1,104 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for uchar3, including all inherited members.
-| x (defined in uchar3) | uchar3 | |
| y (defined in uchar3) | uchar3 | |
| z (defined in uchar3) | uchar3 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structuchar3.html b/projects/hip/docs/RuntimeAPI/html/structuchar3.html
deleted file mode 100644
index 4c2640860a..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structuchar3.html
+++ /dev/null
@@ -1,117 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -unsigned char | x |
| -unsigned char | y |
| -unsigned char | z |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structuchar4-members.html b/projects/hip/docs/RuntimeAPI/html/structuchar4-members.html
deleted file mode 100644
index b37288c0a0..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structuchar4-members.html
+++ /dev/null
@@ -1,105 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for uchar4, including all inherited members.
-| w (defined in uchar4) | uchar4 | |
| x (defined in uchar4) | uchar4 | |
| y (defined in uchar4) | uchar4 | |
| z (defined in uchar4) | uchar4 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structuchar4.html b/projects/hip/docs/RuntimeAPI/html/structuchar4.html
deleted file mode 100644
index 4c6074d22c..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structuchar4.html
+++ /dev/null
@@ -1,120 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -unsigned char | x |
| -unsigned char | y |
| -unsigned char | z |
| -unsigned char | w |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structuint1-members.html b/projects/hip/docs/RuntimeAPI/html/structuint1-members.html
deleted file mode 100644
index 6eec4356c7..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structuint1-members.html
+++ /dev/null
@@ -1,102 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for uint1, including all inherited members.
-| x (defined in uint1) | uint1 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structuint1.html b/projects/hip/docs/RuntimeAPI/html/structuint1.html
deleted file mode 100644
index 8ca11c3a38..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structuint1.html
+++ /dev/null
@@ -1,111 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -unsigned int | x |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structulong1-members.html b/projects/hip/docs/RuntimeAPI/html/structulong1-members.html
deleted file mode 100644
index 669f7fc749..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structulong1-members.html
+++ /dev/null
@@ -1,102 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for ulong1, including all inherited members.
-| x (defined in ulong1) | ulong1 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structulong1.html b/projects/hip/docs/RuntimeAPI/html/structulong1.html
deleted file mode 100644
index 28e2087d73..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structulong1.html
+++ /dev/null
@@ -1,111 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -unsigned long | x |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structulong2-members.html b/projects/hip/docs/RuntimeAPI/html/structulong2-members.html
deleted file mode 100644
index 9120b6de15..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structulong2-members.html
+++ /dev/null
@@ -1,103 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for ulong2, including all inherited members.
-| x (defined in ulong2) | ulong2 | |
| y (defined in ulong2) | ulong2 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structulong2.html b/projects/hip/docs/RuntimeAPI/html/structulong2.html
deleted file mode 100644
index 1f53589875..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structulong2.html
+++ /dev/null
@@ -1,114 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -unsigned long | x |
| -unsigned long | y |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structulong3-members.html b/projects/hip/docs/RuntimeAPI/html/structulong3-members.html
deleted file mode 100644
index 8bd18f2919..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structulong3-members.html
+++ /dev/null
@@ -1,104 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for ulong3, including all inherited members.
-| x (defined in ulong3) | ulong3 | |
| y (defined in ulong3) | ulong3 | |
| z (defined in ulong3) | ulong3 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structulong3.html b/projects/hip/docs/RuntimeAPI/html/structulong3.html
deleted file mode 100644
index 7815a49ac0..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structulong3.html
+++ /dev/null
@@ -1,117 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -unsigned long | x |
| -unsigned long | y |
| -unsigned long | z |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structulong4-members.html b/projects/hip/docs/RuntimeAPI/html/structulong4-members.html
deleted file mode 100644
index 574d994e3e..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structulong4-members.html
+++ /dev/null
@@ -1,105 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for ulong4, including all inherited members.
-| w (defined in ulong4) | ulong4 | |
| x (defined in ulong4) | ulong4 | |
| y (defined in ulong4) | ulong4 | |
| z (defined in ulong4) | ulong4 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structulong4.html b/projects/hip/docs/RuntimeAPI/html/structulong4.html
deleted file mode 100644
index 88ef7a5ff9..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structulong4.html
+++ /dev/null
@@ -1,120 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -unsigned long | x |
| -unsigned long | y |
| -unsigned long | z |
| -unsigned long | w |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structulonglong1-members.html b/projects/hip/docs/RuntimeAPI/html/structulonglong1-members.html
deleted file mode 100644
index a87a99387b..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structulonglong1-members.html
+++ /dev/null
@@ -1,102 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for ulonglong1, including all inherited members.
-| x (defined in ulonglong1) | ulonglong1 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structulonglong1.html b/projects/hip/docs/RuntimeAPI/html/structulonglong1.html
deleted file mode 100644
index c873cf8d93..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structulonglong1.html
+++ /dev/null
@@ -1,111 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -unsigned long long | x |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structulonglong2-members.html b/projects/hip/docs/RuntimeAPI/html/structulonglong2-members.html
deleted file mode 100644
index 6ba70a9646..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structulonglong2-members.html
+++ /dev/null
@@ -1,103 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for ulonglong2, including all inherited members.
-| x (defined in ulonglong2) | ulonglong2 | |
| y (defined in ulonglong2) | ulonglong2 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structulonglong2.html b/projects/hip/docs/RuntimeAPI/html/structulonglong2.html
deleted file mode 100644
index c58d2eaf5d..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structulonglong2.html
+++ /dev/null
@@ -1,114 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -unsigned long long | x |
| -unsigned long long | y |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structulonglong3-members.html b/projects/hip/docs/RuntimeAPI/html/structulonglong3-members.html
deleted file mode 100644
index b057dc42db..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structulonglong3-members.html
+++ /dev/null
@@ -1,104 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for ulonglong3, including all inherited members.
-| x (defined in ulonglong3) | ulonglong3 | |
| y (defined in ulonglong3) | ulonglong3 | |
| z (defined in ulonglong3) | ulonglong3 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structulonglong3.html b/projects/hip/docs/RuntimeAPI/html/structulonglong3.html
deleted file mode 100644
index 1aa9f27840..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structulonglong3.html
+++ /dev/null
@@ -1,117 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -unsigned long long | x |
| -unsigned long long | y |
| -unsigned long long | z |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structulonglong4-members.html b/projects/hip/docs/RuntimeAPI/html/structulonglong4-members.html
deleted file mode 100644
index 8933649bcf..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structulonglong4-members.html
+++ /dev/null
@@ -1,105 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for ulonglong4, including all inherited members.
-| w (defined in ulonglong4) | ulonglong4 | |
| x (defined in ulonglong4) | ulonglong4 | |
| y (defined in ulonglong4) | ulonglong4 | |
| z (defined in ulonglong4) | ulonglong4 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structulonglong4.html b/projects/hip/docs/RuntimeAPI/html/structulonglong4.html
deleted file mode 100644
index a745d34ecf..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structulonglong4.html
+++ /dev/null
@@ -1,120 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -unsigned long long | x |
| -unsigned long long | y |
| -unsigned long long | z |
| -unsigned long long | w |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structushort1-members.html b/projects/hip/docs/RuntimeAPI/html/structushort1-members.html
deleted file mode 100644
index 084a06bb60..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structushort1-members.html
+++ /dev/null
@@ -1,102 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for ushort1, including all inherited members.
-| x (defined in ushort1) | ushort1 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structushort1.html b/projects/hip/docs/RuntimeAPI/html/structushort1.html
deleted file mode 100644
index 10eeae3da1..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structushort1.html
+++ /dev/null
@@ -1,111 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -unsigned short | x |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structushort2-members.html b/projects/hip/docs/RuntimeAPI/html/structushort2-members.html
deleted file mode 100644
index 4219cfcc0d..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structushort2-members.html
+++ /dev/null
@@ -1,103 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for ushort2, including all inherited members.
-| x (defined in ushort2) | ushort2 | |
| y (defined in ushort2) | ushort2 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structushort2.html b/projects/hip/docs/RuntimeAPI/html/structushort2.html
deleted file mode 100644
index b6523a4a17..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structushort2.html
+++ /dev/null
@@ -1,114 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -unsigned short | x |
| -unsigned short | y |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structushort3-members.html b/projects/hip/docs/RuntimeAPI/html/structushort3-members.html
deleted file mode 100644
index 0aa517b830..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structushort3-members.html
+++ /dev/null
@@ -1,104 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for ushort3, including all inherited members.
-| x (defined in ushort3) | ushort3 | |
| y (defined in ushort3) | ushort3 | |
| z (defined in ushort3) | ushort3 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structushort3.html b/projects/hip/docs/RuntimeAPI/html/structushort3.html
deleted file mode 100644
index 590a5579a6..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structushort3.html
+++ /dev/null
@@ -1,117 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -unsigned short | x |
| -unsigned short | y |
| -unsigned short | z |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structushort4-members.html b/projects/hip/docs/RuntimeAPI/html/structushort4-members.html
deleted file mode 100644
index b103b96ed8..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structushort4-members.html
+++ /dev/null
@@ -1,105 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
This is the complete list of members for ushort4, including all inherited members.
-| w (defined in ushort4) | ushort4 | |
| x (defined in ushort4) | ushort4 | |
| y (defined in ushort4) | ushort4 | |
| z (defined in ushort4) | ushort4 |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/structushort4.html b/projects/hip/docs/RuntimeAPI/html/structushort4.html
deleted file mode 100644
index 55ddd7c472..0000000000
--- a/projects/hip/docs/RuntimeAPI/html/structushort4.html
+++ /dev/null
@@ -1,120 +0,0 @@
-
-
-
-
-
-
-|
- HIP: Heterogenous-computing Interface for Portability
-
- |
-
-Public Attributes | |
| -unsigned short | x |
| -unsigned short | y |
| -unsigned short | z |
| -unsigned short | w |
- 1.8.6
-
-
-
diff --git a/projects/hip/docs/RuntimeAPI/html/trace__helper_8h_source.html b/projects/hip/docs/RuntimeAPI/html/trace__helper_8h_source.html
new file mode 100644
index 0000000000..ad334e43a6
--- /dev/null
+++ b/projects/hip/docs/RuntimeAPI/html/trace__helper_8h_source.html
@@ -0,0 +1,231 @@
+
+
+
+
+
+
+|
+ HIP: Heterogenous-computing Interface for Portability
+
+ |
+
+ 1.8.6
+
+
+